service_language = ["English", "French"]

communication_language = ["English", "French", "Both", "Neither"]

gender = ["Female", "Male", "Uknown", "Another gender"]

immigration_status = [
    "Citizen",
    "Permanent resident",
    "Visitor",
    "Worker",
    "Student",
    "Other",
    "Protected Person",
    "Refugee Claimant",
    "Foreign National",
]

marital_status = [
    "Annulled Marriage",
    "Common-Law",
    "Divorced",
    "Married",
    "Separated",
    "Single",
    "Unknown",
    "Widowed",
]

relation_type = ["Common-Law", "Married"]

education_level = [
    "None",
    "Secondary or less",
    "Trade/Apprenticeship Certificate/Diploma",
    "Non-University Certificate/Diploma",
    "Post-Secondary – No Degree",
    "Bachelor’s Degree",
    "Post Graduate – No Degree",
    "Master’s Degree",
    "Doctorate - Ph D",
]

purpose_of_coming = ["Business", "Tourism", "Study", "Work", "Other", "Family Visist"]

purpose_of_vist = [
    "Business",
    "Tourism",
    "Short-Term Studies",
    "Returning Student",
    "Returning Worker",
    "Super Visa: For Parents or Grandpareents",
    "Other",
    "Family Visit",
    "Visit",
]

expense_by = ["Myself", "Parents", "Other"]

level_of_study = [
    "Primary School",
    "Secondary School",
    "PTC/TCST/DVS/AVS",
    "CEGEP - Pre-university",
    "CEGEP - Technical",
    "College - Certificate",
    "College - Diploma",
    "College - Applied degree",
    "University - Bachelor's Deg.",
    "University - Master's Deg.",
    "University - Doctorate",
    "University - Other Studies",
    "ESL/FSL",
    "ESL/FSL and College",
    "ESL/FSL and University",
    "Other Studies",
    "Not Applicable",
]


def get_5709_study_level(edu_level):
    data = {
        "Doctor": "University - Doctorate",
        "Master": "University - Master's Deg.",
        "Post-graduate diploma": "Not Applicable",
        "Bachelor": "University - Bachelor's Deg.",
        "Associate": "Not Applicable",
        "Diploma/Certificate": "College - Diploma",
        "High school": "Secondary School",
        "Less than high school": "Primary School",
    }
    return data.get(edu_level) or "Other Studies"


field_of_study = [
    "Arts/Humanities/Social Science",
    "Arts, Fine/Visual/Performing",
    "Business/Commerce",
    "Computing/IT",
    "ESL/FSL",
    "Flight Training",
    "Hospitality/Tourism",
    "Law",
    "Medicine",
    "Science, Applied",
    "Sciences, General",
    "Sciences, Health",
    "Trades/Vocational",
    "Theology/Religious Studies",
    "Other",
    "Agric/Agric Ops/Rel Sciences",
    "Architecture and Rel Services",
    "Biological/Biomed Sciences",
    "Business/Mgmt/Marketing",
]

country_of_birth = [
    "Afghanistan",
    "Aland Island",
    "Albania",
    "Algeria",
    "Andorra",
    "Angola",
    "Anguilla",
    "Antigua And Barbuda",
    "Argentina",
    "Armenia",
    "Aruba",
    "Australia",
    "Austria",
    "Azerbaijan",
    "Bahamas",
    "Bahrain",
    "Bailwick of Jersey",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bermuda",
    "Bhutan",
    "Bolivia",
    "Bonaire, Sint Eustatius, Saba",
    "Bosnia and Herzegovina",
    "Botswana",
    "Bouvet Island",
    "Brazil",
    "British Indian Ocean Territory",
    "British Virgin Islands",
    "Brunei Darussalam",
    "Bulgaria",
    "Burkina Faso",
    "Burma (Myanmar)",
    "Burundi",
    "Cabo Verde",
    "Cambodia",
    "Cameroon",
    "Canada",
    "Canary Islands",
    "Cayman Islands",
    "Central African Republic",
    "Chad",
    "Channel Islands",
    "Chile",
    "China",
    "China (Hong Kong SAR)",
    "China (Macao SAR)",
    "Christmas Island",
    "Colombia",
    "Comoros",
    "Cook Islands",
    "Costa Rica",
    "Croatia",
    "Cuba",
    "Cura\u00e7ao",
    "Cyprus",
    "Czech Republic",
    "Czechoslovakia",
    "Democratic Rep. of Congo",
    "Denmark",
    "Djibouti",
    "Dominica",
    "Dominican Republic",
    "East Timor",
    "Ecuador",
    "Egypt",
    "El Salvador",
    "England",
    "Equatorial Guinea",
    "Eritrea",
    "Estonia",
    "Ethiopia",
    "Falkland Islands",
    "Faroe Islands",
    "Federated States of Micronesia",
    "Fiji",
    "Finland",
    "Fr. South. and Antarctic Lands",
    "France",
    "French Guiana",
    "French Polynesia",
    "Gabon",
    "Gambia",
    "Georgia",
    "Germany, Federal Republic Of",
    "Ghana",
    "Gibraltar",
    "Greece",
    "Greenland",
    "Grenada",
    "Guadeloupe",
    "Guam",
    "Guatemala",
    "Guernsey",
    "Guinea",
    "Guinea-Bissau",
    "Guyana",
    "Haiti",
    "Heard and MacDonald Islands",
    "Honduras",
    "Hong Kong",
    "Hungary",
    "Iceland",
    "India",
    "Indonesia",
    "Iran",
    "Iraq",
    "Ireland",
    "Isle of Man",
    "Israel",
    "Italy",
    "Ivory Coast",
    "Jamaica",
    "Japan",
    "Jordan",
    "Kampuchea Democratic Rep.",
    "Kazakhstan",
    "Kenya",
    "Kiribati",
    "Korea, North (DPRK)",
    "Korea, South",
    "Kosovo",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "Macao",
    "Macedonia",
    "Madagascar",
    "Madeira",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Marshall Islands",
    "Martinique",
    "Mauritania",
    "Mauritius",
    "Mayotte",
    "Mexico",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montenegro",
    "Montserrat",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nauru",
    "Nepal",
    "Netherlands Antilles, The",
    "Netherlands, The",
    "Nevis",
    "New Caledonia",
    "New Zealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "Niue",
    "Northern Ireland",
    "Northern Mariana Islands",
    "Norway",
    "Oman",
    "Pakistan",
    "Palestinian Authority",
    "Panama",
    "Papua New Guinea",
    "Paraguay",
    "Peru",
    "Philippines",
    "Pitcairn Islands",
    "Poland",
    "Portugal",
    "Puerto Rico",
    "Qatar",
    "Republic of Congo",
    "Republic of Palau",
    "R\u00e9union",
    "Romania",
    "Russia",
    "Rwanda",
    "Saint Helena",
    "Saint Kitts and Nevis",
    "Saint Lucia",
    "Saint Pierre and Miquelon",
    "Saint-Barthelemy",
    "Saint-Martin",
    "Samoa",
    "Samoa, American",
    "San Marino",
    "Sao Tome and Principe",
    "Saudi Arabia",
    "Scotland",
    "Senegal",
    "Serbia And Montenegro",
    "Serbia, Republic Of",
    "Seychelles",
    "Sierra Leone",
    "Singapore",
    "Sint-Maarten",
    "Slovakia",
    "Slovenia",
    "Solomon Islands",
    "Somalia",
    "South Africa, Republic Of",
    "South Sudan",
    "Spain",
    "Sri Lanka",
    "St. Vincent and the Grenadines",
    "Sudan",
    "Suriname",
    "Swaziland",
    "Sweden",
    "Switzerland",
    "Syria",
    "Taiwan",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "Tibet (Autonomous Region)",
    "Togo",
    "Tokelau",
    "Tonga",
    "Trinidad and Tobago",
    "Tunisia",
    "Turkey",
    "Turkmenistan",
    "Turks and Caicos Islands",
    "Tuvalu",
    "U.S. Minor outlying Islands",
    "Uganda",
    "Ukraine",
    "Union Of Soviet Socialist Rep",
    "United Arab Emirates",
    "United States of America",
    "Unknown",
    "Uruguay",
    "Uzbekistan",
    "Vanuatu",
    "Vatican City State",
    "Venezuela",
    "Vietnam",
    "Virgin Islands, U.S.",
    "Wales",
    "Wallis and Futuna Is., Terr.",
    "Western Sahara",
    "Yemen",
    "Yugoslavia",
    "Zambia",
    "Zimbabwe",
]

country_of_citizen = [
    "Afghanistan",
    "Albania",
    "Algeria",
    "Andorra",
    "Angola",
    "Antigua And Barbuda",
    "Argentina",
    "Armenia",
    "Australia",
    "Austria",
    "Azerbaijan",
    "Bahamas",
    "Bahrain",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bhutan",
    "Bolivia",
    "Bosnia and Herzegovina",
    "Botswana",
    "Brazil",
    "Brunei Darussalam",
    "Bulgaria",
    "Burkina Faso",
    "Burma (Myanmar)",
    "Burundi",
    "Cabo Verde",
    "Cambodia",
    "Cameroon",
    "Canada",
    "Central African Republic",
    "Chad",
    "Chile",
    "China",
    "China (Hong Kong SAR)",
    "China (Macao SAR)",
    "Colombia",
    "Comoros",
    "Costa Rica",
    "Croatia",
    "Cuba",
    "Cyprus",
    "Czech Republic",
    "Democratic Rep. of Congo",
    "Denmark",
    "Djibouti",
    "Dominica",
    "Dominican Republic",
    "East Timor",
    "Ecuador",
    "Egypt",
    "El Salvador",
    "Equatorial Guinea",
    "Eritrea",
    "Estonia",
    "Ethiopia",
    "Federated States of Micronesia",
    "Fiji",
    "Finland",
    "France",
    "Gabon",
    "Gambia",
    "Georgia",
    "Germany, Federal Republic Of",
    "Ghana",
    "Greece",
    "Grenada",
    "Guatemala",
    "Guinea",
    "Guinea-Bissau",
    "Guyana",
    "Haiti",
    "Honduras",
    "Hungary",
    "Iceland",
    "India",
    "Indonesia",
    "Iran",
    "Iraq",
    "Ireland",
    "Israel",
    "Italy",
    "Ivory Coast",
    "Jamaica",
    "Japan",
    "Jordan",
    "Kazakhstan",
    "Kenya",
    "Kiribati",
    "Korea, North (DPRK)",
    "Korea, South",
    "Kosovo",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "Macedonia",
    "Madagascar",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Marshall Islands",
    "Mauritania",
    "Mauritius",
    "Mexico",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montenegro",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nauru",
    "Nepal",
    "Netherlands, The",
    "New Caledonia",
    "New Zealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "Northern Mariana Islands",
    "Norway",
    "Oman",
    "Pakistan",
    "Palestinian Authority",
    "Panama",
    "Papua New Guinea",
    "Paraguay",
    "Peru",
    "Philippines",
    "Poland",
    "Portugal",
    "Qatar",
    "Republic of Congo",
    "Republic of Palau",
    "Romania",
    "Russia",
    "Rwanda",
    "Saint Kitts and Nevis",
    "Saint Lucia",
    "Samoa",
    "San Marino",
    "Sao Tome and Principe",
    "Saudi Arabia",
    "Senegal",
    "Serbia, Republic Of",
    "Seychelles",
    "Sierra Leone",
    "Singapore",
    "Slovakia",
    "Slovenia",
    "Solomon Islands",
    "Somalia",
    "South Africa, Republic Of",
    "South Sudan",
    "Spain",
    "Sri Lanka",
    "St. Vincent and the Grenadines",
    "Stateless",
    "Sudan",
    "Suriname",
    "Swaziland",
    "Sweden",
    "Switzerland",
    "Syria",
    "Taiwan",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "Togo",
    "Tonga",
    "Trinidad and Tobago",
    "Tunisia",
    "Turkey",
    "Turkmenistan",
    "Tuvalu",
    "Uganda",
    "UK - Brit. Ntl. Overseas",
    "UK - Brit. overseas citizen",
    "UK - Brit. overseas terr.",
    "UK - British citizen",
    "Ukraine",
    "United Arab Emirates",
    "United States of America",
    "Unknown",
    "Uruguay",
    "Uzbekistan",
    "Vanuatu",
    "Vatican City State",
    "Venezuela",
    "Vietnam",
    "Western Sahara",
    "Yemen",
    "Zambia",
    "Zimbabwe",
]

country_of_residence = [
    "Afghanistan",
    "Albania",
    "Algeria",
    "Andorra",
    "Angola",
    "Anguilla",
    "Antigua And Barbuda",
    "Argentina",
    "Armenia",
    "Aruba",
    "Australia",
    "Austria",
    "Azerbaijan",
    "Azores",
    "Bahamas",
    "Bahrain",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bermuda",
    "Bhutan",
    "Bolivia",
    "Bosnia and Herzegovina",
    "Botswana",
    "Brazil",
    "British Virgin Islands",
    "Brunei Darussalam",
    "Bulgaria",
    "Burkina Faso",
    "Burma (Myanmar)",
    "Burundi",
    "Cabo Verde",
    "Cambodia",
    "Cameroon",
    "Canada",
    "Canary Islands",
    "Cayman Islands",
    "Central African Republic",
    "Chad",
    "Channel Islands",
    "Chile",
    "China",
    "China (Hong Kong SAR)",
    "China (Macao SAR)",
    "Colombia",
    "Comoros",
    "Cook Islands",
    "Costa Rica",
    "Croatia",
    "Cuba",
    "Cyprus",
    "Czech Republic",
    "Democratic Rep. of Congo",
    "Denmark",
    "Djibouti",
    "Dominica",
    "Dominican Republic",
    "East Timor",
    "Ecuador",
    "Egypt",
    "El Salvador",
    "England",
    "Equatorial Guinea",
    "Eritrea",
    "Estonia",
    "Ethiopia",
    "Falkland Islands",
    "Federated States of Micronesia",
    "Fiji",
    "Finland",
    "Fr. South. and Antarctic Lands",
    "France",
    "French Guiana",
    "French Polynesia",
    "Gabon",
    "Gambia",
    "Georgia",
    "Germany, Federal Republic Of",
    "Ghana",
    "Gibraltar",
    "Greece",
    "Greenland",
    "Grenada",
    "Guadeloupe",
    "Guam",
    "Guatemala",
    "Guinea",
    "Guinea-Bissau",
    "Guyana",
    "Haiti",
    "Honduras",
    "Hong Kong",
    "Hungary",
    "Iceland",
    "India",
    "Indonesia",
    "Iran",
    "Iraq",
    "Ireland",
    "Israel",
    "Italy",
    "Ivory Coast",
    "Jamaica",
    "Japan",
    "Jordan",
    "Kazakhstan",
    "Kenya",
    "Kiribati",
    "Korea, North (DPRK)",
    "Korea, South",
    "Kosovo",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "Macao",
    "Macedonia",
    "Madagascar",
    "Madeira",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Marshall Islands",
    "Martinique",
    "Mauritania",
    "Mauritius",
    "Mayotte",
    "Mexico",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montenegro",
    "Montserrat",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nauru",
    "Nepal",
    "Netherlands Antilles, The",
    "Netherlands, The",
    "Nevis",
    "New Caledonia",
    "New Zealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "North Vietnam",
    "Northern Ireland",
    "Northern Mariana Islands",
    "Norway",
    "Oman",
    "Pakistan",
    "Palestinian Authority",
    "Panama",
    "Papua New Guinea",
    "Paraguay",
    "Peru",
    "Philippines",
    "Pitcairn Islands",
    "Poland",
    "Portugal",
    "Puerto Rico",
    "Qatar",
    "Republic of Congo",
    "Republic of Palau",
    "R\u00e9union",
    "Romania",
    "Russia",
    "Rwanda",
    "Saint Helena",
    "Saint Kitts and Nevis",
    "Saint Lucia",
    "Saint Pierre and Miquelon",
    "Saint-Martin",
    "Samoa",
    "Samoa, American",
    "San Marino",
    "Sao Tome and Principe",
    "Saudi Arabia",
    "Scotland",
    "Senegal",
    "Serbia, Republic Of",
    "Seychelles",
    "Sierra Leone",
    "Singapore",
    "Slovakia",
    "Slovenia",
    "Solomon Islands",
    "Somalia",
    "South Africa, Republic Of",
    "South Sudan",
    "Spain",
    "Sri Lanka",
    "St. Vincent and the Grenadines",
    "Sudan",
    "Suriname",
    "Swaziland",
    "Sweden",
    "Switzerland",
    "Syria",
    "Taiwan",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "Togo",
    "Tonga",
    "Trinidad and Tobago",
    "Tunisia",
    "Turkey",
    "Turkmenistan",
    "Turks and Caicos Islands",
    "Tuvalu",
    "Uganda",
    "Ukraine",
    "United Arab Emirates",
    "United States of America",
    "Unknown",
    "Uruguay",
    "Uzbekistan",
    "Vanuatu",
    "Vatican City State",
    "Venezuela",
    "Vietnam",
    "Virgin Islands, U.S.",
    "Wales",
    "Wallis and Futuna Is., Terr.",
    "Western Sahara",
    "Yemen",
    "Zambia",
    "Zimbabwe",
]

previous_country = [
    "Afghanistan",
    "Albania",
    "Algeria",
    "Andorra",
    "Angola",
    "Anguilla",
    "Antigua And Barbuda",
    "Argentina",
    "Armenia",
    "Aruba",
    "Australia",
    "Austria",
    "Azerbaijan",
    "Azores",
    "Bahamas",
    "Bahrain",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bermuda",
    "Bhutan",
    "Bolivia",
    "Bosnia and Herzegovina",
    "Botswana",
    "Brazil",
    "British Virgin Islands",
    "Brunei Darussalam",
    "Bulgaria",
    "Burkina Faso",
    "Burma (Myanmar)",
    "Burundi",
    "Cabo Verde",
    "Cambodia",
    "Cameroon",
    "Canada",
    "Canary Islands",
    "Cayman Islands",
    "Central African Republic",
    "Chad",
    "Channel Islands",
    "Chile",
    "China",
    "China (Hong Kong SAR)",
    "China (Macao SAR)",
    "Colombia",
    "Comoros",
    "Cook Islands",
    "Costa Rica",
    "Croatia",
    "Cuba",
    "Cyprus",
    "Czech Republic",
    "Democratic Rep. of Congo",
    "Denmark",
    "Djibouti",
    "Dominica",
    "Dominican Republic",
    "East Timor",
    "Ecuador",
    "Egypt",
    "El Salvador",
    "England",
    "Equatorial Guinea",
    "Eritrea",
    "Estonia",
    "Ethiopia",
    "Falkland Islands",
    "Federated States of Micronesia",
    "Fiji",
    "Finland",
    "Fr. South. and Antarctic Lands",
    "France",
    "French Guiana",
    "French Polynesia",
    "Gabon",
    "Gambia",
    "Georgia",
    "Germany, Federal Republic Of",
    "Ghana",
    "Gibraltar",
    "Greece",
    "Greenland",
    "Grenada",
    "Guadeloupe",
    "Guam",
    "Guatemala",
    "Guinea",
    "Guinea-Bissau",
    "Guyana",
    "Haiti",
    "Honduras",
    "Hong Kong",
    "Hungary",
    "Iceland",
    "India",
    "Indonesia",
    "Iran",
    "Iraq",
    "Ireland",
    "Israel",
    "Italy",
    "Ivory Coast",
    "Jamaica",
    "Japan",
    "Jordan",
    "Kazakhstan",
    "Kenya",
    "Kiribati",
    "Korea, North (DPRK)",
    "Korea, South",
    "Kosovo",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "Macao",
    "Macedonia",
    "Madagascar",
    "Madeira",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Marshall Islands",
    "Martinique",
    "Mauritania",
    "Mauritius",
    "Mayotte",
    "Mexico",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montenegro",
    "Montserrat",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nauru",
    "Nepal",
    "Netherlands Antilles, The",
    "Netherlands, The",
    "Nevis",
    "New Caledonia",
    "New Zealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "North Vietnam",
    "Northern Ireland",
    "Northern Mariana Islands",
    "Norway",
    "Oman",
    "Pakistan",
    "Palestinian Authority",
    "Panama",
    "Papua New Guinea",
    "Paraguay",
    "Peru",
    "Philippines",
    "Pitcairn Islands",
    "Poland",
    "Portugal",
    "Puerto Rico",
    "Qatar",
    "Republic of Congo",
    "Republic of Palau",
    "Réunion",
    "Romania",
    "Russia",
    "Rwanda",
    "Saint Helena",
    "Saint Kitts and Nevis",
    "Saint Lucia",
    "Saint Pierre and Miquelon",
    "Saint-Martin",
    "Samoa",
    "Samoa, American",
    "San Marino",
    "Sao Tome and Principe",
    "Saudi Arabia",
    "Scotland",
    "Senegal",
    "Serbia, Republic Of",
    "Seychelles",
    "Sierra Leone",
    "Singapore",
    "Slovakia",
    "Slovenia",
    "Solomon Islands",
    "Somalia",
    "South Africa, Republic Of",
    "South Sudan",
    "Spain",
    "Sri Lanka",
    "St. Vincent and the Grenadines",
    "Sudan",
    "Suriname",
    "Swaziland",
    "Sweden",
    "Switzerland",
    "Syria",
    "Taiwan",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "Togo",
    "Tonga",
    "Trinidad and Tobago",
    "Tunisia",
    "Turkey",
    "Turkmenistan",
    "Turks and Caicos Islands",
    "Tuvalu",
    "Uganda",
    "Ukraine",
    "United Arab Emirates",
    "United States of America",
    "Unknown",
    "Uruguay",
    "Uzbekistan",
    "Vanuatu",
    "Vatican City State",
    "Venezuela",
    "Vietnam",
    "Virgin Islands, U.S.",
    "Wales",
    "Wallis and Futuna Is., Terr.",
    "Western Sahara",
    "Yemen",
    "Zambia",
    "Zimbabwe",
]

passport_country = [
    "AFG (Afghanistan)",
    "AGO (Angola)",
    "ALB (Albania)",
    "AND (Andorra)",
    "ANG (Anguilla)",
    "ARE (United Arab Emirates)",
    "ARG (Argentina)",
    "ARM (Armenia)",
    "ATG (Antigua And Barbuda)",
    "AUS (Australia)",
    "AUT (Austria)",
    "AZE (Azerbaijan)",
    "BDI (Burundi)",
    "BEL (Belgium)",
    "BEN (Benin)",
    "BFA (Burkina Faso)",
    "BGD (Bangladesh)",
    "BGR (Bulgaria)",
    "BHR (Bahrain)",
    "BHS (Bahamas)",
    "BIH (Bosnia and Herzegovina)",
    "BLR (Belarus)",
    "BLZ (Belize)",
    "BMU (Bermuda)",
    "BOL (Bolivia)",
    "BRA (Brazil)",
    "BRB (Barbados)",
    "BRN (Brunei Darussalam)",
    "BTN (Bhutan)",
    "BWA (Botswana)",
    "CAF (Central African Republic)",
    "CAN (Canada)",
    "CHE (Switzerland)",
    "CHL (Chile)",
    "CHN (China (Hong Kong SAR))",
    "CHN (China (Macao SAR))",
    "CHN (China)",
    "CIV (Ivory Coast)",
    "CMR (Cameroon)",
    "COD (Democratic Rep. of Congo)",
    "COG (Republic of Congo)",
    "COL (Colombia)",
    "COM (Comoros)",
    "CPV (Cabo Verde)",
    "CRI (Costa Rica)",
    "CUB (Cuba)",
    "CYM (Cayman Islands)",
    "CYP (Cyprus)",
    "CZE (Czech Republic)",
    "D (Germany, Federal Republic Of)",
    "DJI (Djibouti)",
    "DMA (Dominica)",
    "DNK (Denmark)",
    "DOM (Dominican Republic)",
    "DZA (Algeria)",
    "ECU (Ecuador)",
    "EGY (Egypt)",
    "ERI (Eritrea)",
    "ESP (Spain)",
    "EST (Estonia)",
    "ETH (Ethiopia)",
    "FIN (Finland)",
    "FJI (Fiji)",
    "FRA (France)",
    "FSM (Federated States of Micronesia)",
    "GAB (Gabon)",
    "GBD (UK - Brit. overseas terr.)",
    "GBN (UK - Brit. Ntl. Overseas)",
    "GBO (UK - Brit. overseas citizen)",
    "GBP (UK - Brit. protected person)",
    "GBR (UK - British citizen)",
    "GBS (UK - British subject)",
    "GEO (Georgia)",
    "GHA (Ghana)",
    "GIN (Guinea)",
    "GMB (Gambia)",
    "GNB (Guinea-Bissau)",
    "GNQ (Equatorial Guinea)",
    "GRC (Greece)",
    "GRD (Grenada)",
    "GTM (Guatemala)",
    "GUY (Guyana)",
    "HND (Honduras)",
    "HRV (Croatia)",
    "HTI (Haiti)",
    "HUN (Hungary)",
    "IDN (Indonesia)",
    "IND (India)",
    "IRL (Ireland)",
    "IRN (Iran)",
    "IRQ (Iraq)",
    "ISL (Iceland)",
    "ISR (Israel)",
    "ITA (Italy)",
    "JAM (Jamaica)",
    "JOR (Jordan)",
    "JPN (Japan)",
    "KAZ (Kazakhstan)",
    "KEN (Kenya)",
    "KGZ (Kyrgyzstan)",
    "KHM (Cambodia)",
    "KIR (Kiribati)",
    "KNA (Saint Kitts and Nevis)",
    "KOR (Korea, South)",
    "KWT (Kuwait)",
    "LAO (Laos)",
    "LBN (Lebanon)",
    "LBR (Liberia)",
    "LBY (Libya)",
    "LCA (Saint Lucia)",
    "LIE (Liechtenstein)",
    "LKA (Sri Lanka)",
    "LSO (Lesotho)",
    "LTU (Lithuania)",
    "LUX (Luxembourg)",
    "LVA (Latvia)",
    "MAR (Morocco)",
    "MCO (Monaco)",
    "MDA (Moldova)",
    "MDG (Madagascar)",
    "MDV (Maldives)",
    "MEX (Mexico)",
    "MHL (Marshall Islands)",
    "MKD (Macedonia)",
    "MLI (Mali)",
    "MLT (Malta)",
    "MMR (Burma (Myanmar))",
    "MNE (Montenegro)",
    "MNG (Mongolia)",
    "MOZ (Mozambique)",
    "MRT (Mauritania)",
    "MSR (Montserrat)",
    "MUS (Mauritius)",
    "MWI (Malawi)",
    "MYS (Malaysia)",
    "NAM (Namibia)",
    "NER (Niger)",
    "NGA (Nigeria)",
    "NIC (Nicaragua)",
    "NLD (Netherlands, The)",
    "NOR (Norway)",
    "NPL (Nepal)",
    "NRU (Nauru)",
    "NZL (New Zealand)",
    "OMN (Oman)",
    "PAK (Pakistan)",
    "PAN (Panama)",
    "PER (Peru)",
    "PHL (Philippines)",
    "PLW (Republic of Palau)",
    "PNG (Papua New Guinea)",
    "POL (Poland)",
    "PRK (Korea, North (DPRK))",
    "PRT (Portugal)",
    "PRY (Paraguay)",
    "PSE (Palestinian Authority)",
    "QAT (Qatar)",
    "RKS (Kosovo)",
    "ROU (Romania)",
    "RUS (Russia)",
    "RWA (Rwanda)",
    "SAU (Saudi Arabia)",
    "SDN (Sudan)",
    "SEN (Senegal)",
    "SGP (Singapore)",
    "SHN (Saint Helena)",
    "SLB (Solomon Islands)",
    "SLE (Sierra Leone)",
    "SLV (El Salvador)",
    "SMR (San Marino)",
    "SOM (Somalia)",
    "SRB (Serbia, Republic Of)",
    "SSD (South Sudan)",
    "STP (Sao Tome and Principe)",
    "SUR (Suriname)",
    "SVK (Slovakia)",
    "SVN (Slovenia)",
    "SWE (Sweden)",
    "SWZ (Swaziland)",
    "SYC (Seychelles)",
    "SYR (Syria)",
    "TCA (Turks and Caicos Islands)",
    "TCD (Chad)",
    "TGO (Togo)",
    "THA (Thailand)",
    "TJK (Tajikistan)",
    "TKM (Turkmenistan)",
    "TLS (East Timor)",
    "TON (Tonga)",
    "TTO (Trinidad and Tobago)",
    "TUN (Tunisia)",
    "TUR (Turkey)",
    "TUV (Tuvalu)",
    "TWN (Taiwan)",
    "TZA (Tanzania)",
    "UGA (Uganda)",
    "UKR (Ukraine)",
    "UNA (UN specialized agency)",
    "UNO (UN or official)",
    "URY (Uruguay)",
    "USA (United States of America)",
    "UZB (Uzbekistan)",
    "VAT (Vatican City State)",
    "VCT (St. Vincent and the Grenadines)",
    "VEN (Venezuela)",
    "VGB (British Virgin Islands)",
    "VNM (Vietnam)",
    "VUT (Vanuatu)",
    "WSM (Samoa)",
    "YEM (Yemen)",
    "ZAF (South Africa, Republic Of)",
    "ZMB (Zambia)",
    "ZWE (Zimbabwe)",
]

mailing_country = [
    "Afghanistan",
    "Aland Island",
    "Albania",
    "Algeria",
    "Andorra",
    "Angola",
    "Anguilla",
    "Antigua And Barbuda",
    "Argentina",
    "Armenia",
    "Aruba",
    "Australia",
    "Austria",
    "Azerbaijan",
    "Bahamas",
    "Bahrain",
    "Bailwick of Jersey",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bermuda",
    "Bhutan",
    "Bolivia",
    "Bonaire, Sint Eustatius, Saba",
    "Bosnia and Herzegovina",
    "Botswana",
    "Bouvet Island",
    "Brazil",
    "British Indian Ocean Territory",
    "British Virgin Islands",
    "Brunei Darussalam",
    "Bulgaria",
    "Burkina Faso",
    "Burma (Myanmar)",
    "Burundi",
    "Cabo Verde",
    "Cambodia",
    "Cameroon",
    "Canada",
    "Canary Islands",
    "Cayman Islands",
    "Central African Republic",
    "Chad",
    "Channel Islands",
    "Chile",
    "China",
    "China (Hong Kong SAR)",
    "China (Macao SAR)",
    "Christmas Island",
    "Colombia",
    "Comoros",
    "Cook Islands",
    "Costa Rica",
    "Croatia",
    "Cuba",
    "Curaçao",
    "Cyprus",
    "Czech Republic",
    "Czechoslovakia",
    "Democratic Rep. of Congo",
    "Denmark",
    "Djibouti",
    "Dominica",
    "Dominican Republic",
    "East Timor",
    "Ecuador",
    "Egypt",
    "El Salvador",
    "England",
    "Equatorial Guinea",
    "Eritrea",
    "Estonia",
    "Ethiopia",
    "Falkland Islands",
    "Faroe Islands",
    "Federated States of Micronesia",
    "Fiji",
    "Finland",
    "Fr. South. and Antarctic Lands",
    "France",
    "French Guiana",
    "French Polynesia",
    "Gabon",
    "Gambia",
    "Georgia",
    "Germany, Federal Republic Of",
    "Ghana",
    "Gibraltar",
    "Greece",
    "Greenland",
    "Grenada",
    "Guadeloupe",
    "Guam",
    "Guatemala",
    "Guernsey",
    "Guinea",
    "Guinea-Bissau",
    "Guyana",
    "Haiti",
    "Heard and MacDonald Islands",
    "Honduras",
    "Hong Kong",
    "Hungary",
    "Iceland",
    "India",
    "Indonesia",
    "Iran",
    "Iraq",
    "Ireland",
    "Isle of Man",
    "Israel",
    "Italy",
    "Ivory Coast",
    "Jamaica",
    "Japan",
    "Jordan",
    "Kampuchea Democratic Rep.",
    "Kazakhstan",
    "Kenya",
    "Kiribati",
    "Korea, North (DPRK)",
    "Korea, South",
    "Kosovo",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "Macao",
    "Macedonia",
    "Madagascar",
    "Madeira",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Marshall Islands",
    "Martinique",
    "Mauritania",
    "Mauritius",
    "Mayotte",
    "Mexico",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montenegro",
    "Montserrat",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nauru",
    "Nepal",
    "Netherlands Antilles, The",
    "Netherlands, The",
    "Nevis",
    "New Caledonia",
    "New Zealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "Niue",
    "Northern Ireland",
    "Northern Mariana Islands",
    "Norway",
    "Oman",
    "Pakistan",
    "Palestinian Authority",
    "Panama",
    "Papua New Guinea",
    "Paraguay",
    "Peru",
    "Philippines",
    "Pitcairn Islands",
    "Poland",
    "Portugal",
    "Puerto Rico",
    "Qatar",
    "Republic of Congo",
    "Republic of Palau",
    "Réunion",
    "Romania",
    "Russia",
    "Rwanda",
    "Saint Helena",
    "Saint Kitts and Nevis",
    "Saint Lucia",
    "Saint Pierre and Miquelon",
    "Saint-Barthelemy",
    "Saint-Martin",
    "Samoa",
    "Samoa, American",
    "San Marino",
    "Sao Tome and Principe",
    "Saudi Arabia",
    "Scotland",
    "Senegal",
    "Serbia And Montenegro",
    "Serbia, Republic Of",
    "Seychelles",
    "Sierra Leone",
    "Singapore",
    "Sint-Maarten",
    "Slovakia",
    "Slovenia",
    "Solomon Islands",
    "Somalia",
    "South Africa, Republic Of",
    "South Sudan",
    "Spain",
    "Sri Lanka",
    "St. Vincent and the Grenadines",
    "Sudan",
    "Suriname",
    "Swaziland",
    "Sweden",
    "Switzerland",
    "Syria",
    "Taiwan",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "Tibet (Autonomous Region)",
    "Togo",
    "Tokelau",
    "Tonga",
    "Trinidad and Tobago",
    "Tunisia",
    "Turkey",
    "Turkmenistan",
    "Turks and Caicos Islands",
    "Tuvalu",
    "U.S. Minor outlying Islands",
    "Uganda",
    "Ukraine",
    "Union Of Soviet Socialist Rep",
    "United Arab Emirates",
    "United States of America",
    "Unknown",
    "Uruguay",
    "Uzbekistan",
    "Vanuatu",
    "Vatican City State",
    "Venezuela",
    "Vietnam",
    "Virgin Islands, U.S.",
    "Wales",
    "Wallis and Futuna Is., Terr.",
    "Western Sahara",
    "Yemen",
    "Yugoslavia",
    "Zambia",
    "Zimbabwe",
]

canada_province = [
    "AB",
    "BC",
    "MB",
    "NB",
    "NL",
    "NS",
    "NT",
    "NU",
    "ON",
    "PE",
    "QC",
    "SK",
    "YT",
]

passport_issue_country = [
    "AFG (Afghanistan)",
    "AGO (Angola)",
    "ALB (Albania)",
    "AND (Andorra)",
    "ANG (Anguilla)",
    "ARE (United Arab Emirates)",
    "ARG (Argentina)",
    "ARM (Armenia)",
    "ATG (Antigua And Barbuda)",
    "AUS (Australia)",
    "AUT (Austria)",
    "AZE (Azerbaijan)",
    "BDI (Burundi)",
    "BEL (Belgium)",
    "BEN (Benin)",
    "BFA (Burkina Faso)",
    "BGD (Bangladesh)",
    "BGR (Bulgaria)",
    "BHR (Bahrain)",
    "BHS (Bahamas)",
    "BIH (Bosnia and Herzegovina)",
    "BLR (Belarus)",
    "BLZ (Belize)",
    "BMU (Bermuda)",
    "BOL (Bolivia)",
    "BRA (Brazil)",
    "BRB (Barbados)",
    "BRN (Brunei Darussalam)",
    "BTN (Bhutan)",
    "BWA (Botswana)",
    "CAF (Central African Republic)",
    "CAN (Canada)",
    "CHE (Switzerland)",
    "CHL (Chile)",
    "CHN (China (Hong Kong SAR))",
    "CHN (China (Macao SAR))",
    "CHN (China)",
    "CIV (Ivory Coast)",
    "CMR (Cameroon)",
    "COD (Democratic Rep. of Congo)",
    "COG (Republic of Congo)",
    "COL (Colombia)",
    "COM (Comoros)",
    "CPV (Cabo Verde)",
    "CRI (Costa Rica)",
    "CUB (Cuba)",
    "CYM (Cayman Islands)",
    "CYP (Cyprus)",
    "CZE (Czech Republic)",
    "D (Germany, Federal Republic Of)",
    "DJI (Djibouti)",
    "DMA (Dominica)",
    "DNK (Denmark)",
    "DOM (Dominican Republic)",
    "DZA (Algeria)",
    "ECU (Ecuador)",
    "EGY (Egypt)",
    "ERI (Eritrea)",
    "ESP (Spain)",
    "EST (Estonia)",
    "ETH (Ethiopia)",
    "FIN (Finland)",
    "FJI (Fiji)",
    "FRA (France)",
    "FSM (Federated States of Micronesia)",
    "GAB (Gabon)",
    "GBD (UK - Brit. overseas terr.)",
    "GBN (UK - Brit. Ntl. Overseas)",
    "GBO (UK - Brit. overseas citizen)",
    "GBP (UK - Brit. protected person)",
    "GBR (UK - British citizen)",
    "GBS (UK - British subject)",
    "GEO (Georgia)",
    "GHA (Ghana)",
    "GIN (Guinea)",
    "GMB (Gambia)",
    "GNB (Guinea-Bissau)",
    "GNQ (Equatorial Guinea)",
    "GRC (Greece)",
    "GRD (Grenada)",
    "GTM (Guatemala)",
    "GUY (Guyana)",
    "HND (Honduras)",
    "HRV (Croatia)",
    "HTI (Haiti)",
    "HUN (Hungary)",
    "IDN (Indonesia)",
    "IND (India)",
    "IRL (Ireland)",
    "IRN (Iran)",
    "IRQ (Iraq)",
    "ISL (Iceland)",
    "ISR (Israel)",
    "ITA (Italy)",
    "JAM (Jamaica)",
    "JOR (Jordan)",
    "JPN (Japan)",
    "KAZ (Kazakhstan)",
    "KEN (Kenya)",
    "KGZ (Kyrgyzstan)",
    "KHM (Cambodia)",
    "KIR (Kiribati)",
    "KNA (Saint Kitts and Nevis)",
    "KOR (Korea, South)",
    "KWT (Kuwait)",
    "LAO (Laos)",
    "LBN (Lebanon)",
    "LBR (Liberia)",
    "LBY (Libya)",
    "LCA (Saint Lucia)",
    "LIE (Liechtenstein)",
    "LKA (Sri Lanka)",
    "LSO (Lesotho)",
    "LTU (Lithuania)",
    "LUX (Luxembourg)",
    "LVA (Latvia)",
    "MAR (Morocco)",
    "MCO (Monaco)",
    "MDA (Moldova)",
    "MDG (Madagascar)",
    "MDV (Maldives)",
    "MEX (Mexico)",
    "MHL (Marshall Islands)",
    "MKD (Macedonia)",
    "MLI (Mali)",
    "MLT (Malta)",
    "MMR (Burma (Myanmar))",
    "MNE (Montenegro)",
    "MNG (Mongolia)",
    "MOZ (Mozambique)",
    "MRT (Mauritania)",
    "MSR (Montserrat)",
    "MUS (Mauritius)",
    "MWI (Malawi)",
    "MYS (Malaysia)",
    "NAM (Namibia)",
    "NER (Niger)",
    "NGA (Nigeria)",
    "NIC (Nicaragua)",
    "NLD (Netherlands, The)",
    "NOR (Norway)",
    "NPL (Nepal)",
    "NRU (Nauru)",
    "NZL (New Zealand)",
    "OMN (Oman)",
    "PAK (Pakistan)",
    "PAN (Panama)",
    "PER (Peru)",
    "PHL (Philippines)",
    "PLW (Republic of Palau)",
    "PNG (Papua New Guinea)",
    "POL (Poland)",
    "PRK (Korea, North (DPRK))",
    "PRT (Portugal)",
    "PRY (Paraguay)",
    "PSE (Palestinian Authority)",
    "QAT (Qatar)",
    "RKS (Kosovo)",
    "ROU (Romania)",
    "RUS (Russia)",
    "RWA (Rwanda)",
    "SAU (Saudi Arabia)",
    "SDN (Sudan)",
    "SEN (Senegal)",
    "SGP (Singapore)",
    "SHN (Saint Helena)",
    "SLB (Solomon Islands)",
    "SLE (Sierra Leone)",
    "SLV (El Salvador)",
    "SMR (San Marino)",
    "SOM (Somalia)",
    "SRB (Serbia, Republic Of)",
    "SSD (South Sudan)",
    "STP (Sao Tome and Principe)",
    "SUR (Suriname)",
    "SVK (Slovakia)",
    "SVN (Slovenia)",
    "SWE (Sweden)",
    "SWZ (Swaziland)",
    "SYC (Seychelles)",
    "SYR (Syria)",
    "TCA (Turks and Caicos Islands)",
    "TCD (Chad)",
    "TGO (Togo)",
    "THA (Thailand)",
    "TJK (Tajikistan)",
    "TKM (Turkmenistan)",
    "TLS (East Timor)",
    "TON (Tonga)",
    "TTO (Trinidad and Tobago)",
    "TUN (Tunisia)",
    "TUR (Turkey)",
    "TUV (Tuvalu)",
    "TWN (Taiwan)",
    "TZA (Tanzania)",
    "UGA (Uganda)",
    "UKR (Ukraine)",
    "UNA (UN specialized agency)",
    "UNO (UN or official)",
    "URY (Uruguay)",
    "USA (United States of America)",
    "UZB (Uzbekistan)",
    "VAT (Vatican City State)",
    "VCT (St. Vincent and the Grenadines)",
    "VEN (Venezuela)",
    "VGB (British Virgin Islands)",
    "VNM (Vietnam)",
    "VUT (Vanuatu)",
    "WSM (Samoa)",
    "YEM (Yemen)",
    "ZAF (South Africa, Republic Of)",
    "ZMB (Zambia)",
    "ZWE (Zimbabwe)",
]

native_language = [
    "Ada",
    "Adama",
    "Afar",
    "Afghan",
    "Afrikaans",
    "Agbor",
    "Aka",
    "Akan",
    "Akim",
    "Aklanon",
    "Akra",
    "Akwapim",
    "Albanian",
    "Albanian, Greece",
    "Albanian, Italy",
    "American Sign Lang.",
    "Amharic",
    "Arabic",
    "Arabic Standard",
    "Arabic, Algeria",
    "Arabic, Chad",
    "Arabic, Egypt",
    "Arabic, Irak",
    "Arabic, Lebanon, Levantine",
    "Arabic, Libya",
    "Arabic, Morocco",
    "Arabic, Sudan",
    "Arabic, Syria",
    "Arabic, Tunisia",
    "Arabic, Yemen, Judeo-Yemeni",
    "Aranese",
    "Armenian",
    "Armenian, West",
    "Armenian, Western",
    "Ashanti",
    "Assyrian",
    "Atwot",
    "Azerbaijani, North",
    "Azerbaijani, South",
    "Azeri",
    "Bajuni",
    "Balochi East Pak",
    "Balochi South Pak",
    "Balochi West Pak",
    "Baluchi",
    "Bambara",
    "Bamileke",
    "Bantu",
    "Baoule",
    "Barawa",
    "Barbawa",
    "Bassa",
    "Belarusian",
    "Belen",
    "Bemba",
    "Bengali",
    "Bengali Sylhetti",
    "Beni",
    "Benin",
    "Berber",
    "Bikol",
    "Bini",
    "Bissa",
    "Boguni",
    "Bontok",
    "Bosnian",
    "Brava",
    "Breton",
    "British Sign Language",
    "Brong",
    "Buganda",
    "Bulgarian",
    "Burmese",
    "Busan",
    "Cambodian",
    "Cantonese",
    "Capizeno",
    "Catalan",
    "Cebuano",
    "Chadian Sign Language",
    "Chakma",
    "Chaldean",
    "Changle",
    "Chaocho",
    "Chavacano",
    "Chechen",
    "Chichewa",
    "Chinese",
    "Chinese, Min Nan",
    "Chinese, Yue",
    "Chinese, Yuh",
    "Chowchau",
    "Chung Shan",
    "Comorian",
    "Concani",
    "Creole",
    "Creole, Haiti",
    "Croatian",
    "Czech",
    "Dangbe",
    "Danish",
    "Dari",
    "Dari, Peve",
    "Dari/Farsi, Eastern",
    "Deaf-mute",
    "Dendi",
    "Dhopadhola",
    "Diakanke",
    "Dinka, Northeastern",
    "Dinka, Northwestern",
    "Dinka, South Central",
    "Dinka, Southern",
    "Dinka, Southwestern, Twi, Tuic",
    "Dioula",
    "Divehi",
    "Divehi, Maldivian",
    "Dogri",
    "Dutch",
    "Eastern Armenian",
    "Edo",
    "Edo, Kailo, Ledo",
    "Efik",
    "English",
    "Enping",
    "Eritrean",
    "Esan",
    "Estonian",
    "Ewe",
    "Facilitator/Articulator",
    "Fang",
    "Fanti",
    "Farsi",
    "Farsi, Western",
    "Fiji",
    "Findhi",
    "Finnish",
    "Flemish",
    "Fon",
    "Foochow",
    "Foullah",
    "Frafra",
    "Frafra, Gurenne",
    "French",
    "Fujian",
    "Fukien",
    "Fulani",
    "Fuqing",
    "Futa",
    "Ga",
    "Ga, Adangme-Krobo",
    "Gaelic",
    "Georgian",
    "German",
    "Gio",
    "Gio, Gio-Dan",
    "Greek",
    "Guerze",
    "Gujarati",
    "Gurage",
    "Gurage, East",
    "Gurage, North",
    "Gurage, West",
    "Guyanese",
    "Guyroti",
    "Gypsy",
    "Hadiyya",
    "Hainanese",
    "Hakka",
    "Harara",
    "Harary",
    "Hargar",
    "Hasanya",
    "Hausa",
    "Hebrew",
    "Hebrew, Yemen",
    "Henan/Jinyu",
    "Hiligaynon",
    "Hindi",
    "Hindi Dogri",
    "Hindi, Fijian",
    "Hindi, Hin, Nyaheun",
    "Hindko",
    "Hindko, Northern",
    "Hindko, Southern",
    "Hindu, Hindi, Caribbean",
    "Hokkien",
    "Hubei",
    "Huizhou/Yanzhou",
    "Hunan/Xiang",
    "Hungarian",
    "Ibibio",
    "Icelandic",
    "Igbo",
    "Igorot",
    "Iiongo",
    "Ika",
    "Ilican",
    "Ilocano",
    "Indonesian",
    "Interp. Not Required",
    "Ishen",
    "Isoko",
    "Italian",
    "Itshekiri",
    "Izi",
    "Jadgali, Pakistan",
    "Jamaican",
    "Japanese",
    "Javanese",
    "Jianxi",
    "Jolay",
    "Kabyle",
    "Kacchi",
    "Kaiping",
    "Kakwa",
    "Kandahari",
    "Kangri, India",
    "Kangri, Kanjari",
    "Kankani",
    "Kannada",
    "Kaonde, Dari",
    "Kashmiri",
    "Kazakh",
    "Kepelle",
    "Khmer",
    "Kiboma",
    "Kihavu",
    "Kikongo",
    "Kikuyu",
    "Kikuyu, Gikuyu",
    "Kinaraya",
    "Kinyarwanda",
    "Kinyarwanda, Rwanda",
    "Kirundi",
    "Kirundi, Rundi",
    "Kiswahili",
    "Konkani",
    "Korean",
    "Krio",
    "Krobo",
    "Kru, Klao",
    "Kru, Krumen, Tepo",
    "Kurdish",
    "Kurdish Bandinani, Behdini",
    "Kurdish-Central, Kurdi, Sorani",
    "Kurdish-Northern, Kurmanji,",
    "Kwale, Nigeria",
    "Kwale, Papua",
    "Laotian",
    "Lateh",
    "Latvian",
    "Lebanese",
    "Lengie",
    "Limba",
    "Lingala",
    "Linyawanda",
    "Lithuanian",
    "Lowma",
    "Luba-Kasai",
    "Luganda",
    "Lugisu",
    "Luo",
    "Lutoro",
    "Macedonian",
    "Macena",
    "Maghreb",
    "Mahou",
    "Makonde",
    "Makua",
    "Malagasy",
    "Malay",
    "Malayalam",
    "Malgache, Malagasy",
    "Maligo",
    "Malinke, Jula",
    "Maltese",
    "Mandarin",
    "Mandiga, Mandinga",
    "Mandingo",
    "Mandingo, Maninka",
    "Mandingo, Manya",
    "Maninka",
    "Mano",
    "Marakha",
    "Marathi",
    "Masaba",
    "Mashi",
    "Maymay, Somalia",
    "Mende",
    "Meru",
    "Mina",
    "Mina, Gen-Gbe",
    "Mirpuri",
    "Mizo",
    "Moldovan",
    "Moldovan, Romanian",
    "Mongolian",
    "Mongolian, Halh",
    "Moor, Bimoba",
    "Moore",
    "Moore, Burkina",
    "Moore, Waropen",
    "Morisyen",
    "Nahuatl, Classical",
    "Navajo",
    "Ndebele",
    "Ndebele, South Africa",
    "Ndebele, Zimbabwe",
    "Ndjamena",
    "Nepali",
    "Nigerian, Pidgin",
    "Nigerien",
    "Nobiin",
    "Norwegian",
    "Nuer",
    "Nyanja",
    "Nzema",
    "Okpe",
    "Ora",
    "Oriya",
    "Oromo",
    "Oromo, Borana-Arsi-Gujii",
    "Oromo, Qotu",
    "Oromo, Qotu, West Central",
    "Osal",
    "Other",
    "Ouighour",
    "Pahari",
    "Pampango",
    "Pangasinan",
    "Pashto",
    "Pashto, Central",
    "Pashto, Southern",
    "Persian",
    "Peul",
    "Peul, Benin-Togo",
    "Peul, Bororro",
    "Peul, Fulfulde, Adamawa",
    "Peul, Fulfulde, Jelgoore",
    "Phuockien",
    "Pidgin",
    "Pidgin English",
    "Piugon",
    "Polish",
    "Portuguese",
    "Portuguese, Angola",
    "Portuguese, Brazil",
    "Portuguese, Guinea-Bissau",
    "Poular",
    "Punjabi",
    "Pushta",
    "Pushta, Pushto",
    "Pu-Xian",
    "Quechua",
    "Rindre",
    "Rohingya",
    "Romani, Campathian",
    "Romani, Carpathian",
    "Romani, Cigaly",
    "Romani, Cigany",
    "Romani, Vlach",
    "Romani, Vlach, Gypsy",
    "Romanian",
    "Ronga",
    "Rukiga",
    "Runyankole",
    "Russian",
    "Samoan",
    "Samoli",
    "Sango",
    "Santi",
    "Sarahuley",
    "Saraiki",
    "Scoula",
    "Sechuan",
    "Sefwi",
    "Serbian",
    "Serbo-Croatian",
    "Sesotho",
    "Seswi",
    "Setswana",
    "Seychelles",
    "Seychelles,Creole Fre.,Seselwa",
    "Shai",
    "Shan",
    "Shan Dong",
    "Shan Tao",
    "Shanghainese",
    "Shansai",
    "Shanxi",
    "Shona",
    "Sichuan/Szechuan",
    "Sign Language French",
    "Sindhi",
    "Sinhala",
    "Siyap",
    "Slovak",
    "Slovenian",
    "Somali",
    "Somba",
    "Soninke",
    "Soninke, Marakha",
    "Sotho",
    "Sotho, Northern",
    "Sotho, Southern",
    "Spanish",
    "Suesue",
    "Sukuma",
    "Susu",
    "Swahili",
    "Swahili/Congo",
    "Swahili/Kenya",
    "Swati",
    "Swatow",
    "Swedish",
    "Tagalog",
    "Taichew",
    "Taishanese",
    "Taiwanese",
    "Tajiki",
    "Tamil",
    "Tari",
    "Tatar",
    "Tatshanese",
    "Telugu",
    "Temne",
    "Teochew",
    "Thai",
    "Tibetan",
    "Tichiew",
    "Tigre",
    "Tigrea, Tigre",
    "Tigrinya",
    "Timini",
    "Tiv",
    "Tooro",
    "Tshiluba",
    "Turkish",
    "Turkmen",
    "Turkoman",
    "Twi",
    "Uhrobo",
    "Uigrigma",
    "Ukrainian",
    "Ukwuani, Ukwuani-Aboh",
    "Umbundu",
    "Unama",
    "Urdu",
    "Uzbek",
    "Vietnamese",
    "Visayan",
    "Waray-Waray",
    "Welsh",
    "Wenzhou",
    "Wolof",
    "Xangawe",
    "Xhosa",
    "Xin Hui",
    "Xitswa",
    "Xitswa, Twsa",
    "Yacooba",
    "Yao",
    "Yemenite",
    "Yiboe",
    "Yiddish",
    "Yinping",
    "Yoruba",
    "Yue Yang",
    "Yugoslavian",
    "Zaza",
    "Zaza, Kirmanjki",
    "Zshiluba",
    "Zuganda",
    "Zulu",
]

telephone_type = ["Residence", "Cellular", "Business"]

work_permit = [
    "Exemption from labour Market Impact Assessment",
    "Labour Market Impact Assessment Stream",
    "Open Work Permit",
    "Other",
    "Seasonal Agricultural Workers Program",
    "Start-up Business Class",
]

work_permit_ex = [
    "Co-op Work Permit",
    "Exemption from labour Market Impact Assessment",
    "Labour Market Impact Assessment Stream",
    "Live-in Caregiver Program",
    "Open Work Permit",
    "Open Work Permit for Vulnerable Workers",
    "Other",
    "Post Graduation Work Permit",
    "Start-up Business Class",
]

work_permit_student = [
    "Co-op Work Permit",
    "Open Work Permit",
    "Post Graduation Work Permit",
]

canada_province_cities = {
    "AB": [
        "ABEE",
        "ACADIA VALLEY",
        "ACHESON",
        "ACME",
        "ADEN",
        "AETNA",
        "AIRDRIE",
        "ALBERTA BEACH",
        "ALCOMDALE",
        "ALDER FLATS",
        "ALDERSYDE",
        "ALHAMBRA",
        "ALIX",
        "ALLIANCE",
        "ALSIKE",
        "ALTARIO",
        "AMISK",
        "ANDREW",
        "ANZAC",
        "ARDMORE",
        "ARDROSSAN",
        "ARMENA",
        "ARROWWOOD",
        "ASHMONT",
        "ATHABASCA",
        "ATIKAMEG",
        "ATMORE",
        "BALZAC",
        "BANFF",
        "BARNWELL",
        "BARONS",
        "BARRHEAD",
        "BASHAW",
        "BASSANO",
        "BAWLF",
        "BAY TREE",
        "BEAR CANYON",
        "BEAUMONT",
        "BEAUVALLON",
        "BEAVERLODGE",
        "BEISEKER",
        "BELLEVUE",
        "BELLIS",
        "BENALTO",
        "BENTLEY",
        "BERWYN",
        "BEZANSON",
        "BIG STONE",
        "BIG VALLEY",
        "BINDLOSS",
        "BIRCHCLIFF",
        "BITTERN LAKE",
        "BLACK DIAMOND",
        "BLACKFALDS",
        "BLACKFOOT",
        "BLACKIE",
        "BLAIRMORE",
        "BLOOMSBURY",
        "BLUE RIDGE",
        "BLUEBERRY MOUNTAIN",
        "BLUESKY",
        "BLUFFTON",
        "BODO",
        "BON ACCORD",
        "BONANZA",
        "BONNYVILLE",
        "BOTHA",
        "BOW ISLAND",
        "BOWDEN",
        "BOYLE",
        "BOYNE LAKE",
        "BRAGG CREEK",
        "BRANT",
        "BRETON",
        "BREYNAT",
        "BROCKET",
        "BROOKS",
        "BROSSEAU",
        "BROWNFIELD",
        "BROWNVALE",
        "BRUCE",
        "BRUDERHEIM",
        "BRULE",
        "BUCK CREEK",
        "BUCK LAKE",
        "BUFFALO HEAD PRAIRIE",
        "BUFFALO",
        "BURDETT",
        "BUSBY",
        "BYEMOOR",
        "CADOGAN",
        "CADOMIN",
        "CADOTTE LAKE",
        "CALAHOO",
        "CALAIS",
        "CALGARY",
        "CALLING LAKE",
        "CALMAR",
        "CAMP CREEK",
        "CAMROSE",
        "CANMORE",
        "CANYON CREEK",
        "CARBON",
        "CARCAJOU",
        "CARDSTON",
        "CARMANGAY",
        "CARNWOOD",
        "CAROLINE",
        "CARROT CREEK",
        "CARSELAND",
        "CARSTAIRS",
        "CARVEL",
        "CASLAN",
        "CASTOR",
        "CAYLEY",
        "CEREAL",
        "CESSFORD",
        "CHAMPION",
        "CHARD",
        "CHATEH",
        "CHAUVIN",
        "CHERHILL",
        "CHERRY GROVE",
        "CHERRY POINT",
        "CHESTERMERE",
        "CHINOOK",
        "CHIPMAN",
        "CHISHOLM MILLS",
        "CLAIRMONT",
        "CLANDONALD",
        "CLARESHOLM",
        "CLEARDALE",
        "CLIVE",
        "CLUNY",
        "CLYDE",
        "COALDALE",
        "COALHURST",
        "COCHRANE",
        "COLD LAKE",
        "COLEMAN",
        "COLINTON",
        "COLLEGE HEIGHTS",
        "COMPEER",
        "CONDOR",
        "CONKLIN",
        "CONSORT",
        "COOKING LAKE",
        "CORONATION",
        "COUNTY OF GRANDE PRAIRIE NO. 1",
        "COUTTS",
        "COWLEY",
        "CRAIGMYLE",
        "CRANFORD",
        "CREMONA",
        "CROOKED CREEK",
        "CROSSFIELD",
        "CYNTHIA",
        "CYPRESS COUNTY",
        "CZAR",
        "DALEMEAD",
        "DAPP",
        "DARWELL",
        "DAYSLAND",
        "DE WINTON",
        "DEAD MAN'S FLATS",
        "DEADWOOD",
        "DEBOLT",
        "DEL BONITA",
        "DELACOUR",
        "DELBURNE",
        "DELIA",
        "DEMMITT",
        "DENWOOD",
        "DERWENT",
        "DESERT BLUME",
        "DEVON",
        "DEWBERRY",
        "DIAMOND CITY",
        "DIDSBURY",
        "DIXONVILLE",
        "DONALDA",
        "DONNELLY",
        "DOROTHY",
        "DRAYTON VALLEY",
        "DRIFTPILE",
        "DRUMHELLER",
        "DUCHESS",
        "DUFFIELD",
        "DUNMORE",
        "EAGLESHAM",
        "EAST COULEE",
        "ECKVILLE",
        "EDBERG",
        "EDGERTON",
        "EDMONTON",
        "EDSON",
        "EGREMONT",
        "ELK POINT",
        "ELKWATER",
        "ELLSCOTT",
        "ELMWORTH",
        "ELNORA",
        "EMPRESS",
        "ENCHANT",
        "ENDIANG",
        "ENILDA",
        "ENOCH",
        "ENTWISTLE",
        "ERSKINE",
        "ESTHER",
        "ETZIKOM",
        "EUREKA RIVER",
        "EVANSBURG",
        "EXSHAW",
        "FAIRVIEW",
        "FALHER",
        "FALLIS",
        "FALUN",
        "FAUST",
        "FAWCETT",
        "FENN",
        "FERINTOSH",
        "FINNEGAN",
        "FITZGERALD",
        "FLATBUSH",
        "FOISY",
        "FOREMOST",
        "FORESTBURG",
        "FORT ASSINIBOINE",
        "FORT CHIPEWYAN",
        "FORT KENT",
        "FORT MACKAY",
        "FORT MACLEOD",
        "FORT MCMURRAY",
        "FORT SASKATCHEWAN",
        "FORT VERMILION",
        "FOX CREEK",
        "FOX LAKE",
        "FROG LAKE",
        "GADSBY",
        "GAINFORD",
        "GALAHAD",
        "GARDEN RIVER",
        "GEM",
        "GIBBONS",
        "GIFT LAKE",
        "GIROUXVILLE",
        "GLEICHEN",
        "GLENDON",
        "GLENEVIS",
        "GLENWOOD",
        "GOODFARE",
        "GOODFISH LAKE",
        "GOODRIDGE",
        "GORDONDALE",
        "GRANDE CACHE",
        "GRANDE PRAIRIE",
        "GRANUM",
        "GRASSLAND",
        "GRASSY LAKE",
        "GRIMSHAW",
        "GROUARD",
        "GROVEDALE",
        "GUNDY",
        "GUNN",
        "GUY",
        "GWYNNE",
        "HAIRY HILL",
        "HALFMOON BAY",
        "HALKIRK",
        "HANNA",
        "HARDISTY",
        "HARVIE HEIGHTS",
        "HAY LAKES",
        "HAYS",
        "HAYTER",
        "HEINSBURG",
        "HEISLER",
        "HIGH LEVEL",
        "HIGH PRAIRIE",
        "HIGH RIVER",
        "HILDA",
        "HILL SPRING",
        "HILLCREST MINES",
        "HILLIARD",
        "HINES CREEK",
        "HINTON",
        "HOBBEMA",
        "HOLDEN",
        "HONDO",
        "HOTCHKISS",
        "HUGHENDEN",
        "HUSSAR",
        "HUXLEY",
        "HYLO",
        "HYTHE",
        "IDDESLEIGH",
        "INDUS",
        "INNISFAIL",
        "INNISFREE",
        "IRMA",
        "IRON RIVER",
        "IRON SPRINGS",
        "IRRICANA",
        "IRVINE",
        "ISLAND LAKE SOUTH",
        "ISLAND LAKE",
        "ISLAY",
        "JAMES RIVER BRIDGE",
        "JARVIE",
        "JARVIS BAY",
        "JASPER",
        "JEAN COTE",
        "JENNER",
        "JOHN D'OR PRAIRIE",
        "JOUSSARD",
        "KANANASKIS",
        "KAPASIWIN",
        "KATHYRN",
        "KEG RIVER",
        "KEHEWIN",
        "KELSEY",
        "KEOMA",
        "KIKINO",
        "KILLAM",
        "KINGMAN",
        "KINSELLA",
        "KINUSO",
        "KIRRIEMUIR",
        "KITSCOTY",
        "LA COREY",
        "LA CRETE",
        "LA GLACE",
        "LAC DES ARCS",
        "LAC LA BICHE",
        "LACOMBE COUNTY",
        "LACOMBE",
        "LAFOND",
        "LAKE ISLE",
        "LAKE LOUISE",
        "LAMONT",
        "LANCASTER PARK",
        "LANGDON",
        "LAVOY",
        "LEDUC COUNTY",
        "LEDUC",
        "LEGAL",
        "LESLIEVILLE",
        "LETHBRIDGE",
        "LINDALE",
        "LINDBERGH",
        "LINDEN",
        "LITTLE SMOKY",
        "LLOYDMINSTER",
        "LODGEPOLE",
        "LOMOND",
        "LONE PINE",
        "LONGVIEW",
        "LOUGHEED",
        "LOUSANA",
        "LUNDBRECK",
        "LYALTA",
        "MA-ME-O BEACH",
        "MADDEN",
        "MAGRATH",
        "MALEB",
        "MALLAIG",
        "MANNING",
        "MANNVILLE",
        "MANYBERRIES",
        "MARIE REINE",
        "MARKERVILLE",
        "MARWAYNE",
        "MAYERTHORPE",
        "MCLAUGHLIN",
        "MCLENNAN",
        "MCRAE",
        "MEANDER RIVER",
        "MEDICINE HAT",
        "MEETING CREEK",
        "METISKOW",
        "MILK RIVER",
        "MILLARVILLE",
        "MILLET",
        "MILLICENT",
        "MILO",
        "MINBURN",
        "MIRROR",
        "MONARCH",
        "MONITOR",
        "MORINVILLE",
        "MORLEY",
        "MORRIN",
        "MOSSLEIGH",
        "MOUNTAIN VIEW",
        "MULHURST BAY",
        "MUNDARE",
        "MUNSON",
        "MUSIDORA",
        "MYRNAM",
        "NACMINE",
        "NAMAO",
        "NAMPA",
        "NANTON",
        "NEERLANDIA",
        "NESTOW",
        "NEVIS",
        "NEW BRIGDEN",
        "NEW DAYTON",
        "NEW NORWAY",
        "NEWBROOK",
        "NISKU",
        "NITON JUNCTION",
        "NOBLEFORD",
        "NORDEGG",
        "NORGLENWOLD",
        "NORTH STAR",
        "NOTIKEWIN",
        "OHATON",
        "OKOTOKS",
        "OLDS",
        "ONEFOUR",
        "ONOWAY",
        "OPAL",
        "ORION",
        "OYEN",
        "PADDLE PRAIRIE",
        "PARADISE VALLEY",
        "PARKLAND",
        "PATRICIA",
        "PEACE RIVER",
        "PEERLESS LAKE",
        "PEERS",
        "PENHOLD",
        "PERRYVALE",
        "PICKARDVILLE",
        "PICTURE BUTTE",
        "PINCHER CREEK",
        "PINE LAKE",
        "PLAMONDON",
        "POLLOCKVILLE",
        "PONOKA",
        "PRIDDIS",
        "PROVOST",
        "PURPLE SPRINGS",
        "RADWAY",
        "RAINBOW LAKE",
        "RAINIER",
        "RALSTON",
        "RANFURLY",
        "RAYMOND",
        "RED DEER COUNTY",
        "RED DEER",
        "RED EARTH CREEK",
        "RED WILLOW",
        "REDCLIFF",
        "REDWATER",
        "REDWOOD MEADOWS",
        "RIMBEY",
        "RIVERCOURSE",
        "RIVIERE QUI BARRE",
        "ROBB",
        "ROCHESTER",
        "ROCHFORT BRIDGE",
        "ROCHON SANDS",
        "ROCKY MOUNTAIN HOUSE",
        "ROCKY RAPIDS",
        "ROCKY VIEW",
        "ROCKYFORD",
        "ROLLING HILLS",
        "ROLLY VIEW",
        "ROSALIND",
        "ROSEBUD",
        "ROSEDALE STATION",
        "ROSEDALE VALLEY",
        "ROSEMARY",
        "ROUND HILL",
        "ROWLEY",
        "RUMSEY",
        "RYCROFT",
        "RYLEY",
        "SADDLE LAKE",
        "SANGUDO",
        "SCANDIA",
        "SCHULER",
        "SEBA BEACH",
        "SEDALIA",
        "SEDGEWICK",
        "SEVEN PERSONS",
        "SEXSMITH",
        "SHAUGHNESSY",
        "SHERWOOD PARK",
        "SIBBALD",
        "SIKSIKA",
        "SILVER VALLEY",
        "SKIFF",
        "SLAVE LAKE",
        "SMITH",
        "SMOKY LAKE",
        "SOUTH BAPTISTE",
        "SPEDDEN",
        "SPIRIT RIVER",
        "SPRING COULEE",
        "SPRING LAKE",
        "SPRINGBROOK",
        "SPRUCE GROVE",
        "SPRUCE VIEW",
        "SPUTINOW",
        "ST BRIDES",
        "ST ISIDORE",
        "ST LINA",
        "ST MICHAEL",
        "ST PAUL",
        "ST VINCENT",
        "ST. ALBERT",
        "STAND OFF",
        "STANDARD",
        "STAR",
        "STAUFFER",
        "STAVELY",
        "STETTLER",
        "STIRLING",
        "STONY PLAIN",
        "STRATHMORE",
        "STREAMSTOWN",
        "STROME",
        "STURGEON COUNTY",
        "SUNDRE",
        "SUNNYBROOK",
        "SUNNYNOOK",
        "SUNSET BEACH",
        "SUNSET HOUSE",
        "SWALWELL",
        "SWAN HILLS",
        "SYLVAN LAKE",
        "TABER",
        "TANGENT",
        "TAWATINAW",
        "TEES",
        "THORHILD",
        "THORSBY",
        "THREE HILLS",
        "TIGER LILY",
        "TILLEY",
        "TOFIELD",
        "TOMAHAWK",
        "TORRINGTON",
        "TROCHU",
        "TROUT LAKE",
        "TSUU T'INA",
        "TULLIBY LAKE",
        "TURIN",
        "TURNER VALLEY",
        "TWIN BUTTE",
        "TWO HILLS",
        "VALHALLA CENTRE",
        "VALLEYVIEW",
        "VAUXHALL",
        "VEGA",
        "VEGREVILLE",
        "VERMILION",
        "VETERAN",
        "VIKING",
        "VILNA",
        "VIMY",
        "VULCAN",
        "WABAMUN",
        "WABASCA",
        "WAINWRIGHT",
        "WALSH",
        "WANDERING RIVER",
        "WANHAM",
        "WARBURG",
        "WARDLOW",
        "WARNER",
        "WARSPITE",
        "WASKATENAU",
        "WATER VALLEY",
        "WATERTON PARK",
        "WATINO",
        "WELLING",
        "WEMBLEY",
        "WEST BAPTISTE",
        "WESTEROSE",
        "WESTLOCK",
        "WETASKIWIN",
        "WHISPERING HILLS",
        "WHITE GULL",
        "WHITECOURT",
        "WHITELAW",
        "WIDEWATER",
        "WILDWOOD",
        "WILLINGDON",
        "WIMBORNE",
        "WINFIELD",
        "WOKING",
        "WORSLEY",
        "WOSTOK",
        "WRENTHAM",
        "YOUNGSTOWN",
        "ZAMA CITY",
    ],
    "BC": [
        "100 MILE HOUSE",
        "108 MILE RANCH",
        "150 MILE HOUSE",
        "70 MILE HOUSE",
        "ABBOTSFORD",
        "AGASSIZ",
        "AHOUSAT",
        "AINSWORTH HOT SPRINGS",
        "AIYANSH",
        "ALDERGROVE",
        "ALERT BAY",
        "ALEXIS CREEK",
        "ALKALI LAKE",
        "ALTONA",
        "ANAHIM LAKE",
        "ANGLEMONT",
        "ANMORE",
        "ARGENTA",
        "ARMSTRONG",
        "ARRAS",
        "ASHCROFT",
        "ATHALMER",
        "ATLIN",
        "AVOLA",
        "BALDONNEL",
        "BALFOUR",
        "BAMFIELD",
        "BARKERVILLE",
        "BARRIERE",
        "BEAR LAKE",
        "BEAVERDELL",
        "BELCARRA",
        "BELLA BELLA",
        "BELLA COOLA",
        "BIG LAKE RANCH",
        "BLACK CREEK",
        "BLIND BAY",
        "BLIND CHANNEL",
        "BLUBBER BAY",
        "BLUE RIVER",
        "BOSTON BAR",
        "BOSWELL",
        "BOWEN ISLAND",
        "BOWSER",
        "BRACKENDALE",
        "BRENTWOOD BAY",
        "BRIDESVILLE",
        "BRIDGE LAKE",
        "BRISCO",
        "BRITANNIA BEACH",
        "BUFFALO CREEK",
        "BUICK",
        "BURNABY",
        "BURNS LAKE",
        "BURTON",
        "CACHE CREEK",
        "CAMPBELL RIVER",
        "CANAL FLATS",
        "CANIM LAKE",
        "CANOE",
        "CANYON",
        "CASSIDY",
        "CASTLEGAR",
        "CAWSTON",
        "CECIL LAKE",
        "CEDARVALE",
        "CELISTA",
        "CHARLIE LAKE",
        "CHASE",
        "CHEMAINUS",
        "CHERRYVILLE",
        "CHETWYND",
        "CHILANKO FORKS",
        "CHILLIWACK",
        "CHRISTINA LAKE",
        "CLAYHURST",
        "CLEARWATER",
        "CLINTON",
        "COAL HARBOUR",
        "COALMONT",
        "COBBLE HILL",
        "COLDSTREAM",
        "COMOX",
        "COOMBS",
        "COQUITLAM",
        "COURTENAY",
        "COWICHAN BAY",
        "CRANBROOK",
        "CRAWFORD BAY",
        "CRESCENT SPUR",
        "CRESCENT VALLEY",
        "CRESTON",
        "CROFTON",
        "CULTUS LAKE",
        "CUMBERLAND",
        "D'ARCY",
        "DARFIELD",
        "DAWSON CREEK",
        "DAWSONS LANDING",
        "DEASE LAKE",
        "DELTA",
        "DENMAN ISLAND",
        "DENNY ISLAND",
        "DEROCHE",
        "DEWDNEY",
        "DOG CREEK",
        "DOME CREEK",
        "DOUGLAS LAKE",
        "DUNCAN",
        "DUNSTER",
        "EAGLE BAY",
        "EAGLE CREEK",
        "EDGEWATER",
        "EDGEWOOD",
        "EGMONT",
        "ELKFORD",
        "ELKO",
        "ENDAKO",
        "ENDERBY",
        "ERICKSON",
        "ERRINGTON",
        "ESQUIMALT",
        "FAIRMONT HOT SPRINGS",
        "FALKLAND",
        "FANNY BAY",
        "FARMINGTON",
        "FAUQUIER",
        "FERNIE",
        "FIELD",
        "FOREST GROVE",
        "FORT FRASER",
        "FORT NELSON",
        "FORT ST. JAMES",
        "FORT ST. JOHN",
        "FORT STEELE",
        "FRANCOIS LAKE",
        "FRASER LAKE",
        "FRUITVALE",
        "FURRY CREEK",
        "GABRIOLA",
        "GALIANO",
        "GALLOWAY",
        "GANG RANCH",
        "GARDEN BAY",
        "GARIBALDI HIGHLANDS",
        "GENELLE",
        "GERMANSEN LANDING",
        "GIBSONS",
        "GILLIES BAY",
        "GITWINKSIHLKW",
        "GOLD BRIDGE",
        "GOLD RIVER",
        "GOLDEN",
        "GOOD HOPE LAKE",
        "GOODLOW",
        "GRAND FORKS",
        "GRANISLE",
        "GRASMERE",
        "GRAY CREEK",
        "GREENVILLE",
        "GREENWOOD",
        "GRINDROD",
        "GROUNDBIRCH",
        "HAGENSBORG",
        "HAISLA",
        "HALFMOON BAY",
        "HANCEVILLE",
        "HARRISON HOT SPRINGS",
        "HARRISON MILLS",
        "HARROGATE",
        "HARTLEY BAY",
        "HAZELTON",
        "HEDLEY",
        "HEFFLEY CREEK",
        "HERIOT BAY",
        "HIXON",
        "HOLBERG",
        "HONEYMOON BAY",
        "HOPE",
        "HORNBY ISLAND",
        "HORSEFLY",
        "HOUSTON",
        "HUDSON'S HOPE",
        "INVERMERE",
        "ISKUT",
        "JADE CITY",
        "JAFFRAY",
        "JORDAN RIVER",
        "JUSKATLA",
        "KALEDEN",
        "KAMLOOPS",
        "KASLO",
        "KELOWNA",
        "KEREMEOS",
        "KILDONAN",
        "KIMBERLEY",
        "KINCOLITH",
        "KINGCOME INLET",
        "KINGSGATE",
        "KITCHENER",
        "KITIMAT",
        "KITKATLA",
        "KITWANGA",
        "KLEENA KLEENE",
        "KLEMTU",
        "KNUTSFORD",
        "KOKSILAH",
        "KOOTENAY BAY",
        "KYUQUOT",
        "LAC LA HACHE",
        "LADYSMITH",
        "LAKE COWICHAN",
        "LAKE ERROCK",
        "LANGLEY",
        "LANTZVILLE",
        "LASQUETI",
        "LAVINGTON",
        "LAX KW'ALAAMS",
        "LAZO",
        "LIKELY",
        "LILLOOET",
        "LINDELL BEACH",
        "LIONS BAY",
        "LISTER",
        "LITTLE FORT",
        "LOGAN LAKE",
        "LONE BUTTE",
        "LONGWORTH",
        "LOUIS CREEK",
        "LOWER NICOLA",
        "LOWER POST",
        "LUMBY",
        "LUND",
        "LYTTON",
        "MACKENZIE",
        "MADEIRA PARK",
        "MALAHAT",
        "MALAKWA",
        "MANNING PARK",
        "MANSON CREEK",
        "MANSONS LANDING",
        "MAPLE RIDGE",
        "MARA",
        "MASSET",
        "MAYNE",
        "MCBRIDE",
        "MCLEESE LAKE",
        "MCLEOD LAKE",
        "MCLURE",
        "MEADOW CREEK",
        "MERRITT",
        "MERVILLE",
        "MESACHIE LAKE",
        "MEZIADIN LAKE",
        "MICA CREEK",
        "MIDWAY",
        "MILL BAY",
        "MILNER",
        "MINSTREL ISLAND",
        "MISSION",
        "MOBERLY LAKE",
        "MONTE CREEK",
        "MONTE LAKE",
        "MONTNEY",
        "MONTROSE",
        "MOUNT CURRIE",
        "MOYIE",
        "MUNCHO LAKE",
        "NAKUSP",
        "NANAIMO",
        "NANOOSE BAY",
        "NARAMATA",
        "NASS CAMP",
        "NELSON",
        "NEMAIAH VALLEY",
        "NEW DENVER",
        "NEW HAZELTON",
        "NEW SONGHEES 1A",
        "NEW WESTMINSTER",
        "NIMPO LAKE",
        "NORTH PINE",
        "NORTH SAANICH",
        "NORTH VANCOUVER",
        "OCEAN FALLS",
        "OKANAGAN CENTRE",
        "OKANAGAN FALLS",
        "OLIVER",
        "OONA RIVER",
        "OSOYOOS",
        "OYAMA",
        "PANORAMA",
        "PARKSVILLE",
        "PARSON",
        "PAVILION",
        "PEACE RIVER RD",
        "PEACHLAND",
        "PEMBERTON",
        "PENDER ISLAND",
        "PENNY",
        "PENTICTON",
        "PINANTAN LAKE",
        "PINK MOUNTAIN",
        "PITT MEADOWS",
        "PORT ALBERNI",
        "PORT ALICE",
        "PORT CLEMENTS",
        "PORT COQUITLAM",
        "PORT EDWARD",
        "PORT HARDY",
        "PORT MCNEILL",
        "PORT MELLON",
        "PORT MOODY",
        "PORT NEVILLE",
        "PORT RENFREW",
        "POUCE COUPE",
        "POWELL RIVER",
        "PRESPATOU",
        "PRINCE GEORGE",
        "PRINCE RUPERT",
        "PRINCETON",
        "PRITCHARD",
        "PROCTER",
        "PROGRESS",
        "PROPHET RIVER",
        "QUALICUM BEACH",
        "QUATHIASKI COVE",
        "QUATSINO",
        "QUEEN CHARLOTTE",
        "QUESNEL",
        "QUILCHENA",
        "RADIUM HOT SPRINGS",
        "REDSTONE",
        "REFUGE COVE",
        "REVELSTOKE",
        "RICHMOND",
        "RIONDEL",
        "RISKE CREEK",
        "ROBERTS CREEK",
        "ROBSON",
        "ROCK CREEK",
        "ROLLA",
        "ROSE PRAIRIE",
        "ROSEDALE",
        "ROSSLAND",
        "ROYSTON",
        "SAANICH",
        "SAANICHTON",
        "SALMO",
        "SALMON ARM",
        "SALT SPRING ISLAND",
        "SANDSPIT",
        "SATURNA",
        "SAVONA",
        "SAYWARD",
        "SCOTCH CREEK",
        "SECHELT",
        "SETON PORTAGE",
        "SHALALTH",
        "SHAWNIGAN LAKE",
        "SHIRLEY",
        "SICAMOUS",
        "SIDNEY",
        "SILVERTON",
        "SIMOOM SOUND",
        "SINCLAIR MILLS",
        "SIRDAR",
        "SKOOKUMCHUCK",
        "SLOCAN PARK",
        "SLOCAN",
        "SMITHERS",
        "SOINTULA",
        "SOOKE",
        "SORRENTO",
        "SOUTH HAZELTON",
        "SOUTH SLOCAN",
        "SOUTHBANK",
        "SPARWOOD",
        "SPENCES BRIDGE",
        "SPILLIMACHEEN",
        "SQUAMISH",
        "SQUIRREL COVE",
        "STEWART",
        "STUART ISLAND",
        "SUMMERLAND",
        "SUMMIT LAKE",
        "SUN PEAKS",
        "SUNSET PRAIRIE",
        "SURGE NARROWS",
        "SURREY",
        "SWANSEA POINT",
        "TA TA CREEK",
        "TAHSIS",
        "TAKLA LANDING",
        "TAPPEN",
        "TATLA LAKE",
        "TATLAYOKO LAKE",
        "TAYLOR",
        "TELEGRAPH COVE",
        "TELEGRAPH CREEK",
        "TELKWA",
        "TERRACE",
        "THETIS ISLAND",
        "THORNHILL",
        "TLELL",
        "TOAD RIVER",
        "TOFINO",
        "TOMSLAKE",
        "TOPLEY",
        "TRAIL",
        "TSAWWASSEN",
        "TSAY KEH DENE",
        "TULAMEEN",
        "TUMBLER RIDGE",
        "UCLUELET",
        "UNION BAY",
        "UPPER FRASER",
        "VALEMOUNT",
        "VAN ANDA",
        "VANCOUVER",
        "VANDERHOOF",
        "VAVENBY",
        "VERNON",
        "VICTORIA",
        "WALHACHIN",
        "WARDNER",
        "WARE",
        "WASA",
        "WELLS",
        "WEST KELOWNA",
        "WEST VANCOUVER",
        "WESTBANK",
        "WESTBRIDGE",
        "WESTHOLME",
        "WESTWOLD",
        "WHALETOWN",
        "WHISTLER",
        "WHITE ROCK",
        "WILLIAMS LAKE",
        "WILLOW RIVER",
        "WINDERMERE",
        "WINFIELD",
        "WINLAW",
        "WINTER HARBOUR",
        "WONOWON",
        "WOSS",
        "WYNNDEL",
        "YAHK",
        "YALE",
        "YMIR",
        "YOUBOU",
        "ZEBALLOS",
    ],
    "MB": [
        "ALEXANDER",
        "ALONSA",
        "ALTAMONT",
        "ALTONA",
        "AMARANTH",
        "ANGUSVILLE",
        "ANOLA",
        "ARBORG",
        "ARDEN",
        "ARGYLE",
        "ARNAUD",
        "ARNES",
        "ARROW RIVER",
        "ASHERN",
        "ASHVILLE",
        "AUBIGNY",
        "AUSTIN",
        "BAGOT",
        "BALDUR",
        "BALMORAL",
        "BARROWS",
        "BEACONIA",
        "BEAUSEJOUR",
        "BELAIR",
        "BELLEVIEW",
        "BELMONT",
        "BENITO",
        "BERENS RIVER",
        "BETHANY",
        "BEULAH",
        "BINSCARTH",
        "BIRCH RIVER",
        "BIRNIE",
        "BIRTLE",
        "BISSETT",
        "BLOODVEIN",
        "BLUMENORT",
        "BOGGY CREEK",
        "BOISSEVAIN",
        "BOWSMAN",
        "BRADWARDINE",
        "BRANDON",
        "BROAD VALLEY",
        "BROCHET",
        "BROOKDALE",
        "BRUNKILD",
        "BRUXELLES",
        "BUFFALO POINT",
        "CAMP MORTON",
        "CAMPERVILLE",
        "CARBERRY",
        "CARDALE",
        "CARLOWRIE",
        "CARMAN",
        "CARROLL",
        "CARTIER",
        "CARTWRIGHT",
        "CAYER",
        "CHANNING",
        "CHATFIELD",
        "CHURCHILL",
        "CLANDEBOYE",
        "CLANWILLIAM",
        "CLEARWATER",
        "CORMORANT",
        "COULTER",
        "COWAN",
        "CRANBERRY PORTAGE",
        "CRANDALL",
        "CRANE RIVER",
        "CROMER",
        "CROSS LAKE",
        "CRYSTAL CITY",
        "CYPRESS RIVER",
        "DACOTAH",
        "DAKOTA TIPI",
        "DALLAS",
        "DARLINGFORD",
        "DAUPHIN",
        "DECKER",
        "DELEAU",
        "DELORAINE",
        "DOMAIN",
        "DOMINION CITY",
        "DOUGLAS",
        "DROPMORE",
        "DUCK BAY",
        "DUFRESNE",
        "DUFROST",
        "DUGALD",
        "DUNREA",
        "DURBAN",
        "EAST BRAINTREE",
        "EAST SELKIRK",
        "EAST ST PAUL",
        "EASTERVILLE",
        "EBB AND FLOW",
        "EDDYSTONE",
        "EDEN",
        "EDWIN",
        "ELGIN",
        "ELIE",
        "ELKHORN",
        "ELM CREEK",
        "ELMA",
        "ELPHINSTONE",
        "EMERSON",
        "ERICKSON",
        "ERIKSDALE",
        "ETHELBERT",
        "FAIRFAX",
        "FAIRFORD",
        "FALCON BEACH",
        "FANNYSTELLE",
        "FAULKNER",
        "FISHER BRANCH",
        "FLIN FLON",
        "FORK RIVER",
        "FORREST STATION",
        "FORT ALEXANDER",
        "FOXWARREN",
        "FRANKLIN",
        "FRASERWOOD",
        "GARDENTON",
        "GARLAND",
        "GARSON",
        "GILBERT PLAINS",
        "GILLAM",
        "GIMLI",
        "GINEW",
        "GIROUX",
        "GLADSTONE",
        "GLENBORO",
        "GLENELLA",
        "GLENLEA",
        "GLENORA",
        "GODS LAKE NARROWS",
        "GODS RIVER",
        "GOODLANDS",
        "GRAHAMDALE",
        "GRAND MARAIS",
        "GRAND RAPIDS",
        "GRANDE POINTE",
        "GRANDVIEW",
        "GRAYSVILLE",
        "GREAT FALLS",
        "GREEN RIDGE",
        "GRETNA",
        "GRISWOLD",
        "GROSSE ISLE",
        "GRUNTHAL",
        "GUNTON",
        "GYPSUMVILLE",
        "HADASHVILLE",
        "HALBSTADT",
        "HAMIOTA",
        "HARDING",
        "HARGRAVE",
        "HARTNEY",
        "HAYWOOD",
        "HAZELRIDGE",
        "HEADINGLEY",
        "HIGH BLUFF",
        "HILBRE",
        "HODGSON",
        "HOLLAND",
        "HOLMFIELD",
        "HOMEWOOD",
        "HORNDEAN",
        "HOWDEN",
        "ILE DES CHENES",
        "ILFORD",
        "INGLIS",
        "INWOOD",
        "ISABELLA",
        "ISLAND LAKE",
        "JUSTICE",
        "KELWOOD",
        "KENTON",
        "KENVILLE",
        "KILLARNEY",
        "KINOSOTA",
        "KIRKELLA",
        "KLEEFELD",
        "KOLA",
        "KOMARNO",
        "KOOSTATAK",
        "LA BARRIERE",
        "LA BROQUERIE",
        "LA RIVIERE",
        "LA SALLE",
        "LAC BROCHET",
        "LAC DU BONNET",
        "LAKE AUDY",
        "LAKE FRANCIS",
        "LAKE MANITOBA FIRST NATION",
        "LAKELAND",
        "LANDMARK",
        "LANGRUTH",
        "LAUDER",
        "LAURIER",
        "LAVENHAM",
        "LEAF RAPIDS",
        "LENORE",
        "LETELLIER",
        "LIBAU",
        "LITTLE BULLHEAD",
        "LITTLE GRAND RAPIDS",
        "LOCKPORT",
        "LORETTE",
        "LOWE FARM",
        "LUNDAR",
        "LYLETON",
        "LYNN LAKE",
        "MACDONALD",
        "MACGREGOR",
        "MAFEKING",
        "MAKINAK",
        "MALONTON",
        "MANIGOTAGAN",
        "MANITOU",
        "MANSON",
        "MARCHAND",
        "MARGARET",
        "MARIAPOLIS",
        "MARIUS",
        "MARQUETTE",
        "MATHER",
        "MATHESON ISLAND",
        "MATLOCK",
        "MCAULEY",
        "MCCREARY",
        "MEADOW PORTAGE",
        "MEDORA",
        "MELEB",
        "MELITA",
        "MENISINO",
        "MENZIE",
        "MIAMI",
        "MIDDLEBRO",
        "MINIOTA",
        "MINITONAS",
        "MINNEDOSA",
        "MINTO",
        "MITCHELL",
        "MOOSE LAKE",
        "MOOSEHORN",
        "MORDEN",
        "MORRIS",
        "MOUNTAIN ROAD",
        "MULVIHILL",
        "NAPINKA",
        "NARCISSE",
        "NEEPAWA",
        "NEGGINAN",
        "NELSON HOUSE",
        "NESBITT",
        "NEW BOTHWELL",
        "NEWDALE",
        "NEWTON SIDING",
        "NINETTE",
        "NINGA",
        "NIVERVILLE",
        "NORWAY HOUSE",
        "NOTRE DAME DE LOURDES",
        "O'HANLY",
        "OAK BLUFF",
        "OAK LAKE",
        "OAK POINT",
        "OAK RIVER",
        "OAKBANK",
        "OAKBURN",
        "OAKVIEW",
        "OAKVILLE",
        "OCHRE RIVER",
        "OLHA",
        "ONANOLE",
        "OPASKWAYAK",
        "OTTERBURNE",
        "OVERSTONEVILLE",
        "OXFORD HOUSE",
        "PANSY",
        "PAUINGASSI",
        "PEGUIS",
        "PELICAN RAPIDS",
        "PETERSFIELD",
        "PIERSON",
        "PIKWITONEI",
        "PILOT MOUND",
        "PINAWA",
        "PINE FALLS",
        "PINE RIVER",
        "PINEY",
        "PIPESTONE",
        "PLUM COULEE",
        "PLUMAS",
        "POINTE DU BOIS",
        "POLONIA",
        "POPLAR POINT",
        "POPLARFIELD",
        "PORTAGE LA PRAIRIE",
        "POWERVIEW",
        "PRATT",
        "PRINCESS HARBOUR",
        "PUKATAWAGAN",
        "RANDOLPH",
        "RAPID CITY",
        "RATHWELL",
        "RED SUCKER LAKE",
        "REINFELD",
        "RENNIE",
        "RENWER",
        "RESTON",
        "RICHER",
        "RIDGEVILLE",
        "RIDING MOUNTAIN",
        "RIVER HILLS",
        "RIVERS",
        "RIVERTON",
        "ROBLIN",
        "ROCK RIDGE",
        "ROLAND",
        "RORKETON",
        "ROSA",
        "ROSEAU RIVER",
        "ROSEISLE",
        "ROSENFELD",
        "ROSENORT",
        "ROSSBURN",
        "ROSSENDALE",
        "ROSSER",
        "RUSSELL",
        "SAN CLARA",
        "SANDILANDS",
        "SANDY HOOK",
        "SANDY LAKE",
        "SANFORD",
        "SARTO",
        "SCANTERBURY",
        "SCHANZENFELD",
        "SEDDONS CORNER",
        "SELKIRK",
        "SEVEN SISTERS FALLS",
        "SHAMATTAWA",
        "SHELLMOUTH",
        "SHERRIDON",
        "SHILO",
        "SHOAL LAKE",
        "SHORTDALE",
        "SIDNEY",
        "SIFTON",
        "SILVER RIDGE",
        "SILVER",
        "SINCLAIR",
        "SKOWNAN",
        "SNOW LAKE",
        "SNOWFLAKE",
        "SOLSGIRTH",
        "SOMERSET",
        "SOURIS",
        "SOUTH INDIAN LAKE",
        "SOUTH JUNCTION",
        "SOUTHPORT",
        "SPERLING",
        "SPLIT LAKE",
        "SPRAGUE",
        "SPRINGFIELD",
        "SPRINGSTEIN",
        "ST ADOLPHE",
        "ST ALPHONSE",
        "ST AMBROISE",
        "ST ANDREWS",
        "ST CLAUDE",
        "ST CLEMENTS",
        "ST EUSTACHE",
        "ST FRANCOIS XAVIER",
        "ST GERMAIN SOUTH",
        "ST JEAN BAPTISTE",
        "ST JOSEPH",
        "ST LAURENT",
        "ST LAZARE",
        "ST LEON",
        "ST MALO",
        "ST MARKS",
        "ST MARTIN",
        "ST PIERRE JOLYS",
        "ST THERESA POINT",
        "ST. GEORGES",
        "STARBUCK",
        "STE AGATHE",
        "STE ANNE",
        "STE ROSE DU LAC",
        "STEAD",
        "STEEP ROCK",
        "STEINBACH",
        "STEPHENFIELD",
        "STEVENSON ISLAND",
        "STOCKTON",
        "STONEWALL",
        "STONY MOUNTAIN",
        "STRATHCLAIR",
        "STUARTBURN",
        "SUNDOWN",
        "SWAN LAKE",
        "SWAN RIVER",
        "TADOULE LAKE",
        "TEULON",
        "THE PAS",
        "THICKET PORTAGE",
        "THOMPSON",
        "THORNHILL",
        "TILSTON",
        "TOLSTOI",
        "TOUROND",
        "TOUTES AIDES",
        "TRAVERSE BAY",
        "TREHERNE",
        "TYNDALL",
        "VALLEY RIVER",
        "VASSAR",
        "VERMETTE",
        "VICTORIA BEACH",
        "VIRDEN",
        "VISTA",
        "VITA",
        "VOGAR",
        "WABOWDEN",
        "WALDERSEE",
        "WANIPIGOW",
        "WANLESS",
        "WARREN",
        "WASAGAMACK",
        "WASAGAMING",
        "WASKADA",
        "WATERHEN",
        "WAWANESA",
        "WAYWAYSEECAPPO",
        "WELLWOOD",
        "WEST ST PAUL",
        "WESTBOURNE",
        "WHITEMOUTH",
        "WHITESHELL",
        "WINKLER",
        "WINNIPEG BEACH",
        "WINNIPEG",
        "WINNIPEGOSIS",
        "WOODLANDS",
        "WOODMORE",
        "WOODRIDGE",
        "WOODSIDE",
        "YORK LANDING",
        "ZHODA",
    ],
    "NB": [
        "ACADIE SIDING",
        "ACADIEVILLE",
        "ADAMS GULCH",
        "ADAMSVILLE",
        "ALBERT MINES",
        "ALBRIGHTS CORNER",
        "ALCIDA",
        "ALDERWOOD",
        "ALDOUANE",
        "ALLAINVILLE",
        "ALLARDVILLE",
        "ALLISON",
        "ALMA",
        "AMMON",
        "ANAGANCE",
        "ANDERSON ROAD",
        "ANDERSON SETTLEMENT",
        "ANDERSONVILLE",
        "ANFIELD",
        "ANSE-BLEUE",
        "APOHAQUI",
        "ARBEAU SETTLEMENT",
        "ARMOND",
        "AROOSTOOK JUNCTION",
        "AROOSTOOK",
        "ARTHURETTE",
        "ASHLAND",
        "ASTLE",
        "ATHOLVILLE",
        "AULAC",
        "AVONDALE",
        "BACK BAY",
        "BAIE DE BOUCTOUCHE",
        "BAIE DE PETIT-POKEMOUCHE",
        "BAIE VERTE",
        "BAIE-SAINTE-ANNE",
        "BAILLIE",
        "BAINS CORNER",
        "BAIRDSVILLE",
        "BAKER BROOK",
        "BALLA PHILIP",
        "BALMORAL EST",
        "BALMORAL SUD",
        "BALMORAL",
        "BALTIMORE",
        "BANNON",
        "BARNABY",
        "BARNESVILLE",
        "BARNETTVILLE",
        "BARONY",
        "BARRYVILLE",
        "BARTER SETTLEMENT",
        "BARTHOLOMEW",
        "BARTIBOG BRIDGE",
        "BARTIBOG",
        "BARTLETTS MILLS",
        "BAS-CAP-PELE",
        "BAS-CARAQUET",
        "BAS-PAQUETVILLE",
        "BASS RIVER",
        "BASSWOOD RIDGE",
        "BATH",
        "BATHURST",
        "BAXTERS CORNER",
        "BAY DU VIN",
        "BAY VIEW",
        "BAYFIELD",
        "BAYSIDE",
        "BAYSWATER",
        "BEACONSFIELD",
        "BEAR ISLAND",
        "BEARDSLEY",
        "BEAVER DAM",
        "BEAVER HARBOUR",
        "BEAVERBROOK ALBERT CO",
        "BEAVERBROOK",
        "BECKIM SETTLEMENT",
        "BEDELL",
        "BEECHWOOD",
        "BEERSVILLE",
        "BELLEDUNE",
        "BELLEFOND",
        "BELLEISLE CREEK",
        "BELLEVILLE",
        "BENJAMIN RIVER",
        "BENOIT",
        "BENTON",
        "BERESFORD",
        "BERRY MILLS",
        "BERRYTON",
        "BERTRAND",
        "BERWICK",
        "BETHEL",
        "BETTSBURG",
        "BIG COVE QUEENS CO",
        "BIG HOLE",
        "BIG RIVER",
        "BIRCH RIDGE",
        "BIRDTON",
        "BLACK POINT",
        "BLACK RIVER BRIDGE",
        "BLACK RIVER",
        "BLACK ROCK",
        "BLACKLAND RESTIGOUCHE CO",
        "BLACKS HARBOUR",
        "BLACKVILLE",
        "BLAIR ATHOL",
        "BLISSFIELD",
        "BLOOMFIELD CARLETON CO",
        "BLOOMFIELD KINGS CO",
        "BLOOMFIELD RIDGE",
        "BLUE BELL",
        "BLUE MOUNTAIN BEND",
        "BOCABEC",
        "BOIESTOWN",
        "BOIS-BLANC",
        "BOIS-GAGNON",
        "BON ACCORD",
        "BONNY RIVER",
        "BOOM ROAD",
        "BOUCTOUCHE COVE",
        "BOUCTOUCHE RESERVE",
        "BOUCTOUCHE SUD",
        "BOUCTOUCHE",
        "BOUDREAU-OUEST",
        "BOUNDARY CREEK",
        "BRANTVILLE",
        "BREADALBANE",
        "BREWERS MILL",
        "BRIGGS CORNER QUEENS CO",
        "BRISTOL JUNCTION",
        "BRITISH SETTLEMENT",
        "BROCKWAY",
        "BRONSON SETTLEMENT",
        "BROOKVILLE",
        "BROWNS FLAT",
        "BROWNS YARD",
        "BRUNSWICK MINES",
        "BRYENTON",
        "BUBARTOWN",
        "BULL LAKE",
        "BULLS CREEK",
        "BURNSVILLE",
        "BURNT CHURCH FIRST NATION",
        "BURNT CHURCH",
        "BURNT HILL",
        "BURNTLAND BROOK",
        "BURPEE",
        "BURTON",
        "BURTTS CORNER",
        "CAILS MILLS",
        "CAINS RIVER",
        "CAISSIE ROAD",
        "CAITHNESS",
        "CALDERS HEAD",
        "CALEDONIA MOUNTAIN",
        "CALHOUN",
        "CALIFORNIA SETTLEMENT",
        "CAMBRIDGE-NARROWS",
        "CAMPBELL SETTLEMENT YORK CO",
        "CAMPBELL SETTLEMENT",
        "CAMPBELLTON",
        "CANAAN FORKS",
        "CANAAN STATION",
        "CANAL",
        "CANISTO",
        "CANOBIE",
        "CANOOSE",
        "CANTERBURY",
        "CANTON DES BASQUES",
        "CAP-BATEAU",
        "CAP-PELE",
        "CAPE ENRAGE",
        "CAPE SPEAR",
        "CAPE STATION",
        "CAPE TORMENTINE",
        "CARAQUET",
        "CARDIGAN",
        "CARLINGFORD",
        "CARLISLE",
        "CARLOW",
        "CARROL RIDGE",
        "CARROLLS CROSSING",
        "CARSONVILLE",
        "CARTERS POINT",
        "CASSIDY LAKE",
        "CASSILIS",
        "CEDAR CAMP",
        "CENTRAL BLISSVILLE",
        "CENTRAL GREENWICH",
        "CENTRAL HAINESVILLE",
        "CENTRAL HAMPSTEAD",
        "CENTRAL WATERVILLE",
        "CENTRE VILLAGE",
        "CENTREVILLE",
        "CHAMBERLAIN SETTLEMENT",
        "CHAMBERS SETTLEMENT",
        "CHAMCOOK",
        "CHANCE HARBOUR",
        "CHAPLIN ISLAND ROAD",
        "CHARLESTON",
        "CHARLIE LAKE",
        "CHARLO SOUTH",
        "CHARLO",
        "CHARTERS SETTLEMENT",
        "CHELMSFORD",
        "CHERRY BURTON",
        "CHIASSON OFFICE",
        "CHILDS CREEK",
        "CHIPMAN",
        "CHOCOLATE COVE",
        "CLAIR",
        "CLAIRVILLE",
        "CLARENDON",
        "CLARKS CORNER",
        "CLARKVILLE",
        "CLEARVIEW",
        "CLIFTON ROYAL",
        "CLIFTON",
        "CLOVER HILL",
        "CLOVER VALLEY",
        "CLOVERDALE",
        "COAL BRANCH",
        "COAL CREEK",
        "COBURG",
        "COCAGNE",
        "CODYS",
        "COLDSTREAM",
        "COLES ISLAND QUEENS CO",
        "COLLETTE",
        "COLLINA",
        "COLPITTS SETTLEMENT",
        "CONNELL",
        "COOKVILLE",
        "CORMIER-VILLAGE",
        "CORNHILL",
        "COTEAU ROAD",
        "CRAIG FLATS",
        "CROCKER HILL",
        "CROMBIE SETTLEMENT",
        "CROSS CREEK",
        "CUMBERLAND BAY",
        "CUMMINGS COVE",
        "CURRIE SIDING",
        "CURRIEBURG",
        "CURRYVILLE",
        "CURVENTON",
        "DALHOUSIE JUNCTION",
        "DALHOUSIE",
        "DAMASCUS",
        "DARLINGS ISLAND",
        "DAUVERSIERE",
        "DAWSON SETTLEMENT",
        "DAWSONVILLE",
        "DEAD CREEK",
        "DEBEC",
        "DEERSDALE",
        "DEERVILLE",
        "DENNIS BEACH",
        "DERBY JUNCTION",
        "DERBY",
        "DEWOLFE",
        "DIEPPE",
        "DIGDEGUASH",
        "DIPPER HARBOUR",
        "DIVIDE",
        "DOAKTOWN",
        "DOBSON CORNER",
        "DONEGAL",
        "DORCHESTER CAPE",
        "DORCHESTER",
        "DORRINGTON HILL",
        "DOUGLAS HARBOUR",
        "DOUGLAS",
        "DOW SETTLEMENT",
        "DOYLES BROOK",
        "DRUMMOND",
        "DRURYS COVE",
        "DSL DE DRUMMOND",
        "DSL DE GRAND-SAULT/FALLS",
        "DUBEE SETTLEMENT",
        "DUFFERIN CHARLOTTE CO",
        "DUFFERIN QUEENS CO",
        "DUGAS",
        "DUGUAYVILLE",
        "DUMFRIES",
        "DUNDAS",
        "DUNDEE",
        "DUNLOP",
        "DUNSINANE",
        "DURHAM BRIDGE",
        "DUTCH VALLEY",
        "EAST BRANCH",
        "EAST BRIGHTON",
        "EAST CENTREVILLE",
        "EAST COLDSTREAM",
        "EAST NEWBRIDGE",
        "EDGETTS LANDING",
        "EDMUNDSTON",
        "EEL GROUND",
        "EEL RIVER BAR FIRST NATION",
        "EEL RIVER COVE",
        "EEL RIVER CROSSING",
        "EEL RIVER LAKE",
        "ELGIN",
        "ELM HILL",
        "ELMSVILLE",
        "ELMWOOD",
        "ELSIPOGTOG FIRST NATION",
        "ENGLISH SETTLEMENT",
        "ENTERPRISE",
        "ERB SETTLEMENT",
        "ERBS COVE",
        "ESCUMINAC",
        "ESTEY'S BRIDGE",
        "EVANDALE",
        "EVANGELINE",
        "EVANS ROAD",
        "EVERETT",
        "EXMOOR",
        "FAIRFIELD WESTMORLAND CO",
        "FAIRFIELD",
        "FAIRHAVEN",
        "FAIRISLE",
        "FAWCETT HILL",
        "FIELDING",
        "FLATLANDS",
        "FLEMINGTON",
        "FLORENCEVILLE-BRISTOL",
        "FLOWERS COVE",
        "FLUME RIDGE",
        "FORD BANK",
        "FORDS MILLS",
        "FOREST CITY",
        "FOREST GLEN",
        "FOSTERVILLE",
        "FOUR CORNERS",
        "FOUR FALLS",
        "FOUR ROADS",
        "FREDERICKSBURG",
        "FREDERICTON JUNCTION",
        "FREDERICTON",
        "FREE GRANT",
        "FRENCH LAKE",
        "FRENCH VILLAGE KINGS CO",
        "FRENCH VILLAGE-YORK",
        "FROSTY HOLLOW",
        "FUNDY NATIONAL PARK",
        "GAGETOWN",
        "GALLAGHER RIDGE",
        "GALLOWAY",
        "GARDINER POINT",
        "GARDNER CREEK",
        "GARNETT SETTLEMENT",
        "GASPEREAU FORKS",
        "GAUVREAU",
        "GEARY",
        "GERMANTOWN",
        "GIANTS GLEN",
        "GLADESIDE",
        "GLADWYN",
        "GLASSVILLE",
        "GLENCOE",
        "GLENLEVIT",
        "GLENVALE",
        "GLENWOOD KINGS CO",
        "GLENWOOD",
        "GLENWOOD.",
        "GLOUCESTER JUNCTION",
        "GOOD CORNER",
        "GOODWIN MILL",
        "GORDONSVILLE",
        "GRAFTON",
        "GRAND BAY-WESTFIELD",
        "GRAND FALLS",
        "GRAND LAKE ROAD",
        "GRAND MANAN",
        "GRAND-BARACHOIS",
        "GRAND-SAULT/GRAND FALLS",
        "GRANDE-ANSE",
        "GRANDE-DIGUE",
        "GRAVEL HILL",
        "GRAY RAPIDS",
        "GREATER LAKEBURN",
        "GREEN HILL",
        "GREEN MOUNTAIN",
        "GREEN ROAD",
        "GREENFIELD",
        "GREENHILL LAKE",
        "GREGG SETTLEMENT",
        "GROVE HILL",
        "HACHEYVILLE",
        "HALCOMB",
        "HAMMONDVALE",
        "HAMPSTEAD",
        "HAMPTON",
        "HAMTOWN CORNER",
        "HANEYTOWN",
        "HANFORD BROOK",
        "HANWELL",
        "HARCOURT",
        "HARDWICKE",
        "HARDWOOD RIDGE",
        "HAREWOOD",
        "HARTFIELD",
        "HARTFORD",
        "HARTIN SETTLEMENT",
        "HARTLAND",
        "HARTLEY SETTLEMENT",
        "HARVEY ALBERT CO",
        "HARVEY STATION",
        "HARVEY YORK CO",
        "HATFIELD POINT",
        "HAUT-LAMEQUE",
        "HAUT-PAQUETVILLE",
        "HAUT-RIVIERE-DU-PORTAGE",
        "HAUT-SAINT-ANTOINE",
        "HAUT-SHEILA",
        "HAUT-SHIPPAGAN",
        "HAUTE-ABOUJAGANE",
        "HAVELOCK",
        "HAWKINS CORNER",
        "HAWKSHAW",
        "HAY SETTLEMENT",
        "HAYESVILLE",
        "HAYMAN HILL",
        "HAZELDEAN",
        "HAZELTON",
        "HEAD OF MILLSTREAM",
        "HEATHLAND",
        "HEBERT",
        "HEBRON",
        "HENDERSON SETTLEMENT",
        "HERSONVILLE",
        "HIBERNIA COVE",
        "HICKSVILLE",
        "HIGHFIELD",
        "HILLANDALE",
        "HILLGROVE",
        "HILLSBOROUGH WEST",
        "HILLSBOROUGH",
        "HILLSDALE",
        "HILLTOP",
        "HOLMESVILLE",
        "HOLTVILLE",
        "HONEYDALE",
        "HOPEWELL CAPE",
        "HOPEWELL HILL",
        "HOWARD BROOK",
        "HOWARD",
        "HOWLAND RIDGE",
        "HOYT",
        "HUNTERS HOME",
        "IMMIGRANT ROAD",
        "INDIAN ISLAND",
        "INDIAN MOUNTAIN",
        "INKERMAN FERRY",
        "INKERMAN",
        "INTERVALE",
        "IRISH SETTLEMENT",
        "IRISHTOWN",
        "IRON BOUND COVE",
        "ISLAND VIEW",
        "JACKSON FALLS",
        "JACKSONTOWN",
        "JACKSONVILLE",
        "JANEVILLE",
        "JARDINEVILLE",
        "JEFFRIES CORNER",
        "JEMSEG",
        "JEWETTS MILLS",
        "JOHNSON SETTLEMENT CHARLOTTE C",
        "JOHNSON SETTLEMENT YORK CO",
        "JOHNSON'S MILLS",
        "JOHNSTON POINT",
        "JOHNVILLE",
        "JOLICURE",
        "JORDAN MOUNTAIN",
        "JUNIPER",
        "KARS",
        "KEDGWICK NORD",
        "KEDGWICK OUEST",
        "KEDGWICK RIVER",
        "KEDGWICK SUD",
        "KEDGWICK",
        "KEENANS",
        "KENT JUNCTION",
        "KESWICK RIDGE",
        "KESWICK",
        "KIERSTEAD MOUNTAIN",
        "KIERSTEADVILLE",
        "KILBURN",
        "KILLAMS MILLS",
        "KILLARNEY ROAD",
        "KILLOWEEN",
        "KINCARDINE",
        "KINGS LANDING HISTORICAL SETTL",
        "KINGSCLEAR FIRST NATION",
        "KINGSLEY",
        "KINGSTON",
        "KINNEAR SETTLEMENT",
        "KIRKLAND",
        "KNIGHTVILLE",
        "KNOWLESVILLE",
        "KOUCHIBOUGUAC NATIONAL PARK",
        "KOUCHIBOUGUAC",
        "L'ETETE",
        "LAC BAKER",
        "LAGACEVILLE",
        "LAKE EDWARD",
        "LAKE GEORGE",
        "LAKESIDE",
        "LAKETON",
        "LAKEVILLE CARLETON CO",
        "LAKEVILLE CORNER",
        "LAKEVILLE-WESTMORLAND",
        "LAMBERT'S COVE",
        "LAMBERTVILLE",
        "LAMEQUE",
        "LANDRY OFFICE",
        "LANSDOWNE",
        "LAPLANTE",
        "LAVILLETTE",
        "LAWRENCE STATION",
        "LE GOULET",
        "LEE SETTLEMENT",
        "LEECH",
        "LEONARD COLONY",
        "LEONARDVILLE",
        "LEPREAU",
        "LETANG",
        "LEVERVILLE",
        "LEWIS MOUNTAIN",
        "LIMEKILN",
        "LIMESTONE",
        "LINCOLN",
        "LINDSAY",
        "LINTON CORNER",
        "LITTLE BARTIBOG",
        "LITTLE LEPREAU",
        "LITTLE RIDGE",
        "LITTLE RIVER ALBERT CO",
        "LITTLE RIVER GLOUCESTER CO",
        "LITTLE RIVER HILL",
        "LITTLE SALMON RIVER WEST",
        "LITTLE SHEMOGUE",
        "LOCKSTEAD",
        "LONDONDERRY",
        "LONG CREEK",
        "LONG POINT",
        "LONG REACH",
        "LONG SETTLEMENT KINGS CO",
        "LONG SETTLEMENT",
        "LORD'S COVE",
        "LORNE",
        "LOSIER SETTLEMENT",
        "LOWER BRIGHTON",
        "LOWER CAMBRIDGE",
        "LOWER CAPE",
        "LOWER COVE",
        "LOWER COVERDALE",
        "LOWER DERBY",
        "LOWER GREENWICH",
        "LOWER HAINESVILLE",
        "LOWER KINGSCLEAR",
        "LOWER KINTORE",
        "LOWER KNOXFORD",
        "LOWER MILLSTREAM",
        "LOWER NEWCASTLE",
        "LOWER NORTON",
        "LOWER QUEENSBURY",
        "LOWER ST MARYS",
        "LOWER WOODSTOCK",
        "LUDLOW",
        "LUGAR",
        "LUTES MOUNTAIN",
        "LYNNFIELD",
        "LYTTLETON",
        "MACDOUGALL SETTLEMENT",
        "MACES BAY",
        "MACLAGGAN BRIDGE",
        "MACTAQUAC",
        "MADAWASKA MALISEET FRST NATION",
        "MADRAN",
        "MAIN RIVER",
        "MAINSTREAM",
        "MAISONNETTE",
        "MALDEN",
        "MALTEMPEC",
        "MANN'S MOUNTAIN",
        "MANNHURST",
        "MAPLE GLEN",
        "MAPLE GROVE",
        "MAPLE RIDGE",
        "MAPLE VIEW",
        "MAPLEDALE",
        "MAPLEHURST",
        "MAPLEWOOD",
        "MAQUAPIT LAKE",
        "MARKHAMVILLE",
        "MARNE",
        "MARRTOWN",
        "MASCARENE",
        "MATES CORNER",
        "MATTHEWS SETTLEMENT",
        "MAUGERVILLE",
        "MAXWELL",
        "MAYFIELD",
        "MAZEROLLE SETTLEMENT",
        "MCADAM",
        "MCGIVNEY",
        "MCINTOSH HILL",
        "MCKEES MILLS",
        "MCKENNA",
        "MCKENZIE CORNER",
        "MCKINLEYVILLE",
        "MCLAUGHLIN",
        "MCLEOD HILL",
        "MCLEODS",
        "MCNAMEE",
        "MCQUADE",
        "MEADOW BROOK",
        "MECHANIC SETTLEMENT",
        "MEDFORD",
        "MEDUCTIC",
        "MELROSE",
        "MEMRAMCOOK EAST",
        "MEMRAMCOOK",
        "MENNEVAL",
        "MIDDLE HAINESVILLE",
        "MIDDLE RIVER",
        "MIDDLE SACKVILLE",
        "MIDDLETON",
        "MIDGIC",
        "MIDLAND KINGS CO",
        "MIDLAND QUEENS CO",
        "MIDWAY",
        "MILL BROOK",
        "MILL COVE",
        "MILLERTON",
        "MILLVILLE",
        "MINISTERS ISLAND",
        "MINTO",
        "MIRAMICHI BAY",
        "MIRAMICHI ROAD",
        "MIRAMICHI",
        "MISCOU",
        "MISPEC",
        "MOHANNES",
        "MONCTON",
        "MONQUART",
        "MONTEAGLE",
        "MONUMENT",
        "MOORES MILLS",
        "MOOSE MOUNTAIN",
        "MOOSEHORN CREEK",
        "MORRELL SIDING",
        "MORRISDALE",
        "MOUNT DELIGHT",
        "MOUNT HEBRON",
        "MOUNT HOPE",
        "MOUNT PISGAH",
        "MOUNT PLEASANT",
        "MT MIDDLETON",
        "MUNDLEVILLE",
        "MUNIAC",
        "MURRAY CORNER",
        "MURRAY SETTLEMENT",
        "MUSQUASH",
        "NACKAWIC",
        "NAPADOGAN",
        "NAPAN",
        "NASH CREEK",
        "NASHWAAK BRIDGE",
        "NASHWAAK VILLAGE",
        "NASONWORTH",
        "NAUWIGEWAUK",
        "NEGUAC",
        "NELSON HOLLOW",
        "NEPISIGUIT FALLS",
        "NEREPIS",
        "NEW AVON",
        "NEW BANDON GLOUCESTER CO",
        "NEW BANDON NORTHUMB CO",
        "NEW CANAAN",
        "NEW DENMARK",
        "NEW ENGLAND SETTLEMENT",
        "NEW HORTON",
        "NEW JERSEY",
        "NEW LINE",
        "NEW MARKET",
        "NEW MARYLAND",
        "NEW MILLS",
        "NEW RIVER BEACH",
        "NEW SCOTLAND",
        "NEW ZION",
        "NEWBRIDGE",
        "NEWBURG",
        "NEWCASTLE CENTRE",
        "NEWCASTLE CREEK",
        "NEWTOWN",
        "NICHOLAS DENYS",
        "NICTAU",
        "NIGADOO",
        "NOINVILLE",
        "NOONAN",
        "NORTH FORKS",
        "NORTH LAKE",
        "NORTH SHANNONVALE",
        "NORTH TAY",
        "NORTH TETAGOUCHE",
        "NORTH VIEW",
        "NORTHAMPTON",
        "NORTHERN HARBOUR",
        "NORTON",
        "NORTONDALE",
        "NOTRE DAME DE LOURDES",
        "NOTRE-DAME",
        "NOTRE-DAME-DES-ERABLES",
        "OAK BAY",
        "OAK HAVEN",
        "OAK HILL",
        "OAK MOUNTAIN",
        "OAK POINT KINGS CO",
        "OAK POINT",
        "OAKLAND",
        "OAKVILLE",
        "ODELL",
        "OLD AVON",
        "OLD RIDGE",
        "ORANGE HILL",
        "OROMOCTO",
        "OSBORNE CORNER",
        "OTTER CREEK",
        "OXBOW",
        "PABINEAU FALLS",
        "PABINEAU FIRST NATION",
        "PAQUETVILLE",
        "PARKER RIDGE",
        "PARKER ROAD",
        "PARKINDALE",
        "PARLEE BROOK",
        "PARLEEVILLE",
        "PASSEKEAG",
        "PEARSONVILLE",
        "PEEL",
        "PELERIN",
        "PELTOMA SETTLEMENT",
        "PEMBERTON RIDGE",
        "PEMBROKE",
        "PENNFIELD",
        "PENNIAC",
        "PENOBSQUIS",
        "PERRY SETTLEMENT",
        "PERTH-ANDOVER",
        "PETIT TRACADIE",
        "PETIT-CAP",
        "PETIT-PAQUETVILLE",
        "PETIT-ROCHER",
        "PETIT-ROCHER-NORD",
        "PETIT-ROCHER-OUEST",
        "PETIT-ROCHER-SUD",
        "PETIT-SHIPPAGAN",
        "PETITCODIAC EAST",
        "PETITCODIAC",
        "PETITE-LAMEQUE",
        "PETITE-RIVIERE-DE-L'ILE",
        "PICADILLY",
        "PICKETTS COVE",
        "PIERCEMONT",
        "PIGEON HILL",
        "PINE GLEN",
        "PINE RIDGE",
        "PINEVILLE",
        "PLASTER ROCK",
        "PLEASANT RIDGE CHAR COUNTY",
        "PLEASANT RIDGE KINGS CO",
        "PLEASANT VILLA",
        "PLUMWESEEP",
        "PLYMOUTH",
        "POCOLOGAN",
        "POINT DE BUTE",
        "POINT LA NIM",
        "POINTE A BOULEAU",
        "POINTE A TOM",
        "POINTE DES ROBICHAUD",
        "POINTE DIXON POINT",
        "POINTE-ALEXANDRE",
        "POINTE-BRULE",
        "POINTE-CANOT",
        "POINTE-DU-CHENE",
        "POINTE-SAPIN",
        "POINTE-SAUVAGE",
        "POINTE-VERTE",
        "POIRIER SUBDIVISION",
        "POKEMOUCHE",
        "POKESHAW",
        "POKESUDIE",
        "POKIOK",
        "POLE HILL",
        "POLLETT RIVER",
        "POMEROY RIDGE",
        "PONDSTREAM",
        "PONT LAFRANCE",
        "PONT LANDRY",
        "POODIAC",
        "PORT ELGIN",
        "PORTAGE ST-LOUIS",
        "PORTAGE VALE",
        "PORTAGE",
        "PORTER COVE",
        "PRICEVILLE",
        "PRINCE OF WALES",
        "PRINCE WILLIAM",
        "PRINCESS PARK",
        "PRINTZ COVE",
        "PROSSER BROOK",
        "PUBLIC LANDING",
        "QUAKER BROOK",
        "QUARRYVILLE",
        "QUEENSTOWN",
        "QUISPAMSIS",
        "RANG-SAINT-GEORGES",
        "RATTER CORNER",
        "RED BANK QUEENS CO",
        "RED BANK RESERVE",
        "RED BANK",
        "RED BRIDGE",
        "RED RAPIDS",
        "RED ROCK",
        "REDMONDVILLE",
        "RENAUDS MILLS",
        "RENOUS",
        "REXTON",
        "RICEVILLE",
        "RICHARDSON",
        "RICHIBOUCTOU-VILLAGE",
        "RICHIBUCTO ROAD",
        "RICHIBUCTO",
        "RICHMOND CORNER",
        "RICHMOND SETTLEMENT",
        "RILEY BROOK",
        "RIO GRANDE",
        "RIPPLES",
        "RITCHIE",
        "RIVER DE CHUTE",
        "RIVER GLADE",
        "RIVERBANK CARLETON CO",
        "RIVERBANK KINGS CO",
        "RIVERBANK SOUTH",
        "RIVERSIDE-ALBERT",
        "RIVERVIEW",
        "RIVIERE A LA TRUITE",
        "RIVIERE DU NORD",
        "RIVIERE-DU-PORTAGE",
        "RIVIERE-VERTE",
        "ROACHVILLE",
        "ROBERTVILLE",
        "ROBICHAUD SETTLEMENT",
        "ROBINSONVILLE",
        "ROCHEVILLE",
        "ROCKLAND",
        "ROCKPORT",
        "ROGERSVILLE",
        "ROGERSVILLE-EST",
        "ROGERSVILLE-OUEST",
        "ROLLINGDAM",
        "ROSAIREVILLE",
        "ROSEDALE",
        "ROSEHILL",
        "ROSEVALE",
        "ROSSVILLE",
        "ROTHESAY",
        "ROUGH WATERS",
        "ROWENA",
        "ROWLEY",
        "ROYAL ROAD",
        "ROYALTON",
        "RUSAGONIS",
        "RUSSELLVILLE",
        "SACKVILLE ROAD",
        "SACKVILLE",
        "SAINT JOHN",
        "SAINT PONS",
        "SAINT-AMATEUR",
        "SAINT-ANDRE",
        "SAINT-ANDRE-LEBLANC",
        "SAINT-ANTOINE SUD",
        "SAINT-ANTOINE",
        "SAINT-ANTOINE-DE-KENT",
        "SAINT-ARTHUR",
        "SAINT-BASILE",
        "SAINT-CHARLES",
        "SAINT-DAMIEN",
        "SAINT-EDOUARD-DE-KENT",
        "SAINT-FRANCOIS-DE-MADAWASKA",
        "SAINT-GREGOIRE",
        "SAINT-IGNACE",
        "SAINT-IRENEE",
        "SAINT-ISIDORE",
        "SAINT-JACQUES",
        "SAINT-JOSEPH-DE-KENT",
        "SAINT-LAURENT NORD",
        "SAINT-LAURENT",
        "SAINT-LEOLIN",
        "SAINT-LEONARD",
        "SAINT-LEONARD-PARENT",
        "SAINT-LOUIS",
        "SAINT-LOUIS-DE-KENT",
        "SAINT-MARTIN-DE-RESTIGOUCHE",
        "SAINT-MAURE",
        "SAINT-MAURICE",
        "SAINT-NORBERT",
        "SAINT-PAUL",
        "SAINT-PHILIPPE",
        "SAINT-QUENTIN",
        "SAINT-SAUVEUR",
        "SAINT-SIMON",
        "SAINT-THOMAS-DE-KENT",
        "SAINT-WILFRED",
        "SAINTE ROSE",
        "SAINTE-ANNE GLOUCESTER CO",
        "SAINTE-ANNE-DE-KENT",
        "SAINTE-ANNE-DE-MADAWASKA",
        "SAINTE-CECILE",
        "SAINTE-LOUISE",
        "SAINTE-MARIE-DE-KENT",
        "SAINTE-MARIE-SAINT-RAPHAEL",
        "SAINTE-ROSETTE",
        "SAINTE-THERESE SUD",
        "SALEM",
        "SALISBURY WEST",
        "SALISBURY",
        "SALMON BEACH",
        "SALMON CREEK",
        "SALMON RIVER ROAD",
        "SALMON RIVER",
        "SALT SPRINGS",
        "SAUMAREZ",
        "SAVOIE LANDING",
        "SCOTCH LAKE",
        "SCOTCH RIDGE",
        "SCOTCH SETTLEMENT YORK CO",
        "SCOTCH SETTLEMENT",
        "SCOTCHTOWN",
        "SCOTT SIDING",
        "SCOUDOUC ROAD",
        "SCOUDOUC",
        "SEA SIDE",
        "SEARSVILLE",
        "SECOND FALLS",
        "SECOND NORTH RIVER",
        "SEELEYS COVE",
        "SEVOGLE",
        "SHANKLIN",
        "SHANNON",
        "SHEDIAC BRIDGE",
        "SHEDIAC BRIDGE-SHEDIAC RIVER",
        "SHEDIAC CAPE",
        "SHEDIAC RIVER",
        "SHEDIAC",
        "SHEFFIELD",
        "SHEMOGUE",
        "SHENSTONE",
        "SHEPODY ALBERT CO",
        "SHEPODY KINGS CO",
        "SHIPPAGAN",
        "SIEGAS",
        "SILLIKERS",
        "SIMONDS",
        "SISSON BROOK",
        "SISSON RIDGE",
        "SIX ROADS",
        "SKIFF LAKE",
        "SLOPE",
        "SMITH CROSSING",
        "SMITH'S CORNER",
        "SMITHFIELD",
        "SMITHS CREEK",
        "SMITHTOWN",
        "SNIDER MOUNTAIN",
        "SOMERVILLE",
        "SORMANY",
        "SOUTH BRANCH KENT CO",
        "SOUTH BRANCH KINGS CO",
        "SOUTH CANAAN",
        "SOUTH ESK",
        "SOUTH NELSON",
        "SOUTH OROMOCTO LAKE",
        "SOUTH TETAGOUCHE",
        "SOUTHAMPTON",
        "SOUTHFIELD",
        "SPEERVILLE",
        "SPRINGDALE",
        "SPRINGFIELD KINGS CO",
        "SPRINGFIELD YORK CO",
        "SQUAW CAP",
        "ST ALMO",
        "ST ANDREWS",
        "ST CROIX",
        "ST DAVID RIDGE",
        "ST GEORGE",
        "ST MARGARETS",
        "ST MARTINS NORTH",
        "ST MARTINS",
        "ST STEPHEN",
        "ST THOMAS",
        "ST-ANTOINE NORD",
        "ST-HILAIRE",
        "ST-JEAN-BAPTISTE",
        "ST-JOSEPH-DE-MADAWASKA",
        "STANLEY",
        "STAPLES SETTLEMENT",
        "STEEVES MOUNTAIN",
        "STEEVES SETTLEMENT",
        "STICKNEY",
        "STILESVILLE",
        "STONEHAVEN",
        "STONEY CREEK",
        "STOREYTOWN",
        "STRATHADAM",
        "STUART TOWN",
        "STYMIEST",
        "SUMMERFIELD CARLETON CO",
        "SUMMERFIELD KINGS CO",
        "SUMMERVILLE",
        "SUNNY CORNER",
        "SUNNYSIDE BEACH",
        "SUSSEX CORNER",
        "SUSSEX EAST",
        "SUSSEX SOUTH",
        "SUSSEX",
        "SWAN CREEK",
        "SYPHER COVE",
        "TABUSINTAC",
        "TARGETTVILLE",
        "TAXIS RIVER",
        "TAY CREEK",
        "TAY FALLS",
        "TAYLOR VILLAGE",
        "TAYMOUTH",
        "TEEDS MILLS",
        "TEMPERANCE VALE",
        "TEMPLE",
        "TETAGOUCHE FALLS",
        "THE GLADES",
        "THREE BROOKS",
        "THREE TREE CREEK",
        "TIDE HEAD",
        "TILLEY ROAD",
        "TILLEY",
        "TIMBER RIVER",
        "TINKER",
        "TITUSVILLE",
        "TOBIQUE FIRST NATION",
        "TOBIQUE NARROWS",
        "TOWER HILL",
        "TRACADIE BEACH",
        "TRACADIE-SHEILA",
        "TRACEY MILLS",
        "TRACY",
        "TRACYVILLE",
        "TREMBLAY",
        "TROIS-RUISSEAUX",
        "TROUT BROOK",
        "TRUDEL",
        "TURTLE CREEK",
        "TWO BROOKS",
        "TYNEMOUTH CREEK",
        "UNION CORNER",
        "UPHAM",
        "UPPER BLACKVILLE",
        "UPPER BRIGHTON",
        "UPPER CAPE",
        "UPPER CAVERHILL",
        "UPPER COVERDALE",
        "UPPER DERBY",
        "UPPER DORCHESTER",
        "UPPER GAGETOWN",
        "UPPER GOLDEN GROVE",
        "UPPER HAINESVILLE",
        "UPPER HAMPSTEAD",
        "UPPER KENT",
        "UPPER KESWICK",
        "UPPER KINGSCLEAR",
        "UPPER KINTORE",
        "UPPER KNOXFORD",
        "UPPER LETANG",
        "UPPER LOCH LOMOND",
        "UPPER MILLS",
        "UPPER QUEENSBURY",
        "UPPER REXTON",
        "UPPER ROCKPORT",
        "UPPER SACKVILLE",
        "UPPER SALMON CREEK",
        "UPPER TRACY",
        "UPPER WOODSTOCK",
        "UPPERTON",
        "UPSALQUITCH",
        "UTOPIA",
        "VAL COMEAU",
        "VAL-D'AMOUR",
        "VAL-DOUCET",
        "VALLEY ROAD",
        "VERRET",
        "VESPRA",
        "VICTORIA CORNER",
        "VILLAGE BLANCHARD",
        "VILLAGE-DES-POIRIER",
        "VILLAGE-SAINT-LAURENT",
        "VINEGAR HILL",
        "WAASIS",
        "WAKEFIELD",
        "WALKER SETTLEMENT",
        "WAPSKE",
        "WARD SETTLEMENT",
        "WARDS CREEK",
        "WARWICK SETTLEMENT",
        "WATERBOROUGH",
        "WATERFORD",
        "WATERSIDE",
        "WATERVILLE CARLETON CO",
        "WATERVILLE-SUNBURY",
        "WAWEIG",
        "WAYERTON",
        "WEAVER SIDING",
        "WEAVER",
        "WELDON",
        "WELSFORD",
        "WELSHPOOL",
        "WEST BRANCH",
        "WEST FLORENCEVILLE",
        "WEST QUACO",
        "WEST RIVER",
        "WESTCOCK",
        "WESTON",
        "WHEATON SETTLEMENT",
        "WHITE HEAD ISLAND",
        "WHITE HEAD",
        "WHITE RAPIDS",
        "WHITES BROOK",
        "WHITES COVE",
        "WHITES MOUNTAIN",
        "WHITNEY",
        "WICKHAM",
        "WICKLOW",
        "WIGGINS MILL",
        "WILLIAMSBURG",
        "WILLIAMSTOWN CARLETON CO",
        "WILLIAMSTOWN",
        "WILLOW GROVE",
        "WILMOT",
        "WILSONS BEACH",
        "WINDSOR",
        "WIRRAL",
        "WOOD POINT",
        "WOODLANDS",
        "WOODMANS POINT",
        "WOODSIDE",
        "WOODSTOCK FIRST NATION",
        "WOODSTOCK",
        "WUHRS BEACH",
        "WYERS BROOK",
        "YOHO",
        "YOUNGS COVE",
        "ZEALAND",
        "ZIONVILLE",
    ],
    "NL": [
        "AGUATHUNA",
        "ANCHOR POINT",
        "AQUAFORTE",
        "ARNOLDS COVE",
        "ASPEN COVE",
        "AVONDALE",
        "BADGER",
        "BADGERS QUAY",
        "BAIE VERTE",
        "BAINE HARBOUR",
        "BARACHOIS BROOK",
        "BARTLETTS HARBOUR",
        "BAULINE",
        "BAY BULLS",
        "BAY DE VERDE",
        "BAY L'ARGENT",
        "BAY ROBERTS",
        "BAYTONA",
        "BEACHSIDE",
        "BEAUMONT",
        "BELL ISLAND FRONT",
        "BELL ISLAND",
        "BELLBURNS",
        "BELLEORAM",
        "BELLEVUE",
        "BENOITS COVE",
        "BENTON",
        "BIDE ARM",
        "BIRCHY BAY",
        "BIRCHY HEAD",
        "BIRD COVE",
        "BISHOPS FALLS",
        "BLACK DUCK COVE",
        "BLACK DUCK SIDING",
        "BLACK TICKLE",
        "BLAKETOWN",
        "BLOOMFIELD",
        "BOAT HARBOUR WEST",
        "BONAVISTA",
        "BONNE BAY POND",
        "BONNE BAY",
        "BOTWOOD",
        "BOYDS COVE",
        "BRANCH",
        "BRENTS COVE",
        "BRIDGEPORT",
        "BRIGHTON",
        "BRIGUS JUNCTION",
        "BRIGUS",
        "BROAD COVE BDV",
        "BROOKFIELD",
        "BROWNSDALE",
        "BUCHANS JUNCTION",
        "BUCHANS",
        "BUNYANS COVE",
        "BURGEO",
        "BURGOYNES COVE",
        "BURIN BAY ARM",
        "BURIN",
        "BURLINGTON",
        "BURNSIDE",
        "BURNT ISLANDS BLP",
        "BURNT POINT BDV",
        "CALVERT",
        "CAMPBELLTON",
        "CANNINGS COVE",
        "CAPE BROYLE",
        "CAPE FREELS NORTH",
        "CAPE RAY",
        "CAPE ST GEORGE",
        "CAPLIN COVE BDV",
        "CAPPAHAYDEN",
        "CARBONEAR",
        "CARMANVILLE",
        "CARTERS COVE",
        "CARTWRIGHT",
        "CARTYVILLE",
        "CASTORS RIVER",
        "CATALINA",
        "CAVENDISH",
        "CHANCE COVE",
        "CHANGE ISLANDS",
        "CHANNEL-PORT-AUX-BASQUES",
        "CHAPEL ARM",
        "CHAPEL COVE",
        "CHARLESTON",
        "CHARLOTTETOWN LAB",
        "CHARLOTTETOWN",
        "CHURCHILL FALLS",
        "CLARENVILLE",
        "CLARKES BEACH",
        "COACHMANS COVE",
        "CODROY",
        "COLEYS POINT SOUTH",
        "COLINET",
        "COLLIERS RIVERHEAD",
        "COME BY CHANCE",
        "COMFORT COVE-NEWSTEAD",
        "CONCEPTION BAY SOUTH",
        "CONCEPTION HARBOUR",
        "CONCHE",
        "CONNE RIVER",
        "COOKS HARBOUR",
        "CORMACK",
        "CORNER BROOK",
        "COTTLESVILLE",
        "COTTRELLS COVE",
        "COW HEAD",
        "COXS COVE",
        "CRESTON NORTH",
        "CRESTON",
        "CROQUE",
        "CUPIDS",
        "DANIELS HARBOUR",
        "DEADMANS BAY",
        "DEEP BAY",
        "DEER LAKE",
        "DILDO",
        "DOVER",
        "DOYLES",
        "DUNTARA",
        "DUNVILLE",
        "DURRELL",
        "EASTPORT",
        "EDDIES COVE WEST",
        "EDDIES COVE",
        "ELLISTON",
        "EMBREE",
        "ENGLEE",
        "ENGLISH HARBOUR EAST",
        "ENGLISH HARBOUR WEST",
        "EPWORTH",
        "FAIR HAVEN",
        "FERMEUSE",
        "FERRYLAND",
        "FLATROCK",
        "FLEUR DE LYS",
        "FLOWERS COVE",
        "FOGO",
        "FORTEAU",
        "FORTUNE",
        "FOX HARBOUR PB",
        "FRANCOIS",
        "FREDERICKTON",
        "FRENCHMANS COVE BOI",
        "FRENCHMANS COVE FB",
        "FRESHWATER PB",
        "GALLANTS",
        "GAMBO SOUTH",
        "GAMBO",
        "GANDER BAY SOUTH",
        "GANDER BAY",
        "GANDER",
        "GARDEN COVE PB",
        "GARNISH",
        "GAULTOIS",
        "GLENWOOD",
        "GLOVERTOWN SOUTH",
        "GLOVERTOWN",
        "GOOSEBERRY COVE",
        "GOULDS",
        "GRAND BANK",
        "GRAND BAY EAST",
        "GRAND BEACH",
        "GRAND BRUIT",
        "GRAND FALLS-WINDSOR",
        "GRAND LE PIERRE",
        "GRATES COVE",
        "GREEN ISLAND BROOK",
        "GREEN ISLAND COVE",
        "GREENS HARBOUR",
        "GREENSPOND",
        "GREY RIVER",
        "HAMPDEN",
        "HANTS HARBOUR",
        "HAPPY VALLEY-GOOSE BAY",
        "HARBOUR BRETON",
        "HARBOUR GRACE SOUTH",
        "HARBOUR GRACE",
        "HARBOUR MAIN",
        "HARBOUR MILLE",
        "HARBOUR ROUND",
        "HARE BAY BB",
        "HARRYS HARBOUR",
        "HAWKES BAY",
        "HEAD BAY D'ESPOIR",
        "HEART'S CONTENT",
        "HEART'S DELIGHT",
        "HEART'S DESIRE",
        "HEATHERTON",
        "HERMITAGE",
        "HERRING NECK",
        "HICKMANS HARBOUR",
        "HIGHLANDS",
        "HILLGRADE",
        "HILLVIEW",
        "HODGES COVE",
        "HOLYROOD",
        "HOPEALL",
        "HOPEDALE",
        "HORWOOD",
        "HOWLEY",
        "INDIAN BAY BB",
        "ISLAND HARBOUR",
        "ISLE-AUX-MORTS",
        "ISLINGTON",
        "JACKSONS ARM",
        "JACKSONS COVE",
        "JEFFREYS",
        "JERSEYSIDE",
        "JOBS COVE",
        "JOE BATTS ARM",
        "KEELS",
        "KILBRIDE",
        "KINGS COVE",
        "KINGS POINT",
        "KIPPENS",
        "KNIGHTS COVE",
        "L'ANSE AU CLAIR",
        "L'ANSE AU LOUP",
        "LA POILE",
        "LA SCIE",
        "LABRADOR CITY",
        "LADLE COVE",
        "LAMALINE",
        "LANCE COVE",
        "LARK HARBOUR",
        "LAURENCETON",
        "LAWN",
        "LEADING TICKLES",
        "LETHBRIDGE",
        "LEWINS COVE",
        "LEWISPORTE",
        "LITTLE BAY EAST",
        "LITTLE BAY ISLANDS",
        "LITTLE BAY NDB",
        "LITTLE BAY PB",
        "LITTLE BURNT BAY",
        "LITTLE CATALINA",
        "LITTLE HARBOUR EAST PB",
        "LITTLE HEARTS EASE",
        "LITTLE ST LAWRENCE",
        "LODGE BAY",
        "LOGY BAY",
        "LONG HARBOUR",
        "LOON BAY",
        "LOURDES",
        "LOWER ISLAND COVE",
        "LUMSDEN",
        "MAIN BROOK",
        "MAIN POINT",
        "MAKINSONS",
        "MAKKOVIK",
        "MARYS HARBOUR",
        "MARYSTOWN",
        "MARYSVALE",
        "MASSEY DRIVE",
        "MCCALLUM",
        "MELROSE",
        "MIDDLE ARM GB",
        "MIDDLE COVE",
        "MILES COVE",
        "MILLERTOWN",
        "MILLTOWN",
        "MINGS BIGHT",
        "MOBILE",
        "MONKSTOWN",
        "MORETONS HARBOUR",
        "MOUNT ARLINGTON HEIGHTS",
        "MOUNT CARMEL",
        "MOUNT MORIAH",
        "MOUNT PEARL",
        "MUD LAKE",
        "MUSGRAVE HARBOUR",
        "MUSGRAVETOWN",
        "NAIN",
        "NATUASHISH",
        "NEW CHELSEA",
        "NEW HARBOUR TB",
        "NEW MELBOURNE",
        "NEW PERLICAN",
        "NEWMANS COVE",
        "NEWTOWN",
        "NIPPERS HARBOUR",
        "NOELS POND",
        "NORMANS COVE",
        "NORRIS ARM NORTHSIDE",
        "NORRIS ARM",
        "NORRIS POINT",
        "NORTH HARBOUR PB",
        "NORTH HARBOUR SMB",
        "NORTH VALLEY",
        "NORTH WEST BROOK",
        "NORTH WEST RIVER",
        "NORTHERN BAY",
        "OCHRE PIT COVE",
        "OLD PERLICAN",
        "OLD SHOP",
        "OPEN HALL",
        "OUTER COVE",
        "PACQUET",
        "PARADISE RIVER",
        "PARADISE",
        "PARKERS COVE",
        "PARSONS POND",
        "PASADENA",
        "PETERVIEW",
        "PETIT FORTE",
        "PETTY HARBOUR",
        "PILLEYS ISLAND",
        "PLACENTIA",
        "PLATE COVE EAST",
        "PLATE COVE WEST",
        "PLUM POINT",
        "POINT LEAMINGTON",
        "POINT OF BAY",
        "POLLARDS POINT",
        "POOLS COVE",
        "POOLS ISLAND",
        "PORT ALBERT",
        "PORT ANSON",
        "PORT AU CHOIX",
        "PORT AU PORT",
        "PORT BLANDFORD",
        "PORT DE GRAVE",
        "PORT HOPE SIMPSON",
        "PORT REXTON",
        "PORT SAUNDERS",
        "PORT UNION",
        "PORTLAND CREEK",
        "PORTUGAL COVE-ST PHILIPS",
        "POSTVILLE",
        "POUCH COVE",
        "POUND COVE",
        "PRINCETON",
        "PYNN'S BROOK",
        "RALEIGH",
        "RAMEA",
        "RATTLING BROOK",
        "RED BAY",
        "RED HARBOUR PB",
        "RED HEAD COVE",
        "REEFS HARBOUR",
        "REIDVILLE",
        "RENCONTRE EAST",
        "RENEWS",
        "RIGOLET",
        "RIVER OF PONDS",
        "RIVERHEAD HARBOUR GRACE",
        "ROBERTS ARM",
        "ROBINSONS",
        "ROCKY HARBOUR",
        "RODDICKTON",
        "RODGERS COVE",
        "ROSE BLANCHE",
        "ROUND HARBOUR GB",
        "RUSHOON",
        "SALLYS COVE",
        "SALMON COVE BDV",
        "SALVAGE",
        "SANDRINGHAM",
        "SANDY COVE",
        "SEAL COVE FB",
        "SEAL COVE WB",
        "SELDOM",
        "SHALLOWAY COVE",
        "SHEA HEIGHTS",
        "SHEARSTOWN",
        "SHIP HARBOUR PB",
        "SHOE COVE",
        "SNOOKS ARM",
        "SOPS ARM",
        "SOUTH BRANCH",
        "SOUTH BROOK GB",
        "SOUTH DILDO",
        "SOUTH EAST BIGHT",
        "SOUTH RIVER",
        "SOUTHERN BAY",
        "SOUTHERN HARBOUR PB",
        "SPANIARDS BAY",
        "SPRINGDALE",
        "ST ALBANS",
        "ST ANDREWS",
        "ST ANTHONY EAST",
        "ST BERNARDS-JACQUES FONTAINE",
        "ST BRENDANS",
        "ST BRIDES",
        "ST CHADS",
        "ST DAVIDS",
        "ST FINTANS",
        "ST GEORGES",
        "ST JOSEPHS SAL",
        "ST JUDES",
        "ST JULIENS",
        "ST LAWRENCE",
        "ST LEWIS",
        "ST LUNAIRE-GRIQUET",
        "ST MARYS",
        "ST PAULS",
        "ST SHOTTS",
        "ST VINCENTS",
        "ST. ANTHONY",
        "ST. JOHN'S",
        "STAG HARBOUR",
        "STEPHENVILLE CROSSING",
        "STEPHENVILLE",
        "STONEVILLE",
        "SUMMERFORD",
        "SUMMERVILLE",
        "SUNNYSIDE",
        "SWEET BAY",
        "SWIFT CURRENT",
        "TEMPLEMAN",
        "TERRENCEVILLE",
        "TICKLE COVE",
        "TILTING",
        "TIZZARDS HARBOUR",
        "TORBAY",
        "TORS COVE",
        "TRAYTOWN",
        "TREPASSEY",
        "TRINITY BB",
        "TRINITY TB",
        "TRITON",
        "TROUT RIVER",
        "TURKS COVE",
        "TWILLINGATE",
        "UPPER ISLAND COVE",
        "VALLEY POND",
        "VICTORIA CB",
        "VICTORIA COVE",
        "WABUSH",
        "WAREHAM-CENTREVILLE",
        "WESLEYVILLE",
        "WEST BAY CENTRE",
        "WEST ST MODESTE",
        "WESTERN BAY",
        "WESTPORT",
        "WHITBOURNE",
        "WHITEWAY",
        "WILD COVE WB",
        "WILLIAMS HARBOUR",
        "WILTONDALE",
        "WINGS POINT",
        "WINTERLAND",
        "WINTERTON",
        "WITLESS BAY",
        "WOODFORDS",
        "WOODSTOCK",
        "YORK HARBOUR",
    ],
    "NS": [
        "ADMIRAL ROCK",
        "ADVOCATE HARBOUR",
        "AFTON STATION",
        "ALBERT BRIDGE",
        "ALDER POINT",
        "ALTON",
        "AMHERST",
        "ANNAPOLIS ROYAL",
        "ANTIGONISH",
        "ANTRIM",
        "ARCADIA",
        "ARICHAT",
        "ASKILTON",
        "ASPEN",
        "AUBURN",
        "AUBURNDALE",
        "AVONPORT",
        "AYLESFORD",
        "BACCARO",
        "BADDECK",
        "BAKER SETTLEMENT",
        "BALD ROCK",
        "BALLS CREEK",
        "BARNEYS RIVER STATION",
        "BARR SETTLEMENT",
        "BARRA GLEN",
        "BARRACHOIS",
        "BARRINGTON PASSAGE",
        "BARRINGTON",
        "BARSS CORNER",
        "BARTON",
        "BASS RIVER",
        "BATESTON",
        "BAYSIDE",
        "BEAR COVE",
        "BEAR RIVER",
        "BEAVER BANK",
        "BEAVER BROOK",
        "BEAVER COVE",
        "BEDFORD",
        "BEECHMONT",
        "BEECHVILLE",
        "BELLE COTE",
        "BELLIVEAU COVE",
        "BELMONT",
        "BELNAN",
        "BEN EOIN",
        "BENACADIE",
        "BERWICK",
        "BIBLE HILL",
        "BICKERTON WEST",
        "BIG BEACH",
        "BIG BRAS D'OR",
        "BIG LAKE",
        "BIG POND CENTRE",
        "BIG POND",
        "BIG RIDGE",
        "BIRCH GROVE",
        "BIRCH HILL",
        "BLACK BROOK",
        "BLACK POINT",
        "BLACK ROCK",
        "BLACKETTS LAKE",
        "BLANDFORD",
        "BLIND BAY",
        "BLOCKHOUSE",
        "BOISDALE",
        "BOULARDERIE CENTER",
        "BOULARDERIE EAST",
        "BOUTILIERS POINT",
        "BOYLSTON",
        "BRANCH LAHAVE",
        "BRAS D'OR",
        "BRENTWOOD",
        "BRIDGETOWN",
        "BRIDGEWATER",
        "BROOKFIELD",
        "BROOKLYN",
        "BROOKSIDE",
        "BROOKSIDE.",
        "BROUGHTON",
        "BUCKFIELD",
        "CALEDONIA",
        "CAMBRIDGE",
        "CAMDEN",
        "CAMPERDOWN",
        "CANNING",
        "CANSO",
        "CAPE DAUPHIN",
        "CAPE NEGRO",
        "CAPE NORTH",
        "CAPSTICK",
        "CARIBOU MARSH",
        "CARLETON",
        "CARROLLS CORNER",
        "CASTLE BAY",
        "CATALONE GUT",
        "CATALONE",
        "CENTRAL NORTH RIVER",
        "CENTRAL ONSLOW",
        "CENTRE BURLINGTON",
        "CENTREVILLE",
        "CHASWOOD",
        "CHELSEA",
        "CHERRY BROOK",
        "CHESTER BASIN",
        "CHESTER",
        "CHETICAMP",
        "CHEVERIE",
        "CHRISTMAS ISLAND",
        "CHURCH POINT",
        "CLAM POINT",
        "CLARKS HARBOUR",
        "CLEMENTSPORT",
        "CLEMENTSVALE",
        "CLEVELAND",
        "CLIFTON",
        "CLOVERDALE",
        "CLYDE RIVER",
        "COLDBROOK",
        "COLDSTREAM",
        "COLE HARBOUR",
        "COLLINGWOOD CORNER",
        "CONQUERALL BANK",
        "CONQUERALL MILLS",
        "COOKS BROOK",
        "COOKVILLE",
        "CORNWALLIS",
        "COW BAY",
        "COXHEATH",
        "CRAIGMORE",
        "CRANDALL ROAD",
        "CREIGNISH",
        "CROSS ROADS COUNTRY HARBOUR",
        "CROUSES SETTLEMENT",
        "CROUSETOWN",
        "CROWELL",
        "CROWES MILLS",
        "CURRYS CORNER",
        "D'ESCOUSSE",
        "DALEM LAKE",
        "DANESVILLE",
        "DARTMOUTH",
        "DAYSPRING",
        "DEBERT",
        "DEEP BROOK",
        "DENSMORES MILLS",
        "DIGBY",
        "DILIGENT RIVER",
        "DINGWALL",
        "DOMINION",
        "DONKIN",
        "DUNCANS COVE",
        "DUTCH BROOK",
        "DUTCH SETTLEMENT",
        "EAST BACCARO",
        "EAST BAY",
        "EAST CLIFFORD",
        "EAST DOVER",
        "EAST GORE",
        "EAST LAHAVE",
        "EAST LAWRENCETOWN",
        "EAST MOUNTAIN",
        "EAST PENNANT",
        "EAST PRESTON",
        "EAST STEWIACKE",
        "EASTERN PASSAGE",
        "ECONOMY",
        "EDWARDSVILLE",
        "ELDERBANK",
        "ELLERSHOUSE",
        "ELMSDALE",
        "ENFIELD",
        "ENGLISHTOWN",
        "ENON",
        "ESKASONI",
        "EUREKA",
        "FALL RIVER",
        "FALMOUTH",
        "FERGUSONS COVE",
        "FISHERMANS HARBOUR",
        "FIVE ISLANDS",
        "FLETCHERS LAKE",
        "FLORENCE",
        "FORT ELLIS",
        "FORTRESS OF LOUISBOURG",
        "FOURCHU",
        "FRAMBOISE INTERVALE",
        "FRAMBOISE",
        "FRANKVILLE",
        "FREEPORT",
        "FRENCH ROAD",
        "FRENCH VILLAGE",
        "FRENCHVALE",
        "GABARUS LAKE",
        "GABARUS",
        "GARDINER MINES",
        "GAYS RIVER",
        "GEORGES RIVER",
        "GILLIS LAKE",
        "GILLIS POINT",
        "GLACE BAY",
        "GLEN HAVEN",
        "GLEN MARGARET",
        "GLENWOOD",
        "GOFFS",
        "GOLDBORO",
        "GOODWOOD",
        "GOSHEN",
        "GRAND ETANG",
        "GRAND LAKE ROAD",
        "GRAND LAKE",
        "GRAND MIRA NORTH",
        "GRAND MIRA SOUTH",
        "GRAND NARROWS",
        "GRAND PRE",
        "GRAND RIVER",
        "GRANVILLE FERRY",
        "GRASS COVE",
        "GREAT VILLAGE",
        "GREEN BAY",
        "GREEN CREEK",
        "GREEN OAKS",
        "GREENFIELD",
        "GREENFIELD.",
        "GREENWOOD",
        "GRIMMS SETTLEMENT",
        "GROVES POINT",
        "GUYSBOROUGH",
        "HACKETTS COVE",
        "HALIBUT BAY",
        "HALIFAX",
        "HAMMONDS PLAINS",
        "HAMPTON",
        "HANTSPORT",
        "HARDWOOD LANDS",
        "HARMONY",
        "HARRIETSFIELD",
        "HATCHET LAKE",
        "HAVRE BOUCHER",
        "HEAD OF CHEZZETCOOK",
        "HEAD OF JEDDORE",
        "HEAD OF ST MARGARETS BAY",
        "HEATHERTON",
        "HEBBS CROSS",
        "HEBBVILLE",
        "HEBRON",
        "HERRING COVE",
        "HIGHLAND HILL",
        "HILLSIDE BOULARDERIE",
        "HOMEVILLE",
        "HOPEWELL",
        "HOWIE CENTER",
        "HUBBARDS",
        "HUBLEY",
        "HUNTINGTON",
        "HUNTS POINT",
        "INDIAN BROOK 14",
        "INDIAN HARBOUR",
        "INDIAN PATH",
        "INGOMAR",
        "INGONISH BEACH",
        "INGONISH",
        "INGRAMPORT",
        "INVERNESS",
        "IONA",
        "IRISH COVE",
        "IRISHVALE",
        "IRONVILLE",
        "ISAACS HARBOUR",
        "ISLANDVIEW",
        "ITALY CROSS",
        "JAMESVILLE",
        "JEDDORE OYSTER PONDS",
        "JOGGINS",
        "JORDAN FALLS",
        "JUDIQUE",
        "JUNIPER MOUNTAIN",
        "KEMPT HEAD",
        "KEMPTOWN",
        "KEMPTVILLE",
        "KENNETCOOK",
        "KENTVILLE",
        "KETCH HARBOUR",
        "KINGSTON",
        "KINSAC",
        "L'ARDOISE",
        "LA HAVE",
        "LABELLE",
        "LACONIA",
        "LAKE CHARLOTTE",
        "LAKE ECHO",
        "LAKE EGMONT",
        "LAKE UIST",
        "LAKESIDE",
        "LAKEVIEW",
        "LANESVILLE",
        "LANTZ",
        "LAPLAND",
        "LARRYS RIVER",
        "LAWRENCETOWN",
        "LAWRENCETOWN.",
        "LEITCHES CREEK",
        "LEWIS LAKE",
        "LEXINGTON",
        "LINGAN ROAD",
        "LINGAN",
        "LISCOMB",
        "LITTLE BRAS D'OR",
        "LITTLE BROOK",
        "LITTLE DOVER",
        "LITTLE LORRAINE",
        "LITTLE NARROWS",
        "LITTLE POND",
        "LITTLE RIVER",
        "LITTLE TANCOOK",
        "LIVERPOOL",
        "LOCH LOMOND",
        "LOCKEPORT",
        "LONDONDERRY",
        "LONG ISLAND",
        "LONG POINT",
        "LOUISBOURG",
        "LOUISDALE",
        "LOWER BRANCH",
        "LOWER EAST PUBNICO",
        "LOWER FIVE ISLANDS",
        "LOWER L'ARDOISE",
        "LOWER NORTHFIELD",
        "LOWER ONSLOW",
        "LOWER PROSPECT",
        "LOWER SACKVILLE",
        "LOWER TRURO",
        "LOWER WASHABUCK",
        "LOWER WEDGEPORT",
        "LOWER WEST PUBNICO",
        "LOWER WOODS HARBOUR",
        "LUCASVILLE",
        "LUNENBURG",
        "LYDGATE",
        "MABOU",
        "MACADAMS LAKE",
        "MACCAN",
        "MACKAY SIDING",
        "MACKDALE",
        "MACKINNONS HARBOUR",
        "MACPHEES CORNER",
        "MAHONE BAY",
        "MAIN-A-DIEU",
        "MAITLAND BRIDGE",
        "MAITLAND",
        "MALAGASH",
        "MANGANESE MINES",
        "MAPLE GROVE",
        "MARGAREE CENTRE",
        "MARGAREE FORKS",
        "MARGAREE HARBOUR",
        "MARGAREE VALLEY",
        "MARGAREE",
        "MARGARETSVILLE",
        "MARIE JOSEPH",
        "MARION BRIDGE",
        "MAVILLETTE",
        "MCCALLUM SETTLEMENT",
        "MCGRATHS COVE",
        "MCGRAY",
        "MEAGHERS GRANT",
        "MELVILLE",
        "MEMBERTOU",
        "MERIGOMISH",
        "METEGHAN CENTRE",
        "METEGHAN RIVER",
        "METEGHAN",
        "MICMAC",
        "MIDDLE CAPE",
        "MIDDLE LAHAVE",
        "MIDDLE MUSQUODOBOIT",
        "MIDDLE PORTERS LAKE",
        "MIDDLE SACKVILLE",
        "MIDDLE STEWIACKE",
        "MIDDLE WEST PUBNICO",
        "MIDDLETON",
        "MIDDLEWOOD",
        "MIDVILLE BRANCH",
        "MILFORD STATION",
        "MILFORD",
        "MILL CREEK",
        "MILL VILLAGE",
        "MILL VILLAGE.",
        "MILLBROOK",
        "MILLVILLE",
        "MILTON",
        "MINEVILLE",
        "MIRA GUT",
        "MIRA ROAD",
        "MOLEGA LAKE",
        "MONASTERY",
        "MONTAGUE GOLD MINES",
        "MOOSELAND",
        "MOSER RIVER",
        "MOUNT UNIACKE",
        "MULGRAVE",
        "MURRAY SIDING",
        "MUSQUODOBOIT HARBOUR",
        "NAPPAN",
        "NEILS HARBOUR",
        "NEW CAMPBELLTON",
        "NEW CANADA",
        "NEW GERMANY",
        "NEW GLASGOW",
        "NEW HARRIS",
        "NEW HAVEN",
        "NEW MINAS",
        "NEW ROSS",
        "NEW VICTORIA",
        "NEW WATERFORD",
        "NEWCOMBVILLE",
        "NEWPORT STATION",
        "NEWPORT",
        "NEWTOWN",
        "NINE MILE RIVER",
        "NOEL",
        "NORTH EAST MARGAREE",
        "NORTH EAST POINT",
        "NORTH PRESTON",
        "NORTH RIVER",
        "NORTH SALEM",
        "NORTH SYDNEY",
        "NORTH WEST ARM",
        "NORTHPORT",
        "NORTHSIDE EAST BAY",
        "NUTTBY",
        "OAKFIELD",
        "OAKHILL",
        "OLD BARNS",
        "OLDHAM",
        "ONSLOW MOUNTAIN",
        "ORANGEDALE",
        "OSBORNE HARBOUR",
        "OTTAWA BROOK",
        "OXFORD JUNCTION",
        "OXFORD",
        "PARADISE",
        "PARRSBORO",
        "PEGGYS COVE",
        "PETIT DE GRAT",
        "PETIT ETANG",
        "PETITE RIVIERE",
        "PICTOU ISLAND",
        "PICTOU",
        "PINE GROVE",
        "PINE GROVE.",
        "PINEHURST",
        "PIPERS COVE",
        "PLEASANT BAY",
        "PLEASANT HILL",
        "PLEASANTVILLE",
        "PLYMPTON",
        "POINT ACONI",
        "POINT EDWARD",
        "POINT TUPPER",
        "PORT CALEDONIA",
        "PORT CLYDE",
        "PORT DUFFERIN",
        "PORT GREVILLE",
        "PORT HASTINGS",
        "PORT HAWKESBURY",
        "PORT HOOD",
        "PORT HOWE",
        "PORT JOLI",
        "PORT LA TOUR",
        "PORT MAITLAND",
        "PORT MALCOLM",
        "PORT MEDWAY",
        "PORT MORIEN",
        "PORT MOUTON",
        "PORT WILLIAMS",
        "PORTAGE",
        "PORTERS LAKE",
        "PORTUGUESE COVE",
        "PRIME BROOK",
        "PRINCEPORT",
        "PROSPECT BAY",
        "PROSPECT VILLAGE",
        "PROSPECT",
        "PUBNICO",
        "PUGWASH JUNCTION",
        "PUGWASH",
        "QUEENSVILLE",
        "RED POINT",
        "RESERVE MINES",
        "RHODES CORNER",
        "RINES CREEK",
        "RIVER BOURGEOIS",
        "RIVER DENYS",
        "RIVER HEBERT EAST",
        "RIVER HEBERT",
        "RIVER JOHN",
        "RIVER PHILIP",
        "RIVER RYAN",
        "RIVERPORT",
        "RIVERSDALE",
        "RIVERSIDE",
        "ROCK ELM",
        "ROSE BAY",
        "ROSS FERRY",
        "ROUND ISLAND",
        "SABLE RIVER",
        "SALMON RIVER",
        "SALMON RIVER.",
        "SALT SPRINGS",
        "SAMBRO CREEK",
        "SAMBRO HEAD",
        "SAMBRO",
        "SAMPSON COVE",
        "SANDFIELD",
        "SANDY COVE",
        "SAULNIERVILLE",
        "SCOTCH LAKE",
        "SCOTCH VILLAGE",
        "SCOTCHTOWN",
        "SCOTSBURN",
        "SCOTSVILLE",
        "SEABRIGHT",
        "SHAD BAY",
        "SHAG HARBOUR",
        "SHEARWATER",
        "SHEET HARBOUR",
        "SHELBURNE",
        "SHENACADIE",
        "SHERBROOKE",
        "SHORTTS LAKE",
        "SHUBENACADIE EAST",
        "SHUBENACADIE",
        "SMITHS COVE",
        "SMITHSVILLE",
        "SOUTH BAR",
        "SOUTH BROOKFIELD",
        "SOUTH HEAD",
        "SOUTH MAITLAND",
        "SOUTH OHIO",
        "SOUTH WEST MARGAREE",
        "SOUTHAMPTON",
        "SOUTHSIDE BOULARDERIE",
        "SPECTACLE LAKES",
        "SPRINGFIELD",
        "SPRINGHILL",
        "ST ANDREWS CHANNEL",
        "ST ANDREWS",
        "ST COLUMBA",
        "ST MARGARET VILLAGE",
        "ST PETERS",
        "ST-JOSEPH-DU-MOINE",
        "STE CROIX",
        "STE-ANNE-DU-RUISSEAU",
        "STELLARTON",
        "STEWIACKE",
        "STILLWATER LAKE",
        "STIRLING",
        "STONEY ISLAND",
        "SUGAR CAMP",
        "SUMMERVILLE",
        "SUNNYBRAE",
        "SYDNEY FORKS",
        "SYDNEY MINES",
        "SYDNEY RIVER",
        "SYDNEY",
        "TANCOOK ISLAND",
        "TANGIER",
        "TANTALLON",
        "TATAMAGOUCHE",
        "TERENCE BAY",
        "THOMASVILLE",
        "THORBURN",
        "TIMBERLEA",
        "TIVERTON",
        "TOWER ROAD",
        "TRENTON",
        "TROY",
        "TRURO HEIGHTS",
        "TRURO",
        "TUSKET",
        "UPPER BRANCH",
        "UPPER BROOKSIDE",
        "UPPER CHELSEA",
        "UPPER GRAND MIRA",
        "UPPER HAMMONDS PLAINS",
        "UPPER KENNETCOOK",
        "UPPER LAHAVE",
        "UPPER LEITCHES CREEK",
        "UPPER MUSQUODOBOIT",
        "UPPER NINE MILE RIVER",
        "UPPER NORTH RIVER",
        "UPPER NORTH SYDNEY",
        "UPPER NORTHFIELD",
        "UPPER ONSLOW",
        "UPPER PORT LA TOUR",
        "UPPER RAWDON",
        "UPPER SACKVILLE",
        "UPPER STEWIACKE",
        "UPPER TANTALLON",
        "UPPER WASHABUCK",
        "URBANIA",
        "VALLEY",
        "VICTORIA MINES",
        "WAGMATCOOK",
        "WALLACE",
        "WALTON",
        "WASHABUCK CENTRE",
        "WATERLOO",
        "WATERVILLE",
        "WAVERLEY",
        "WEDGEPORT",
        "WELLINGTON",
        "WENTWORTH",
        "WENTZELLS LAKE",
        "WEST ARICHAT",
        "WEST BAY ROAD",
        "WEST BAY",
        "WEST CLIFFORD",
        "WEST DOVER",
        "WEST INDIAN ROAD",
        "WEST NORTHFIELD",
        "WEST PENNANT",
        "WEST PORTERS LAKE",
        "WEST PUBNICO",
        "WEST RIVER STATION",
        "WEST ST ANDREWS",
        "WESTCHESTER STATION",
        "WESTERN SHORE",
        "WESTMOUNT",
        "WESTPHAL",
        "WESTPORT",
        "WESTVILLE",
        "WEYMOUTH",
        "WHITES LAKE",
        "WHYCOCOMAGH",
        "WHYNOTTS SETTLEMENT",
        "WILEVILLE",
        "WILLIAMSWOOD",
        "WILMOT STATION",
        "WINDSOR JUNCTION",
        "WINDSOR",
        "WITTENBURG",
        "WOLFVILLE",
        "WYSES CORNER",
        "YARMOUTH",
    ],
    "NT": [
        "AKLAVIK",
        "BEHCHOKO",
        "COLVILLE LAKE",
        "DELINE",
        "ENTERPRISE",
        "FORT GOOD HOPE",
        "FORT LIARD",
        "FORT MCPHERSON",
        "FORT PROVIDENCE",
        "FORT RESOLUTION",
        "FORT SIMPSON",
        "FORT SMITH",
        "GAMETI",
        "HAY RIVER",
        "INUVIK",
        "LUTSELK'E",
        "NORMAN WELLS",
        "PAULATUK",
        "SACHS HARBOUR",
        "TROUT LAKE",
        "TSIIGEHTCHIC",
        "TUKTOYAKTUK",
        "TULITA",
        "ULUKHAKTOK",
        "WEKWETI",
        "WHATI",
        "WRIGLEY",
        "YELLOWKNIFE",
    ],
    "NU": [
        "ARCTIC BAY",
        "ARVIAT",
        "BAKER LAKE",
        "BAY CHIMO",
        "CAMBRIDGE BAY",
        "CAPE DORSET",
        "CHESTERFIELD INLET",
        "CLYDE RIVER",
        "CORAL HARBOUR",
        "EUREKA",
        "GJOA HAVEN",
        "GRISE FIORD",
        "HALL BEACH",
        "IGLOOLIK",
        "IQALUIT",
        "KIMMIRUT",
        "KUGAARUK",
        "KUGLUKTUK",
        "PANGNIRTUNG",
        "POND INLET",
        "QIKIQTARJUAQ",
        "RANKIN INLET",
        "REPULSE BAY",
        "RESOLUTE",
        "SANIKILUAQ",
        "TALOYOAK",
        "WHALE COVE",
    ],
    "ON": [
        "ACTON",
        "ADDISON",
        "AHMIC HARBOUR",
        "AILSA CRAIG",
        "AJAX",
        "AKWESASNE",
        "ALBAN",
        "ALBERTON",
        "ALEXANDRIA",
        "ALFRED",
        "ALGOMA MILLS",
        "ALLANBURG",
        "ALLENFORD",
        "ALLISTON",
        "ALMA",
        "ALMONTE",
        "ALTON",
        "ALVINSTON",
        "AMELIASBURG",
        "AMHERSTBURG",
        "AMHERSTVIEW",
        "ANCASTER",
        "ANGLING LAKE",
        "ANGUS",
        "ANNAN",
        "APPIN",
        "APPLE HILL",
        "APSLEY",
        "ARDEN",
        "ARDOCH",
        "ARISS",
        "ARKELL",
        "ARKONA",
        "ARMSTRONG STATION",
        "ARNPRIOR",
        "ARNSTEIN",
        "AROLAND",
        "ARTHUR",
        "ARVA",
        "ASHBURN",
        "ASHTON",
        "ASTORVILLE",
        "ASTRA",
        "ATHENS",
        "ATIKOKAN",
        "ATTAWAPISKAT",
        "ATWOOD",
        "AUBURN",
        "AURORA",
        "AVONMORE",
        "AYLMER",
        "AYR",
        "AYTON",
        "AZILDA",
        "BADEN",
        "BADJEROS",
        "BAILIEBORO",
        "BAINSVILLE",
        "BALA",
        "BALDERSON",
        "BALDWIN",
        "BALLINAFAD",
        "BALMERTOWN",
        "BALTIMORE",
        "BANCROFT",
        "BARRIE",
        "BARRYS BAY",
        "BARWICK",
        "BATAWA",
        "BATCHAWANA BAY",
        "BATH",
        "BATTERSEA",
        "BAYFIELD",
        "BAYSVILLE",
        "BEACHBURG",
        "BEACHVILLE",
        "BEAMSVILLE",
        "BEAR ISLAND",
        "BEARDMORE",
        "BEARSKIN LAKE",
        "BEAVERTON",
        "BEETON",
        "BELFOUNTAIN",
        "BELGRAVE",
        "BELLE EWART",
        "BELLE RIVER",
        "BELLE VALLEE",
        "BELLEVILLE",
        "BELMONT",
        "BELWOOD",
        "BERKELEY",
        "BERWICK",
        "BETHANY",
        "BEWDLEY",
        "BIG TROUT LAKE",
        "BINBROOK",
        "BIRCH ISLAND",
        "BISCOTASING",
        "BISSETT CREEK",
        "BLACKSTOCK",
        "BLENHEIM",
        "BLEZARD VALLEY",
        "BLIND RIVER",
        "BLOOMFIELD",
        "BLOOMINGDALE",
        "BLUE MOUNTAINS",
        "BLUEVALE",
        "BLYTH",
        "BLYTHESWOOD",
        "BOBCAYGEON",
        "BOGNOR",
        "BOLSOVER",
        "BOLTON",
        "BOND HEAD",
        "BONFIELD",
        "BORDEN",
        "BORNHOLM",
        "BOTHWELL",
        "BOULTER",
        "BOURGET",
        "BOWMANVILLE",
        "BRACEBRIDGE",
        "BRADFORD",
        "BRAESIDE",
        "BRAMPTON",
        "BRANCHTON",
        "BRANTFORD",
        "BRECHIN",
        "BRESLAU",
        "BRIDGENORTH",
        "BRIGDEN",
        "BRIGHT",
        "BRIGHT'S GROVE",
        "BRIGHTON",
        "BRINSTON",
        "BRITT",
        "BROCKVILLE",
        "BRODHAGEN",
        "BROUGHAM",
        "BROWNSVILLE",
        "BRUCE MINES",
        "BRUCEFIELD",
        "BRUNNER",
        "BRUSSELS",
        "BUCKHORN",
        "BURFORD",
        "BURGESSVILLE",
        "BURKS FALLS",
        "BURLINGTON",
        "BURNSTOWN",
        "BURNT RIVER",
        "BURRITTS RAPIDS",
        "BYNG INLET",
        "CACHE BAY",
        "CAESAREA",
        "CAISTOR CENTRE",
        "CALABOGIE",
        "CALEDON EAST",
        "CALEDON VILLAGE",
        "CALEDON",
        "CALEDONIA",
        "CALLANDER",
        "CAMBRAY",
        "CAMBRIDGE",
        "CAMDEN EAST",
        "CAMERON",
        "CAMLACHIE",
        "CAMPBELLCROFT",
        "CAMPBELLFORD",
        "CAMPBELLVILLE",
        "CAMPDEN",
        "CANFIELD",
        "CANNIFTON",
        "CANNINGTON",
        "CAPREOL",
        "CARAMAT",
        "CARDIFF",
        "CARDINAL",
        "CARGILL",
        "CARLETON PLACE",
        "CARLISLE",
        "CARLSBAD SPRINGS",
        "CARNARVON",
        "CARP",
        "CARRYING PLACE",
        "CARTIER",
        "CASSELMAN",
        "CASTLETON",
        "CAT LAKE",
        "CATHCART",
        "CAVAN",
        "CAYUGA",
        "CEDAR POINT",
        "CEDAR SPRINGS",
        "CEDAR VALLEY",
        "CENTRALIA",
        "CENTREVILLE",
        "CHALK RIVER",
        "CHAPLEAU",
        "CHAPUT HUGHES",
        "CHARING CROSS",
        "CHARLTON",
        "CHATHAM",
        "CHATSWORTH",
        "CHELMSFORD",
        "CHELTENHAM",
        "CHEPSTOW",
        "CHERRY VALLEY",
        "CHESLEY",
        "CHESTERVILLE",
        "CHURCHILL",
        "CHUTE A BLONDEAU",
        "CLAREMONT",
        "CLARENCE CREEK",
        "CLARENDON STATION",
        "CLARKSBURG",
        "CLAYTON",
        "CLEAR CREEK",
        "CLEARWATER BAY",
        "CLIFFORD",
        "CLINTON",
        "CLOYNE",
        "COATSWORTH STATION",
        "COBALT",
        "COBDEN",
        "COBOCONK",
        "COBOURG",
        "COCHENOUR",
        "COCHRANE",
        "CODRINGTON",
        "COE HILL",
        "COLBORNE",
        "COLDWATER",
        "COLLINGWOOD",
        "COLLINS",
        "COMBER",
        "COMBERMERE",
        "COMMANDA",
        "CONCORD",
        "CONESTOGO",
        "CONISTON",
        "CONN",
        "CONNAUGHT",
        "CONSECON",
        "CONSTANCE LAKE",
        "COOKSTOWN",
        "COPETOWN",
        "COPPER CLIFF",
        "CORBEIL",
        "CORBYVILLE",
        "CORMAC",
        "CORNWALL",
        "CORUNNA",
        "COTTAM",
        "COURTICE",
        "COURTLAND",
        "COURTRIGHT",
        "CREDITON",
        "CREEMORE",
        "CROTON",
        "CRYSLER",
        "CRYSTAL BEACH",
        "CRYSTAL FALLS",
        "CUMBERLAND BEACH",
        "CUMBERLAND",
        "CURRAN",
        "CURVE LAKE",
        "CUTLER",
        "DACRE",
        "DALKEITH",
        "DASHWOOD",
        "DEEP RIVER",
        "DEER LAKE",
        "DELAWARE",
        "DELHI",
        "DELTA",
        "DEMORESTVILLE",
        "DENBIGH",
        "DENFIELD",
        "DESBARATS",
        "DESBORO",
        "DESERONTO",
        "DEUX RIVIERES",
        "DEVLIN",
        "DINORWIC",
        "DOBBINTON",
        "DOBIE",
        "DORCHESTER",
        "DORION",
        "DORSET",
        "DOUGLAS",
        "DOURO",
        "DOVER CENTRE",
        "DOWLING",
        "DRAYTON",
        "DRESDEN",
        "DRIFTWOOD",
        "DRUMBO",
        "DRYDEN",
        "DUART",
        "DUBLIN",
        "DUBREUILVILLE",
        "DUNCHURCH",
        "DUNDALK",
        "DUNDAS",
        "DUNGANNON",
        "DUNNVILLE",
        "DUNROBIN",
        "DUNSFORD",
        "DUNTROON",
        "DUNVEGAN",
        "DURHAM",
        "DUTTON",
        "DWIGHT",
        "EABAMET LAKE",
        "EAGLE LAKE",
        "EAGLE RIVER",
        "EAR FALLS",
        "EARLTON",
        "EAST GWILLIMBURY",
        "EAST YORK",
        "ECHO BAY",
        "EDEN MILLS",
        "EDEN",
        "EDWARDS",
        "EGANVILLE",
        "EGBERT",
        "EGMONDVILLE",
        "ELDORADO",
        "ELGIN",
        "ELGINBURG",
        "ELIZABETHTOWN",
        "ELK LAKE",
        "ELLIOT LAKE",
        "ELMIRA",
        "ELMVALE",
        "ELMWOOD",
        "ELORA",
        "EMBRO",
        "EMBRUN",
        "EMERYVILLE",
        "EMO",
        "EMSDALE",
        "ENGLEHART",
        "ENNISMORE",
        "ENTERPRISE",
        "ERIEAU",
        "ERIN",
        "ERINSVILLE",
        "ESPANOLA",
        "ESSEX",
        "ETHEL",
        "ETOBICOKE",
        "EVANSVILLE",
        "EVERETT",
        "EXETER",
        "FALCONBRIDGE",
        "FAUQUIER",
        "FENELON FALLS",
        "FENWICK",
        "FERGUS",
        "FEVERSHAM",
        "FIELD",
        "FINCH",
        "FINGAL",
        "FISHERVILLE",
        "FITZROY HARBOUR",
        "FLESHERTON",
        "FLINTON",
        "FLORADALE",
        "FLORENCE",
        "FOLEYET",
        "FONTHILL",
        "FORDWICH",
        "FOREST",
        "FORESTERS FALLS",
        "FORMOSA",
        "FORT ALBANY",
        "FORT ERIE",
        "FORT FRANCES",
        "FORT SEVERN",
        "FOURNIER",
        "FOXBORO",
        "FOYMOUNT",
        "FRANKFORD",
        "FRANKVILLE",
        "FRASERVILLE",
        "FREDERICKHOUSE",
        "FREELTON",
        "FULLARTON",
        "GADS HILL STATION",
        "GANANOQUE",
        "GARDEN RIVER",
        "GARDEN VILLAGE",
        "GARSON",
        "GATINEAU",
        "GEORGETOWN",
        "GERALDTON",
        "GILFORD",
        "GILMOUR",
        "GLEN HURON",
        "GLEN MORRIS",
        "GLEN ROBERTSON",
        "GLENBURNIE",
        "GLENCAIRN",
        "GLENCOE",
        "GLOUCESTER",
        "GODERICH",
        "GODFREY",
        "GOGAMA",
        "GOLDEN LAKE",
        "GOLDEN VALLEY",
        "GOODERHAM",
        "GOODWOOD",
        "GORE BAY",
        "GORES LANDING",
        "GORMLEY",
        "GORRIE",
        "GOULAIS RIVER",
        "GOWANSTOWN",
        "GOWGANDA",
        "GRAFTON",
        "GRAHAM",
        "GRAND BEND",
        "GRAND VALLEY",
        "GRANDE POINTE",
        "GRANTON",
        "GRASSIE",
        "GRASSY NARROWS",
        "GRAVENHURST",
        "GREELY",
        "GREEN VALLEY",
        "GREENBANK",
        "GREENWOOD",
        "GRIFFITH",
        "GRIMSBY",
        "GUELPH",
        "GULL BAY",
        "HAGAR",
        "HAGERSVILLE",
        "HAILEYBURY",
        "HALEY STATION",
        "HALIBURTON",
        "HALLEBOURG",
        "HAMILTON",
        "HAMMOND",
        "HAMPTON",
        "HANMER",
        "HANNON",
        "HANOVER",
        "HARCOURT",
        "HARLEY",
        "HARRIETSVILLE",
        "HARRISTON",
        "HARROW",
        "HARROWSMITH",
        "HARTINGTON",
        "HARTY",
        "HARWOOD",
        "HASTINGS",
        "HAVELOCK",
        "HAWK JUNCTION",
        "HAWKESBURY",
        "HAWKESTONE",
        "HAWKESVILLE",
        "HAY",
        "HAYDON",
        "HEARST",
        "HEATHCOTE",
        "HEIDELBERG",
        "HENSALL",
        "HEPWORTH",
        "HERON BAY",
        "HICKSON",
        "HIGHGATE",
        "HIGHLAND GROVE",
        "HILLIARDTON",
        "HILLIER",
        "HILLSBURGH",
        "HILLSDALE",
        "HILTON BEACH",
        "HOLLAND CENTRE",
        "HOLLAND LANDING",
        "HOLSTEIN",
        "HOLTYRE",
        "HOLYROOD",
        "HONEY HARBOUR",
        "HONEYWOOD",
        "HORNBY",
        "HORNELL HEIGHTS",
        "HORNEPAYNE",
        "HORNINGS MILLS",
        "HUDSON",
        "HUNTA",
        "HUNTSVILLE",
        "HURON PARK",
        "IGNACE",
        "ILDERTON",
        "INDIAN RIVER",
        "INGERSOLL",
        "INGLESIDE",
        "INGLEWOOD",
        "INGOLF",
        "INKERMAN",
        "INNERKIP",
        "INNISFIL",
        "INVERARY",
        "INWOOD",
        "IONA STATION",
        "IRON BRIDGE",
        "IRONDALE",
        "IROQUOIS FALLS A",
        "IROQUOIS FALLS",
        "IROQUOIS",
        "JACKSONS POINT",
        "JANETVILLE",
        "JARVIS",
        "JASPER",
        "JELLICOE",
        "JERSEYVILLE",
        "JOGUES",
        "JORDAN STATION",
        "JOYCEVILLE",
        "JUNIPER ISLAND",
        "KAGAWONG",
        "KAKABEKA FALLS",
        "KALADAR",
        "KAMINISTIQUIA",
        "KANATA",
        "KAPUSKASING",
        "KARS",
        "KASABONIKA",
        "KASHABOWIE",
        "KASHECHEWAN",
        "KATRINE",
        "KEARNEY",
        "KEARNS",
        "KEENE",
        "KEEWATIN",
        "KEEWAYWIN",
        "KEJICK",
        "KEMBLE",
        "KEMPTVILLE",
        "KENABEEK",
        "KENDAL",
        "KENILWORTH",
        "KENMORE",
        "KENORA",
        "KENT BRIDGE",
        "KERWOOD",
        "KESWICK",
        "KETTLEBY",
        "KILLALOE",
        "KILLARNEY",
        "KILWORTHY",
        "KIMBERLEY",
        "KINBURN",
        "KINCARDINE",
        "KING CITY",
        "KING KIRKLAND",
        "KINGFISHER LAKE",
        "KINGSTON",
        "KINGSVILLE",
        "KINMOUNT",
        "KINTORE",
        "KIPPEN",
        "KIRKFIELD",
        "KIRKLAND LAKE",
        "KIRKTON",
        "KITCHENER",
        "KLEINBURG",
        "KOMOKA",
        "L'AMABLE",
        "L'ORIGNAL",
        "LA SALETTE",
        "LAC SEUL",
        "LAKE OF BAYS",
        "LAKE ST PETER",
        "LAKEFIELD",
        "LAKEHURST",
        "LAKESIDE",
        "LANARK",
        "LANCASTER",
        "LANGTON",
        "LANSDOWNE HOUSE",
        "LANSDOWNE",
        "LARDER LAKE",
        "LASALLE",
        "LATCHFORD",
        "LAUREL",
        "LAVIGNE",
        "LEAMINGTON",
        "LEASKDALE",
        "LEFAIVRE",
        "LEFROY",
        "LEITH",
        "LEVACK",
        "LIMEHOUSE",
        "LIMOGES",
        "LINDSAY",
        "LINWOOD",
        "LIONS HEAD",
        "LISLE",
        "LISTOWEL",
        "LITTLE BRITAIN",
        "LITTLE CURRENT",
        "LIVELY",
        "LOCHLIN",
        "LOCUST HILL",
        "LOMBARDY",
        "LONDESBOROUGH",
        "LONDON",
        "LONG SAULT",
        "LONGBOW LAKE",
        "LONGFORD MILLS",
        "LONGLAC",
        "LORETTO",
        "LORING",
        "LOWBANKS",
        "LUCAN",
        "LUCKNOW",
        "LUNENBURG",
        "LYN",
        "LYNDEN",
        "LYNDHURST",
        "M'CHIGEENG",
        "MABERLY",
        "MACDIARMID",
        "MACKEY",
        "MACTIER",
        "MADAWASKA",
        "MADOC",
        "MADSEN",
        "MAGNETAWAN",
        "MAIDSTONE",
        "MAITLAND",
        "MALLORYTOWN",
        "MANILLA",
        "MANITOUWADGE",
        "MANITOWANING",
        "MANOTICK",
        "MANSFIELD",
        "MAPLE LEAF",
        "MAPLE",
        "MAR",
        "MARATHON",
        "MARKDALE",
        "MARKHAM",
        "MARKSTAY",
        "MARLBANK",
        "MARMORA",
        "MARTEN RIVER",
        "MARTINTOWN",
        "MARYHILL",
        "MARYSVILLE",
        "MASSEY",
        "MATACHEWAN",
        "MATHESON",
        "MATTAWA",
        "MATTICE",
        "MAXVILLE",
        "MAXWELL",
        "MAYNOOTH",
        "MCARTHURS MILLS",
        "MCDONALDS CORNERS",
        "MCGREGOR",
        "MCKELLAR",
        "MCKENZIE ISLAND",
        "MCKERROW",
        "MEAFORD",
        "MELBOURNE",
        "MELDRUM BAY",
        "MERLIN",
        "MERRICKVILLE",
        "METCALFE",
        "MIDHURST",
        "MIDLAND",
        "MIGISI SAHGAIGAN",
        "MILDMAY",
        "MILFORD BAY",
        "MILFORD",
        "MILLBANK",
        "MILLBROOK",
        "MILLER LAKE",
        "MILLGROVE",
        "MILTON",
        "MILVERTON",
        "MINAKI",
        "MINDEMOYA",
        "MINDEN",
        "MINE CENTRE",
        "MINESING",
        "MINETT",
        "MINNITAKI",
        "MISSANABIE",
        "MISSISSAUGA",
        "MISSISSIPPI STATION",
        "MITCHELL",
        "MOBERT",
        "MOFFAT",
        "MONETVILLE",
        "MONKLAND",
        "MONKTON",
        "MONTEITH",
        "MONTREAL RIVER HARBOUR",
        "MOONBEAM",
        "MOONSTONE",
        "MOOREFIELD",
        "MOORETOWN",
        "MOOSE CREEK",
        "MOOSE FACTORY",
        "MOOSONEE",
        "MOREWOOD",
        "MORPETH",
        "MORRISBURG",
        "MORRISTON",
        "MORSON",
        "MOSSLEY",
        "MOUNT ALBERT",
        "MOUNT BRYDGES",
        "MOUNT ELGIN",
        "MOUNT FOREST",
        "MOUNT HOPE",
        "MOUNT PLEASANT",
        "MOUNTAIN GROVE",
        "MOUNTAIN",
        "MUIRKIRK",
        "MUNCEY",
        "MUNSTER",
        "MURILLO",
        "MUSKRAT DAM",
        "NAIRN CENTRE",
        "NAKINA",
        "NANTICOKE",
        "NAPANEE",
        "NAUGHTON",
        "NAVAN",
        "NEEBING",
        "NEPEAN",
        "NESTLETON STATION",
        "NESTOR FALLS",
        "NEUSTADT",
        "NEW DUNDEE",
        "NEW HAMBURG",
        "NEW LISKEARD",
        "NEW LOWELL",
        "NEWBORO",
        "NEWBURGH",
        "NEWBURY",
        "NEWCASTLE",
        "NEWINGTON",
        "NEWMARKET",
        "NEWTON",
        "NEWTONVILLE",
        "NIAGARA FALLS",
        "NIAGARA ON THE LAKE",
        "NIPIGON",
        "NIPISSING",
        "NOBEL",
        "NOBLETON",
        "NOELVILLE",
        "NOLALU",
        "NORLAND",
        "NORTH AUGUSTA",
        "NORTH BAY",
        "NORTH BUXTON",
        "NORTH COBALT",
        "NORTH GOWER",
        "NORTH LANCASTER",
        "NORTH SPIRIT LAKE",
        "NORTH YORK",
        "NORTHBROOK",
        "NORVAL",
        "NORWICH",
        "NORWOOD",
        "NOTTAWA",
        "NOVAR",
        "OAKLAND",
        "OAKVILLE",
        "OAKWOOD",
        "OBA",
        "ODESSA",
        "OGOKI",
        "OHSWEKEN",
        "OIL CITY",
        "OIL SPRINGS",
        "OLDCASTLE",
        "OMEMEE",
        "OMPAH",
        "ONAPING",
        "OPASATIKA",
        "ORANGEVILLE",
        "ORILLIA",
        "ORLEANS",
        "ORO STATION",
        "ORO",
        "ORONO",
        "ORTON",
        "OSGOODE",
        "OSHAWA",
        "OSNABURGH HOUSE",
        "OTTAWA",
        "OTTERVILLE",
        "OWEN SOUND",
        "OXDRIFT",
        "OXFORD MILLS",
        "OXFORD STATION",
        "PAIN COURT",
        "PAISLEY",
        "PAKENHAM",
        "PALGRAVE",
        "PALMER RAPIDS",
        "PALMERSTON",
        "PARHAM",
        "PARIS",
        "PARKHILL",
        "PARRY SOUND",
        "PASS LAKE",
        "PAWITIK",
        "PAYS PLAT",
        "PEAWANUCK",
        "PEFFERLAW",
        "PELEE ISLAND",
        "PEMBROKE",
        "PENETANGUISHENE",
        "PERKINSFIELD",
        "PERRAULT FALLS",
        "PERTH ROAD",
        "PERTH",
        "PETAWAWA",
        "PETERBOROUGH",
        "PETERSBURG",
        "PETROLIA",
        "PHELPSTON",
        "PICKEREL",
        "PICKERING",
        "PICKLE LAKE",
        "PICTON",
        "PIKANGIKUM",
        "PINEWOOD",
        "PLAINFIELD",
        "PLANTAGENET",
        "PLATTSVILLE",
        "PLEVNA",
        "POINT EDWARD",
        "POINTE AUX ROCHES",
        "POINTE-AU-BARIL-STATION",
        "PONTYPOOL",
        "POOLE",
        "POPLAR HILL",
        "PORCUPINE",
        "PORQUIS JUNCTION",
        "PORT ALMA",
        "PORT BURWELL",
        "PORT CARLING",
        "PORT COLBORNE",
        "PORT DOVER",
        "PORT ELGIN",
        "PORT FRANKS",
        "PORT HOPE",
        "PORT LAMBTON",
        "PORT LORING",
        "PORT MCNICOLL",
        "PORT PERRY",
        "PORT ROBINSON",
        "PORT ROWAN",
        "PORT SANDFIELD",
        "PORT SEVERN",
        "PORT STANLEY",
        "PORT SYDNEY",
        "PORTLAND",
        "POWASSAN",
        "PRESCOTT",
        "PRICEVILLE",
        "PRINCE ALBERT",
        "PRINCETON",
        "PROTON STATION",
        "PROVIDENCE BAY",
        "PUSLINCH",
        "PUTNAM",
        "QUADEVILLE",
        "QUEENSTON",
        "QUEENSVILLE",
        "RAINY RIVER",
        "RAITH",
        "RAMA",
        "RAMORE",
        "RAMSAYVILLE",
        "RAMSEY",
        "RAVENNA",
        "REABORO",
        "RED LAKE",
        "RED ROCK",
        "REDBRIDGE",
        "REDDITT",
        "RENFREW",
        "RESTOULE",
        "RICHARDS LANDING",
        "RICHMOND HILL",
        "RICHMOND",
        "RIDEAU FERRY",
        "RIDGETOWN",
        "RIDGEVILLE",
        "RIDGEWAY",
        "RIPLEY",
        "RIVER DRIVE PARK",
        "RIVER VALLEY",
        "ROBLIN",
        "ROCHES POINT",
        "ROCKCLIFFE",
        "ROCKLAND",
        "ROCKPORT",
        "ROCKTON",
        "ROCKWOOD",
        "RODNEY",
        "ROLPHTON",
        "ROSEMONT",
        "ROSENEATH",
        "ROSLIN",
        "ROSSEAU",
        "ROSSPORT",
        "ROSTOCK",
        "ROUND LAKE CENTRE",
        "RUSCOM STATION",
        "RUSSELL",
        "RUTHERGLEN",
        "RUTHVEN",
        "SACHIGO LAKE",
        "SAINT-PASCAL-BAYLON",
        "SALFORD",
        "SANDFORD",
        "SANDY LAKE",
        "SARNIA",
        "SARSFIELD",
        "SAUBLE BEACH",
        "SAULT STE. MARIE",
        "SAVANT LAKE",
        "SCARBOROUGH",
        "SCHOMBERG",
        "SCHREIBER",
        "SCHUMACHER",
        "SCOTLAND",
        "SEAFORTH",
        "SEAGRAVE",
        "SEARCHMONT",
        "SEBRIGHT",
        "SEBRINGVILLE",
        "SEELEYS BAY",
        "SELBY",
        "SELKIRK",
        "SERPENT RIVER",
        "SESEKINIKA",
        "SEVERN BRIDGE",
        "SHAKESPEARE",
        "SHALLOW LAKE",
        "SHANNONVILLE",
        "SHANTY BAY",
        "SHARBOT LAKE",
        "SHARON",
        "SHEBANDOWAN",
        "SHEDDEN",
        "SHEFFIELD",
        "SHEGUIANDAH",
        "SHELBURNE",
        "SHERKSTON",
        "SHESHEGWANING",
        "SHINING TREE",
        "SILVER WATER",
        "SIMCOE",
        "SINGHAMPTON",
        "SIOUX LOOKOUT",
        "SIOUX NARROWS",
        "SKEAD",
        "SLATE FALLS",
        "SLEEMAN",
        "SMITHS FALLS",
        "SMITHVILLE",
        "SMOOTH ROCK FALLS",
        "SNOW ROAD STATION",
        "SOMBRA",
        "SOUTH BAYMOUTH",
        "SOUTH GILLIES",
        "SOUTH LANCASTER",
        "SOUTH MOUNTAIN",
        "SOUTH PORCUPINE",
        "SOUTH RIVER",
        "SOUTH WOODSLEE",
        "SOUTHAMPTON",
        "SOUTHWOLD",
        "SPANISH",
        "SPARTA",
        "SPENCERVILLE",
        "SPRAGGE",
        "SPRING BAY",
        "SPRINGBROOK",
        "SPRINGFIELD",
        "SPRINGFORD",
        "SPRUCEDALE",
        "ST AGATHA",
        "ST ALBERT",
        "ST ANDREWS WEST",
        "ST ANNS",
        "ST BERNARDIN",
        "ST CATHARINES",
        "ST CHARLES",
        "ST CLEMENTS",
        "ST DAVIDS",
        "ST EUGENE",
        "ST GEORGE BRANT",
        "ST ISIDORE",
        "ST JACOBS",
        "ST JOACHIM",
        "ST MARYS",
        "ST PAULS STATION",
        "ST THOMAS",
        "ST WILLIAMS",
        "STAFFA",
        "STAPLES",
        "STAYNER",
        "STE ANNE DE PRESCOTT",
        "STELLA",
        "STEVENSVILLE",
        "STIRLING",
        "STITTSVILLE",
        "STOKES BAY",
        "STONECLIFFE",
        "STONEY CREEK",
        "STOUFFVILLE",
        "STRAFFORDVILLE",
        "STRATFORD",
        "STRATHROY",
        "STRATTON",
        "STRICKLAND",
        "STURGEON FALLS",
        "SUDBURY",
        "SULTAN",
        "SUMMER BEAVER",
        "SUMMERSTOWN",
        "SUNDERLAND",
        "SUNDRIDGE",
        "SUTTON WEST",
        "SWASTIKA",
        "SYDENHAM",
        "TALBOTVILLE ROYAL",
        "TAMWORTH",
        "TARA",
        "TARZWELL",
        "TAVISTOCK",
        "TECUMSEH",
        "TEESWATER",
        "TEETERVILLE",
        "TEHKUMMAH",
        "TEMAGAMI",
        "TERRA COTTA",
        "TERRACE BAY",
        "THAMESFORD",
        "THAMESVILLE",
        "THEDFORD",
        "THESSALON",
        "THOMASBURG",
        "THORNBURY",
        "THORNDALE",
        "THORNE",
        "THORNHILL",
        "THORNLOE",
        "THORNTON",
        "THOROLD",
        "THUNDER BAY",
        "TICHBORNE",
        "TILBURY",
        "TILDEN LAKE",
        "TILLSONBURG",
        "TIMMINS",
        "TIVERTON",
        "TOBERMORY",
        "TOLEDO",
        "TORONTO",
        "TORRANCE",
        "TORY HILL",
        "TOTTENHAM",
        "TOWNSEND",
        "TRENT RIVER",
        "TRENTON",
        "TROUT CREEK",
        "TROY",
        "TUNIS",
        "TUPPERVILLE",
        "TURKEY POINT",
        "TWEED",
        "UDORA",
        "UNION",
        "UNIONVILLE",
        "UPPER CANADA VILLAGE",
        "UPSALA",
        "UTOPIA",
        "UTTERSON",
        "UXBRIDGE",
        "VAL CARON",
        "VAL COTE",
        "VAL GAGNE",
        "VAL RITA",
        "VAL THERESE",
        "VANESSA",
        "VANIER",
        "VANKLEEK HILL",
        "VARNA",
        "VARS",
        "VAUGHAN",
        "VERMILION BAY",
        "VERNER",
        "VERNON",
        "VERONA",
        "VICTORIA HARBOUR",
        "VIENNA",
        "VINELAND STATION",
        "VINELAND",
        "VIRGIL",
        "VIRGINIATOWN",
        "VITTORIA",
        "WABIGOON",
        "WAHNAPITAE",
        "WAINFLEET",
        "WALDHOF",
        "WALFORD STATION",
        "WALKERTON",
        "WALLACEBURG",
        "WALLACETOWN",
        "WALLENSTEIN",
        "WALSINGHAM",
        "WALTERS FALLS",
        "WALTON",
        "WARDSVILLE",
        "WARKWORTH",
        "WARMINSTER",
        "WARREN",
        "WARSAW",
        "WASAGA BEACH",
        "WASHAGO",
        "WATERDOWN",
        "WATERFORD",
        "WATERLOO",
        "WATFORD",
        "WAUBAUSHENE",
        "WAWA",
        "WEAGAMOW LAKE",
        "WEBBWOOD",
        "WEBEQUIE",
        "WELLAND",
        "WELLANDPORT",
        "WELLESLEY",
        "WELLINGTON",
        "WENDOVER",
        "WEST GUILFORD",
        "WEST LORNE",
        "WEST MONTROSE",
        "WESTBROOK",
        "WESTMEATH",
        "WESTPORT",
        "WESTWOOD",
        "WHEATLEY",
        "WHITBY",
        "WHITE LAKE",
        "WHITE RIVER",
        "WHITEDOG",
        "WHITEFISH FALLS",
        "WHITEFISH",
        "WHITEVALE",
        "WHITNEY",
        "WIARTON",
        "WIKWEMIKONG",
        "WILBERFORCE",
        "WILKESPORT",
        "WILLIAMSBURG",
        "WILLIAMSFORD",
        "WILLIAMSTOWN",
        "WILLOW BEACH",
        "WILMOT",
        "WILNO",
        "WILSONVILLE",
        "WINCHESTER SPRINGS",
        "WINCHESTER",
        "WINDERMERE",
        "WINDHAM CENTRE",
        "WINDSOR",
        "WINGHAM",
        "WOLFE ISLAND",
        "WOODBRIDGE",
        "WOODHAM",
        "WOODLAWN",
        "WOODSTOCK",
        "WOODVIEW",
        "WOODVILLE",
        "WOOLER",
        "WORTHINGTON",
        "WROXETER",
        "WUNNUMIN LAKE",
        "WYEBRIDGE",
        "WYEVALE",
        "WYOMING",
        "YARKER",
        "YORK",
        "YORK.",
        "YOUNGS POINT",
        "ZEPHYR",
        "ZURICH",
    ],
    "PE": [
        "ALBANY",
        "ALBERTON",
        "BEDEQUE",
        "BELFAST",
        "BELLE RIVER",
        "BLOOMFIELD STATION",
        "BONSHAW",
        "BORDEN-CARLETON",
        "BREADALBANE",
        "CARDIGAN",
        "CENTRAL BEDEQUE",
        "CHARLOTTETOWN",
        "COLEMAN",
        "CORNWALL",
        "CRAPAUD",
        "ELLERSLIE",
        "ELMIRA",
        "ELMSDALE",
        "FREETOWN",
        "GEORGETOWN",
        "GREEN GABLES",
        "KENSINGTON",
        "KINKORA",
        "LENNOX ISLAND",
        "MIMINEGASH",
        "MISCOUCHE",
        "MONTAGUE",
        "MORELL",
        "MOUNT STEWART",
        "MURRAY HARBOUR",
        "MURRAY RIVER",
        "NEW GLASGOW",
        "NORTH RUSTICO",
        "NORTH WILTSHIRE",
        "O'LEARY",
        "POWNAL",
        "RICHMOND",
        "SLEMON PARK",
        "SOURIS",
        "ST-LOUIS",
        "ST-PETERS BAY",
        "STRATFORD",
        "SUMMERSIDE",
        "TIGNISH",
        "TYNE VALLEY",
        "VERNON BRIDGE",
        "VICTORIA",
        "WELLINGTON STATION",
        "WINSLOE",
        "YORK",
    ],
    "QC": [
        "ABERCORN",
        "ACTON VALE",
        "ADSTOCK",
        "AGUANISH",
        "AKULIVIK",
        "AKWESASNE",
        "ALBANEL",
        "ALBERTVILLE",
        "ALCOVE",
        "ALMA",
        "ALOUETTE",
        "AMHERST",
        "AMOS",
        "AMQUI",
        "ANGE-GARDIEN",
        "ANGLIERS",
        "ANJOU",
        "ARMAGH",
        "ARNTFIELD",
        "ARUNDEL",
        "ASBESTOS",
        "ASCOT CORNER",
        "ASTON-JONCTION",
        "ATHELSTAN",
        "AUCLAIR",
        "AUDET",
        "AUMOND",
        "AUPALUK",
        "AUSTIN",
        "AUTHIER",
        "AUTHIER-NORD",
        "AYER'S CLIFF",
        "BAIE-COMEAU",
        "BAIE-D'URFE",
        "BAIE-DES-SABLES",
        "BAIE-DU-FEBVRE",
        "BAIE-JOHAN-BEETZ",
        "BAIE-SAINT-PAUL",
        "BAIE-SAINTE-CATHERINE",
        "BAIE-TRINITE",
        "BARACHOIS",
        "BARKMERE",
        "BARRAUTE",
        "BASSIN",
        "BATISCAN",
        "BEACONSFIELD",
        "BEARN",
        "BEAUCANTON",
        "BEAUCEVILLE",
        "BEAUHARNOIS",
        "BEAULAC-GARTHBY",
        "BEAUMONT",
        "BEAUPRE",
        "BECANCOUR",
        "BEDFORD",
        "BEGIN",
        "BELCOURT",
        "BELLECOMBE",
        "BELLETERRE",
        "BELOEIL",
        "BERRY",
        "BERTHIER-SUR-MER",
        "BERTHIERVILLE",
        "BETHANIE",
        "BETSIAMITES",
        "BIENCOURT",
        "BISHOPTON",
        "BLAINVILLE",
        "BLANC-SABLON",
        "BLUE SEA",
        "BOILEAU",
        "BOIS-DES-FILION",
        "BOIS-FRANC",
        "BOISBRIAND",
        "BOISCHATEL",
        "BOLTON-EST",
        "BOLTON-OUEST",
        "BON-CONSEIL",
        "BONAVENTURE",
        "BONSECOURS",
        "BOUCHERVILLE",
        "BOUCHETTE",
        "BOULANGER",
        "BOWMAN",
        "BRADOR",
        "BREBEUF",
        "BRIGHAM",
        "BRISTOL",
        "BROME",
        "BROMONT",
        "BROSSARD",
        "BROWNSBURG-CHATHAM",
        "BRYSON",
        "BUCKLAND",
        "BURY",
        "CABANO",
        "CACOUNA",
        "CADILLAC",
        "CALIXA-LAVALLEE",
        "CAMPBELL'S BAY",
        "CANDIAC",
        "CANTLEY",
        "CANTON BEDFORD",
        "CANTON STANSTEAD",
        "CANTON TREMBLAY",
        "CANTON-DE-HATLEY",
        "CAP-AU-RENARD",
        "CAP-AUX-MEULES",
        "CAP-CHAT",
        "CAP-CHAT-EST",
        "CAP-D'ESPOIR",
        "CAP-SAINT-IGNACE",
        "CAP-SANTE",
        "CAPLAN",
        "CAPUCINS",
        "CARIGNAN",
        "CARLETON",
        "CASCAPEDIA-SAINT-JULES",
        "CAUSAPSCAL",
        "CAZAVILLE",
        "CHAMBLY",
        "CHAMBORD",
        "CHAMPLAIN",
        "CHAMPNEUF",
        "CHANDLER",
        "CHAPAIS",
        "CHAPEAU",
        "CHARETTE",
        "CHARLEMAGNE",
        "CHARNY",
        "CHARTIERVILLE",
        "CHATEAU-RICHER",
        "CHATEAUGUAY",
        "CHAZEL",
        "CHELSEA",
        "CHENEVILLE",
        "CHERTSEY",
        "CHESTERVILLE",
        "CHEVERY",
        "CHIBOUGAMAU",
        "CHICOUTIMI",
        "CHISASIBI",
        "CHOMEDEY",
        "CHUTE-AUX-OUTARDES",
        "CHUTE-SAINT-PHILIPPE",
        "CLARENCEVILLE",
        "CLARKE CITY",
        "CLERICY",
        "CLERMONT",
        "CLERVAL",
        "CLEVELAND",
        "CLORIDORME",
        "CLOUTIER",
        "CLOVA",
        "COATICOOK",
        "COLOMBIER",
        "COMPTON",
        "CONTRECOEUR",
        "COOKSHIRE-EATON",
        "COTE SAINT-LUC",
        "COTEAU-DU-LAC",
        "COURCELETTE",
        "COURCELLES",
        "COWANSVILLE",
        "CRABTREE",
        "D'ALEMBERT",
        "DALHOUSIE",
        "DALMAS",
        "DANFORD LAKE",
        "DANVILLE",
        "DAVELUYVILLE",
        "DAVIDSON",
        "DEGELIS",
        "DELEAGE",
        "DELSON",
        "DENHOLM",
        "DESBIENS",
        "DESCHAILLONS-SUR-SAINT-LAURENT",
        "DESCHAMBAULT",
        "DESMARAISVILLE",
        "DESMELOIZES",
        "DESTOR",
        "DEUX-MONTAGNES",
        "DEWITTVILLE",
        "DISRAELI",
        "DIXVILLE",
        "DOLBEAU-MISTASSINI",
        "DOLLARD-DES-ORMEAUX",
        "DONNACONA",
        "DORVAL",
        "DOSQUET",
        "DRUMMONDVILLE",
        "DUCLOS",
        "DUHAMEL",
        "DUHAMEL-OUEST",
        "DUNHAM",
        "DUPARQUET",
        "DUPUY",
        "DURHAM-SUD",
        "EAST ANGUS",
        "EAST BROUGHTON STATION",
        "EAST BROUGHTON",
        "EAST FARNHAM",
        "EAST HEREFORD",
        "EASTMAIN",
        "EASTMAN",
        "EGAN",
        "ELGIN",
        "EM-1-A-SARCELLE-RUPERT",
        "ENTRELACS",
        "ESCUMINAC",
        "ESPRIT-SAINT",
        "ESTEREL",
        "EVAIN",
        "FABRE",
        "FABREVILLE",
        "FALARDEAU",
        "FARNHAM",
        "FARRELLTON",
        "FASSETT",
        "FATIMA",
        "FERLAND-ET-BOILLEAU",
        "FERME-NEUVE",
        "FERMONT",
        "FORESTVILLE",
        "FORT-COULONGE",
        "FORTIERVILLE",
        "FOSSAMBAULT-SUR-LE-LAC",
        "FOSTER",
        "FRAMPTON",
        "FRANKLIN",
        "FRANQUELIN",
        "FRELIGHSBURG",
        "FRONTENAC",
        "FUGEREVILLE",
        "FULFORD",
        "GALLICHAN",
        "GALLIX",
        "GASCONS",
        "GASPE",
        "GATINEAU",
        "GEORGEVILLE",
        "GETHSEMANI",
        "GIRARDVILLE",
        "GODBOUT",
        "GODMANCHESTER",
        "GORE",
        "GRACEFIELD",
        "GRANBY",
        "GRAND-MERE",
        "GRAND-REMOUS",
        "GRAND-SAINT-ESPRIT",
        "GRANDE-ENTREE",
        "GRANDE-RIVIERE",
        "GRANDE-RIVIERE-OUEST",
        "GRANDE-VALLEE",
        "GRANDES-BERGERONNES",
        "GRANDES-PILES",
        "GREENFIELD PARK",
        "GRENVILLE",
        "GRENVILLE-SUR-LA-ROUGE",
        "GRONDINES",
        "GROS-MORNE",
        "GROSSE-ILE",
        "GROSSES-ROCHES",
        "GUERIN",
        "GUYENNE",
        "HAM-NORD",
        "HAMPSTEAD",
        "HARRINGTON HARBOUR",
        "HARRINGTON",
        "HATLEY",
        "HAVELOCK",
        "HAVRE-AUBERT",
        "HAVRE-AUX-MAISONS",
        "HAVRE-SAINT-PIERRE",
        "HEBERTVILLE",
        "HEBERTVILLE-STATION",
        "HEMMINGFORD",
        "HENRYVILLE",
        "HEROUXVILLE",
        "HINCHINBROOKE",
        "HONFLEUR",
        "HOPE",
        "HOWICK",
        "HUBERDEAU",
        "HUDSON HEIGHTS",
        "HUDSON",
        "HUNTINGDON",
        "ILE DU GRAND-CALUMET",
        "ILE-AUX-NOIX",
        "INUKJUAK",
        "INVERNESS",
        "IRLANDE",
        "ISLE-AUX-COUDRES",
        "ISSOUDUN",
        "IVRY-SUR-LE-LAC",
        "IVUJIVIK",
        "JACQUES-CARTIER",
        "JOLIETTE",
        "JOLY",
        "JONQUIERE",
        "KAHNAWAKE",
        "KAMOURASKA",
        "KANGIQSUALUJJUAQ",
        "KANGIQSUJUAQ",
        "KANGIRSUK",
        "KAWAWACHIKAMACH",
        "KAZABAZUA",
        "KEGASKA",
        "KIAMIKA",
        "KINGSBURY",
        "KINGSEY FALLS",
        "KINNEAR'S MILLS",
        "KIPAWA",
        "KIRKLAND",
        "KNOWLTON",
        "KUUJJUAQ",
        "KUUJJUARAPIK",
        "L'ALVERNE",
        "L'ANCIENNE-LORETTE",
        "L'ANGE GARDIEN",
        "L'ANGE-GARDIEN",
        "L'ANSE-PLEUREUSE",
        "L'ANSE-SAINT-JEAN",
        "L'ASCENSION",
        "L'ASCENSION-DE-NOTRE-SEIGNEUR",
        "L'ASCENSION-DE-PATAPEDIA",
        "L'ASSOMPTION",
        "L'AVENIR",
        "L'EPIPHANIE",
        "L'ETANG-DU-NORD",
        "L'ILE-BIZARD",
        "L'ILE-CADIEUX",
        "L'ILE-D'ENTREE",
        "L'ILE-MICHON",
        "L'ILE-PERROT",
        "L'ISLE-AUX-GRUES",
        "L'ISLE-VERTE",
        "L'ISLET",
        "L'ISLETVILLE",
        "LA BAIE",
        "LA BALEINE",
        "LA BOSTONNAIS",
        "LA CONCEPTION",
        "LA CORNE",
        "LA CROCHE",
        "LA DORE",
        "LA DURANTAYE",
        "LA GUADELOUPE",
        "LA MACAZA",
        "LA MALBAIE",
        "LA MARTRE",
        "LA MINERVE",
        "LA MORANDIERE",
        "LA MOTTE",
        "LA PATRIE",
        "LA POCATIERE",
        "LA PRAIRIE",
        "LA PRESENTATION",
        "LA REDEMPTION",
        "LA REINE",
        "LA SARRE",
        "LA TABATIERE",
        "LA TRINITE-DES-MONTS",
        "LA TUQUE",
        "LA VISITATION-DE-L'ILE-DUPAS",
        "LA VISITATION-DE-YAMASKA",
        "LABELLE",
        "LABRECQUE",
        "LAC DES LOUPS",
        "LAC-A-LA-TORTUE",
        "LAC-AU-SAUMON",
        "LAC-AUX-SABLES",
        "LAC-BEAUPORT",
        "LAC-BOUCHETTE",
        "LAC-CAYAMANT",
        "LAC-DELAGE",
        "LAC-DES-AIGLES",
        "LAC-DES-ECORCES",
        "LAC-DES-ILES",
        "LAC-DES-PLAGES",
        "LAC-DES-SEIZE-ILES",
        "LAC-DROLET",
        "LAC-DU-CERF",
        "LAC-EDOUARD",
        "LAC-ETCHEMIN",
        "LAC-FRONTIERE",
        "LAC-HUMQUI",
        "LAC-KENOGAMI",
        "LAC-MEGANTIC",
        "LAC-SAGUAY",
        "LAC-SAINT-JOSEPH",
        "LAC-SAINT-PAUL",
        "LAC-SAINTE-MARIE",
        "LAC-SERGENT",
        "LAC-SIMON",
        "LAC-SUPERIEUR",
        "LACHINE",
        "LACHUTE",
        "LACOLLE",
        "LADRIERE",
        "LADYSMITH",
        "LAFORCE",
        "LAMARCHE",
        "LAMARTINE",
        "LAMBTON",
        "LANDRIENNE",
        "LANIEL",
        "LANORAIE",
        "LANTIER",
        "LAROUCHE",
        "LASALLE",
        "LATERRIERE",
        "LATULIPE",
        "LAUNAY",
        "LAURIER-STATION",
        "LAURIERVILLE",
        "LAVAL",
        "LAVAL-OUEST",
        "LAVALTRIE",
        "LAVERLOCHERE",
        "LAWRENCEVILLE",
        "LE BIC",
        "LE GARDEUR",
        "LEBEL-SUR-QUEVILLON",
        "LECLERCVILLE",
        "LEFEBVRE",
        "LEJEUNE",
        "LEMIEUX",
        "LEMOYNE",
        "LERY",
        "LES BUISSONS",
        "LES CEDRES",
        "LES COTEAUX",
        "LES EBOULEMENTS",
        "LES ESCOUMINS",
        "LES HAUTEURS",
        "LES MECHINS",
        "LEVIS",
        "LINGWICK",
        "LISTUGUJ",
        "LONGUE-POINTE-DE-MINGAN",
        "LONGUE-RIVE",
        "LONGUEUIL",
        "LORRAINE",
        "LORRAINVILLE",
        "LOTBINIERE",
        "LOTS-RENVERSES",
        "LOUISEVILLE",
        "LOURDES",
        "LOURDES-DE-BLANC-SABLON",
        "LOURDES-DE-JOLIETTE",
        "LOW",
        "LUSKVILLE",
        "LYSTER",
        "MACAMIC",
        "MADDINGTON",
        "MADELEINE-CENTRE",
        "MAGOG",
        "MAGPIE",
        "MALARTIC",
        "MALIOTENAM",
        "MANCEBOURG",
        "MANCHE-D'EPEE",
        "MANDEVILLE",
        "MANIWAKI",
        "MANOUANE",
        "MANSEAU",
        "MANSFIELD",
        "MANSONVILLE",
        "MAPLE GROVE",
        "MARBLETON",
        "MARIA",
        "MARICOURT",
        "MARIEVILLE",
        "MARSOUI",
        "MARSTON",
        "MARTINVILLE",
        "MASCOUCHE",
        "MASHTEUIATSH",
        "MASKINONGE",
        "MASSUEVILLE",
        "MATAGAMI",
        "MATANE",
        "MATAPEDIA",
        "MAYO",
        "MCMASTERVILLE",
        "MCWATTERS",
        "MELBOURNE",
        "MELOCHEVILLE",
        "MERCIER",
        "MESSINES",
        "METABETCHOUAN-LAC-A-LA-CROIX",
        "METIS-SUR-MER",
        "MIDDLE BAY",
        "MILAN",
        "MILLE-ISLES",
        "MIQUELON",
        "MIRABEL",
        "MISTISSINI",
        "MOFFET",
        "MOISIE",
        "MONT-BRUN",
        "MONT-CARMEL",
        "MONT-JOLI",
        "MONT-LAURIER",
        "MONT-LOUIS",
        "MONT-ROYAL",
        "MONT-SAINT-GREGOIRE",
        "MONT-SAINT-HILAIRE",
        "MONT-SAINT-MICHEL",
        "MONT-SAINT-PIERRE",
        "MONT-TREMBLANT",
        "MONTBEILLARD",
        "MONTCALM",
        "MONTCERF-LYTTON",
        "MONTEBELLO",
        "MONTMAGNY",
        "MONTPELLIER",
        "MONTREAL",
        "MONTREAL-EST",
        "MONTREAL-NORD",
        "MONTREAL-OUEST",
        "MORIN-HEIGHTS",
        "MULGRAVE-ET-DERRY",
        "MURDOCHVILLE",
        "MUTTON BAY",
        "NAMUR",
        "NANTES",
        "NAPIERVILLE",
        "NATASHQUAN",
        "NEDELEC",
        "NEMISCAU",
        "NEUVILLE",
        "NEW CARLISLE",
        "NEW RICHMOND",
        "NEWPORT",
        "NICOLET",
        "NOMININGUE",
        "NORMANDIN",
        "NORMETAL",
        "NORTH HATLEY",
        "NOTRE-DAME-DE-HAM",
        "NOTRE-DAME-DE-L'ILE-PERROT",
        "NOTRE-DAME-DE-LA-MERCI",
        "NOTRE-DAME-DE-LA-PAIX",
        "NOTRE-DAME-DE-LA-SALETTE",
        "NOTRE-DAME-DE-LORETTE",
        "NOTRE-DAME-DE-MONTAUBAN",
        "NOTRE-DAME-DE-PONTMAIN",
        "NOTRE-DAME-DE-STANBRIDGE",
        "NOTRE-DAME-DES-BOIS",
        "NOTRE-DAME-DES-MONTS",
        "NOTRE-DAME-DES-PINS",
        "NOTRE-DAME-DES-PRAIRIES",
        "NOTRE-DAME-DES-SEPT-DOULEURS",
        "NOTRE-DAME-DU-LAC",
        "NOTRE-DAME-DU-LAUS",
        "NOTRE-DAME-DU-MONT-CARMEL",
        "NOTRE-DAME-DU-NORD",
        "NOTRE-DAME-DU-PORTAGE",
        "NOTRE-DAME-DU-ROSAIRE",
        "NOUVELLE",
        "NOUVELLE-OUEST",
        "NOYAN",
        "OBEDJIWAN",
        "ODANAK",
        "OGDEN",
        "OKA",
        "OLD FORT BAY",
        "ORFORD",
        "ORMSTOWN",
        "OTTER LAKE",
        "OTTERBURN PARK",
        "OUJE-BOUGOUMOU",
        "OUTREMONT",
        "PABOS MILLS",
        "PABOS",
        "PACKINGTON",
        "PADOUE",
        "PALMAROLLE",
        "PAPINEAUVILLE",
        "PARENT",
        "PARISVILLE",
        "PASPEBIAC",
        "PERCE",
        "PERIBONKA",
        "PETIT-SAGUENAY",
        "PETITE-RIVIERE-SAINT-FRANCOIS",
        "PETITE-VALLEE",
        "PHILIPSBURG",
        "PIEDMONT",
        "PIERREFONDS",
        "PIERREVILLE",
        "PIKE RIVER",
        "PINCOURT",
        "PINTENDRE",
        "PIOPOLIS",
        "PLAISANCE",
        "PLESSISVILLE",
        "POHENEGAMOOK",
        "POINTE-A-LA-CROIX",
        "POINTE-A-LA-GARDE",
        "POINTE-AUX-LOUPS",
        "POINTE-AUX-OUTARDES",
        "POINTE-AUX-TREMBLES",
        "POINTE-CALUMET",
        "POINTE-CLAIRE",
        "POINTE-DES-CASCADES",
        "POINTE-FORTUNE",
        "POINTE-LEBEL",
        "PONT-ROUGE",
        "PORT-CARTIER",
        "PORT-DANIEL",
        "PORT-MENIER",
        "PORTAGE-DU-FORT",
        "PORTNEUF",
        "PORTNEUF-SUR-MER",
        "POULARIES",
        "PREISSAC",
        "PREVOST",
        "PRICE",
        "PRINCEVILLE",
        "PROULXVILLE",
        "PUVIRNITUQ",
        "QUAQTAQ",
        "QUEBEC",
        "QUYON",
        "RACINE",
        "RADISSON",
        "RAGUENEAU",
        "RAPID LAKE",
        "RAPIDE-DANSEUR",
        "RAPIDES-DES-JOACHIMS",
        "RAVIGNAN",
        "RAWDON",
        "REMIGNY",
        "REPENTIGNY",
        "RICHELIEU",
        "RICHMOND",
        "RIGAUD",
        "RIMOUSKI",
        "RIPON",
        "RIVIERE-A-CLAUDE",
        "RIVIERE-A-PIERRE",
        "RIVIERE-AU-TONNERRE",
        "RIVIERE-BEAUDETTE",
        "RIVIERE-BLEUE",
        "RIVIERE-DU-LOUP",
        "RIVIERE-ETERNITE",
        "RIVIERE-HEVA",
        "RIVIERE-MADELEINE",
        "RIVIERE-OUELLE",
        "RIVIERE-PASPEBIAC",
        "RIVIERE-PENTECOTE",
        "RIVIERE-ROUGE",
        "RIVIERE-SAINT-JEAN",
        "RIVIERE-SAINT-PAUL",
        "RIVIERE-TROIS-PISTOLES",
        "ROBERVAL",
        "ROCHEBAUCOURT",
        "ROLLET",
        "ROQUEMAURE",
        "ROSEMERE",
        "ROUGEMONT",
        "ROUTHIERVILLE",
        "ROUYN-NORANDA",
        "ROXBORO",
        "ROXTON FALLS",
        "ROXTON POND",
        "RUISSEAU-A-REBOURS",
        "SABREVOIS",
        "SACRE-COEUR-SAGUENAY",
        "SAINT-ADALBERT",
        "SAINT-ADELME",
        "SAINT-ADELPHE-DE-CHAMPLAIN",
        "SAINT-ADOLPHE-D'HOWARD",
        "SAINT-ADRIEN",
        "SAINT-ADRIEN-D'IRLANDE",
        "SAINT-AGAPIT",
        "SAINT-AIME",
        "SAINT-AIME-DES-LACS",
        "SAINT-ALBAN",
        "SAINT-ALBERT",
        "SAINT-ALEXANDRE-D'IBERVILLE",
        "SAINT-ALEXANDRE-DE-KAMOURASKA",
        "SAINT-ALEXANDRE-DES-LACS",
        "SAINT-ALEXIS-DE-MATAPEDIA",
        "SAINT-ALEXIS-DE-MONTCALM",
        "SAINT-ALEXIS-DES-MONTS",
        "SAINT-ALFRED",
        "SAINT-ALPHONSE-DE-CAPLAN",
        "SAINT-ALPHONSE-DE-GRANBY",
        "SAINT-ALPHONSE-RODRIGUEZ",
        "SAINT-AMABLE",
        "SAINT-AMBROISE",
        "SAINT-AMBROISE-DE-KILDARE",
        "SAINT-ANACLET",
        "SAINT-ANDRE-AVELLIN",
        "SAINT-ANDRE-D'ARGENTEUIL",
        "SAINT-ANDRE-DE-KAMOURASKA",
        "SAINT-ANDRE-DE-RESTIGOUCHE",
        "SAINT-ANDRE-DU-LAC-SAINT-JEAN",
        "SAINT-ANICET",
        "SAINT-ANSELME",
        "SAINT-ANTOINE-ABBE",
        "SAINT-ANTOINE-DE-TILLY",
        "SAINT-ANTOINE-SUR-RICHELIEU",
        "SAINT-ANTONIN",
        "SAINT-APOLLINAIRE",
        "SAINT-ARMAND",
        "SAINT-ARSENE",
        "SAINT-AUBERT",
        "SAINT-AUGUSTIN-DE-DESMAURES",
        "SAINT-AUGUSTIN-SAGUENAY",
        "SAINT-BARNABE-SUD",
        "SAINT-BARTHELEMY",
        "SAINT-BASILE",
        "SAINT-BASILE-LE-GRAND",
        "SAINT-BENJAMIN",
        "SAINT-BENOIT-DU-LAC",
        "SAINT-BENOIT-LABRE",
        "SAINT-BERNARD",
        "SAINT-BERNARD-DE-LACOLLE",
        "SAINT-BERNARD-DE-MICHAUDVILLE",
        "SAINT-BERNARD-SUR-MER",
        "SAINT-BLAISE-SUR-RICHELIEU",
        "SAINT-BONAVENTURE",
        "SAINT-BONIFACE-DE-SHAWINIGAN",
        "SAINT-BRUNO",
        "SAINT-BRUNO-DE-GUIGUES",
        "SAINT-BRUNO-DE-KAMOURASKA",
        "SAINT-BRUNO-LAC-SAINT-JEAN",
        "SAINT-CALIXTE",
        "SAINT-CAMILLE",
        "SAINT-CAMILLE-DE-BELLECHASSE",
        "SAINT-CASIMIR",
        "SAINT-CELESTIN",
        "SAINT-CESAIRE",
        "SAINT-CHARLES-BORROMEE",
        "SAINT-CHARLES-DE-BELLECHASSE",
        "SAINT-CHARLES-DE-BOURGET",
        "SAINT-CHARLES-DE-DRUMMOND",
        "SAINT-CHARLES-GARNIER",
        "SAINT-CHARLES-SUR-RICHELIEU",
        "SAINT-CHRISTOPHE-D'ARTHABASKA",
        "SAINT-CHRYSOSTOME",
        "SAINT-CLAUDE",
        "SAINT-CLEMENT",
        "SAINT-CLEOPHAS",
        "SAINT-CLEOPHAS-DE-BRANDON",
        "SAINT-CLET",
        "SAINT-COLOMBAN",
        "SAINT-COME",
        "SAINT-COME-LINIERE",
        "SAINT-CONSTANT",
        "SAINT-CUTHBERT",
        "SAINT-CYPRIEN",
        "SAINT-CYPRIEN-DES-ETCHEMINS",
        "SAINT-CYRILLE-DE-L'ISLET",
        "SAINT-CYRILLE-DE-WENDOVER",
        "SAINT-DAMASE",
        "SAINT-DAMASE-DE-MATAPEDIA",
        "SAINT-DAMASE-DES-AULNAIES",
        "SAINT-DAMIEN",
        "SAINT-DAMIEN-DE-BUCKLAND",
        "SAINT-DAVID",
        "SAINT-DENIS-DE-BROMPTON",
        "SAINT-DENIS-DE-LA-BOUTEILLERIE",
        "SAINT-DENIS-SUR-RICHELIEU",
        "SAINT-DIDACE",
        "SAINT-DOMINIQUE",
        "SAINT-DOMINIQUE-DU-ROSAIRE",
        "SAINT-DONAT",
        "SAINT-DONAT-DE-MONTCALM",
        "SAINT-EDMOND-DE-GRANTHAM",
        "SAINT-EDMOND-LES-PLAINES",
        "SAINT-EDOUARD-DE-LOTBINIERE",
        "SAINT-EDOUARD-DE-MASKINONGE",
        "SAINT-EDOUARD-DE-NAPIERVILLE",
        "SAINT-ELIE-DE-CAXTON",
        "SAINT-ELOI",
        "SAINT-ELPHEGE",
        "SAINT-ELZEAR",
        "SAINT-ELZEAR-DE-BONAVENTURE",
        "SAINT-ELZEAR-DE-TEMISCOUATA",
        "SAINT-EMILE-DE-SUFFOLK",
        "SAINT-EPHREM-DE-BEAUCE",
        "SAINT-EPIPHANE",
        "SAINT-ESPRIT",
        "SAINT-ETIENNE-DE-BEAUHARNOIS",
        "SAINT-ETIENNE-DE-BOLTON",
        "SAINT-ETIENNE-DE-LAUZON",
        "SAINT-ETIENNE-DES-GRES",
        "SAINT-EUGENE-D'ARGENTENAY",
        "SAINT-EUGENE-DE-GRANTHAM",
        "SAINT-EUGENE-DE-GUIGUES",
        "SAINT-EUSEBE",
        "SAINT-EUSTACHE",
        "SAINT-EVARISTE-DE-FORSYTH",
        "SAINT-FABIEN",
        "SAINT-FABIEN-DE-PANET",
        "SAINT-FAUSTIN-LAC-CARRE",
        "SAINT-FELICIEN",
        "SAINT-FELIX-D'OTIS",
        "SAINT-FELIX-DE-DALQUIER",
        "SAINT-FELIX-DE-KINGSEY",
        "SAINT-FELIX-DE-VALOIS",
        "SAINT-FERDINAND",
        "SAINT-FERREOL-LES-NEIGES",
        "SAINT-FLAVIEN",
        "SAINT-FORTUNAT",
        "SAINT-FRANCOIS-D'ASSISE",
        "SAINT-FRANCOIS-D'ORLEANS",
        "SAINT-FRANCOIS-DE-SALES",
        "SAINT-FRANCOIS-DU-LAC",
        "SAINT-FRANCOIS-XAVIER-DE-VIGER",
        "SAINT-FREDERIC",
        "SAINT-FULGENCE",
        "SAINT-GABRIEL-DE-BRANDON",
        "SAINT-GABRIEL-DE-RIMOUSKI",
        "SAINT-GABRIEL-DE-VALCARTIER",
        "SAINT-GEDEON",
        "SAINT-GEDEON-DE-BEAUCE",
        "SAINT-GEORGES",
        "SAINT-GEORGES-DE-CHAMPLAIN",
        "SAINT-GEORGES-DE-MALBAIE",
        "SAINT-GEORGES-DE-WINDSOR",
        "SAINT-GERARD-DES-LAURENTIDES",
        "SAINT-GERMAIN",
        "SAINT-GERMAIN-DE-GRANTHAM",
        "SAINT-GERVAIS",
        "SAINT-GILBERT",
        "SAINT-GILLES",
        "SAINT-GODEFROI",
        "SAINT-GUILLAUME",
        "SAINT-GUY",
        "SAINT-HENRI-DE-LEVIS",
        "SAINT-HERMENEGILDE",
        "SAINT-HILARION",
        "SAINT-HIPPOLYTE",
        "SAINT-HONORE-DE-CHICOUTIMI",
        "SAINT-HONORE-DE-SHENLEY",
        "SAINT-HONORE-DE-TEMISCOUATA",
        "SAINT-HUBERT",
        "SAINT-HUBERT-RIVIERE-DU-LOUP",
        "SAINT-HUGUES",
        "SAINT-HYACINTHE",
        "SAINT-IGNACE-DE-LOYOLA",
        "SAINT-IGNACE-DE-STANBRIDGE",
        "SAINT-IRENEE",
        "SAINT-ISIDORE",
        "SAINT-ISIDORE-DE-CLIFTON",
        "SAINT-ISIDORE-DE-LAPRAIRIE",
        "SAINT-JACQUES",
        "SAINT-JACQUES-DE-LEEDS",
        "SAINT-JACQUES-LE-MINEUR",
        "SAINT-JEAN-BAPTISTE",
        "SAINT-JEAN-CHRYSOSTOME",
        "SAINT-JEAN-D'ORLEANS",
        "SAINT-JEAN-DE-BREBEUF",
        "SAINT-JEAN-DE-CHERBOURG",
        "SAINT-JEAN-DE-DIEU",
        "SAINT-JEAN-DE-LA-LANDE",
        "SAINT-JEAN-DE-MATAPEDIA",
        "SAINT-JEAN-DE-MATHA",
        "SAINT-JEAN-DES-PILES",
        "SAINT-JEAN-PORT-JOLI",
        "SAINT-JEAN-SUR-RICHELIEU",
        "SAINT-JEROME",
        "SAINT-JOACHIM-DE-COURVAL",
        "SAINT-JOACHIM-DE-SHEFFORD",
        "SAINT-JOGUES",
        "SAINT-JOSEPH-DE-BEAUCE",
        "SAINT-JOSEPH-DE-COLERAINE",
        "SAINT-JOSEPH-DE-HAM-SUD",
        "SAINT-JOSEPH-DE-KAMOURASKA",
        "SAINT-JOSEPH-DE-LA-RIVE",
        "SAINT-JOSEPH-DE-LEPAGE",
        "SAINT-JOSEPH-DE-SOREL",
        "SAINT-JOSEPH-DU-LAC",
        "SAINT-JUDE",
        "SAINT-JULES",
        "SAINT-JULIEN",
        "SAINT-JUST-DE-BRETENIERES",
        "SAINT-JUSTE-DU-LAC",
        "SAINT-JUSTIN",
        "SAINT-LAMBERT",
        "SAINT-LAMBERT-DE-LAUZON",
        "SAINT-LAURENT",
        "SAINT-LAURENT-ILE-D'ORLEANS",
        "SAINT-LAZARE",
        "SAINT-LAZARE-DE-BELLECHASSE",
        "SAINT-LEANDRE",
        "SAINT-LEON",
        "SAINT-LEON-LE-GRAND",
        "SAINT-LEONARD",
        "SAINT-LEONARD-D'ASTON",
        "SAINT-LEONARD-DE-PORTNEUF",
        "SAINT-LIBOIRE",
        "SAINT-LIGUORI",
        "SAINT-LIN-LAURENTIDES",
        "SAINT-LOUIS",
        "SAINT-LOUIS-DE-BLANDFORD",
        "SAINT-LOUIS-DE-GONZAGUE",
        "SAINT-LOUIS-DU-HA-HA",
        "SAINT-LUC-DE-BELLECHASSE",
        "SAINT-LUC-DE-VINCENNES",
        "SAINT-LUCIEN",
        "SAINT-LUDGER",
        "SAINT-LUDGER-DE-MILOT",
        "SAINT-MAGLOIRE",
        "SAINT-MAJORIQUE",
        "SAINT-MALACHIE",
        "SAINT-MALO",
        "SAINT-MARC-DE-FIGUERY",
        "SAINT-MARC-DES-CARRIERES",
        "SAINT-MARC-DU-LAC-LONG",
        "SAINT-MARC-SUR-RICHELIEU",
        "SAINT-MARCEL-DE-RICHELIEU",
        "SAINT-MARCELLIN",
        "SAINT-MARTIN",
        "SAINT-MATHIAS-SUR-RICHELIEU",
        "SAINT-MATHIEU-D'HARRICANA",
        "SAINT-MATHIEU-DE-BELOEIL",
        "SAINT-MATHIEU-DE-LAPRAIRIE",
        "SAINT-MATHIEU-DE-RIOUX",
        "SAINT-MATHIEU-DU-PARC",
        "SAINT-MAURICE",
        "SAINT-MEDARD",
        "SAINT-MICHEL",
        "SAINT-MICHEL-DE-BELLECHASSE",
        "SAINT-MICHEL-DES-SAINTS",
        "SAINT-MODESTE",
        "SAINT-MOISE",
        "SAINT-NARCISSE",
        "SAINT-NARCISSE-DE-BEAURIVAGE",
        "SAINT-NARCISSE-DE-RIMOUSKI",
        "SAINT-NAZAIRE-D'ACTON",
        "SAINT-NAZAIRE-DE-DORCHESTER",
        "SAINT-NEREE",
        "SAINT-NICEPHORE",
        "SAINT-NICOLAS",
        "SAINT-NOEL",
        "SAINT-NORBERT",
        "SAINT-NORBERT-D'ARTHABASKA",
        "SAINT-ODILON",
        "SAINT-OMER",
        "SAINT-OMER-L'ISLET",
        "SAINT-OURS",
        "SAINT-PACOME",
        "SAINT-PAMPHILE",
        "SAINT-PASCAL",
        "SAINT-PATRICE-DE-BEAURIVAGE",
        "SAINT-PAUL",
        "SAINT-PAUL-D'ABBOTSFORD",
        "SAINT-PAUL-DE-LA-CROIX",
        "SAINT-PAUL-DE-MONTMINY",
        "SAINT-PAULIN",
        "SAINT-PHILEMON",
        "SAINT-PHILIBERT",
        "SAINT-PHILIPPE",
        "SAINT-PHILIPPE-DE-NERI",
        "SAINT-PIE",
        "SAINT-PIE-DE-GUIRE",
        "SAINT-PIERRE-BAPTISTE",
        "SAINT-PIERRE-DE-BROUGHTON",
        "SAINT-PIERRE-DE-LAMY",
        "SAINT-PIERRE-ILE-D'ORLEANS",
        "SAINT-PIERRE-LES-BECQUETS",
        "SAINT-PLACIDE",
        "SAINT-POLYCARPE",
        "SAINT-PRIME",
        "SAINT-PROSPER",
        "SAINT-PROSPER-DE-DORCHESTER",
        "SAINT-RAPHAEL",
        "SAINT-RAYMOND",
        "SAINT-REDEMPTEUR",
        "SAINT-REMI",
        "SAINT-REMI-D'AMHERST",
        "SAINT-REMI-DE-TINGWICK",
        "SAINT-RENE",
        "SAINT-RENE-DE-MATANE",
        "SAINT-ROBERT",
        "SAINT-ROBERT-BELLARMIN",
        "SAINT-ROCH-DE-L'ACHIGAN",
        "SAINT-ROCH-DE-MEKINAC",
        "SAINT-ROCH-DE-RICHELIEU",
        "SAINT-ROCH-DES-AULNAIES",
        "SAINT-ROCH-OUEST",
        "SAINT-ROMAIN",
        "SAINT-ROMUALD",
        "SAINT-ROSAIRE",
        "SAINT-SAMUEL",
        "SAINT-SAUVEUR",
        "SAINT-SEBASTIEN",
        "SAINT-SEBASTIEN-DE-FRONTENAC",
        "SAINT-SEVERE",
        "SAINT-SEVERIN-DE-BEAUCE",
        "SAINT-SIMEON",
        "SAINT-SIMEON-DE-BONAVENTURE",
        "SAINT-SIMON-DE-BAGOT",
        "SAINT-SIMON-DE-RIMOUSKI",
        "SAINT-SIMON-LES-MINES",
        "SAINT-STANISLAS",
        "SAINT-STANISLAS-DE-CHAMPLAIN",
        "SAINT-STANISLAS-DE-KOSTKA",
        "SAINT-SULPICE",
        "SAINT-SYLVERE",
        "SAINT-SYLVESTRE",
        "SAINT-TELESPHORE",
        "SAINT-THARCISIUS",
        "SAINT-THEODORE-D'ACTON",
        "SAINT-THEOPHILE",
        "SAINT-THOMAS",
        "SAINT-THOMAS-DIDYME",
        "SAINT-THURIBE",
        "SAINT-TITE",
        "SAINT-TITE-DES-CAPS",
        "SAINT-UBALDE",
        "SAINT-ULRIC",
        "SAINT-URBAIN-DE-CHARLEVOIX",
        "SAINT-URBAIN-PREMIER",
        "SAINT-VALENTIN",
        "SAINT-VALERE",
        "SAINT-VALERIEN-DE-RIMOUSKI",
        "SAINT-VALLIER",
        "SAINT-VIANNEY",
        "SAINT-VICTOR",
        "SAINT-VITAL-DE-CLERMONT",
        "SAINT-WENCESLAS",
        "SAINT-ZACHARIE",
        "SAINT-ZENON",
        "SAINT-ZEPHIRIN-DE-COURVAL",
        "SAINT-ZOTIQUE",
        "SAINTE-ADELE",
        "SAINTE-AGATHE-DE-LOTBINIERE",
        "SAINTE-AGATHE-DES-MONTS",
        "SAINTE-AGATHE-NORD",
        "SAINTE-AGNES-DE-DUNDEE",
        "SAINTE-ANGELE-DE-MERICI",
        "SAINTE-ANGELE-DE-MONNOIR",
        "SAINTE-ANGELE-DE-PREMONT",
        "SAINTE-ANNE-DE-BEAUPRE",
        "SAINTE-ANNE-DE-BELLEVUE",
        "SAINTE-ANNE-DE-LA-PERADE",
        "SAINTE-ANNE-DE-LA-ROCHELLE",
        "SAINTE-ANNE-DE-SOREL",
        "SAINTE-ANNE-DES-LACS",
        "SAINTE-ANNE-DES-MONTS",
        "SAINTE-ANNE-DES-PLAINES",
        "SAINTE-ANNE-DU-LAC",
        "SAINTE-ANNE-DU-SAULT",
        "SAINTE-APOLLINE-DE-PATTON",
        "SAINTE-AURELIE",
        "SAINTE-BARBE",
        "SAINTE-BEATRIX",
        "SAINTE-BRIGIDE-D'IBERVILLE",
        "SAINTE-BRIGITTE-DE-LAVAL",
        "SAINTE-BRIGITTE-DES-SAULTS",
        "SAINTE-CATHERINE",
        "SAINTE-CATHERINE-DE-HATLEY",
        "SAINTE-CECILE-DE-LEVRARD",
        "SAINTE-CECILE-DE-MASHAM",
        "SAINTE-CECILE-DE-MILTON",
        "SAINTE-CECILE-DE-WHITTON",
        "SAINTE-CHRISTINE",
        "SAINTE-CHRISTINE-D'AUVERGNE",
        "SAINTE-CLAIRE",
        "SAINTE-CLOTILDE-DE-BEAUCE",
        "SAINTE-CLOTILDE-DE-CHATEAUGUAY",
        "SAINTE-CLOTILDE-DE-HORTON",
        "SAINTE-CROIX",
        "SAINTE-DOROTHEE",
        "SAINTE-EDWIDGE",
        "SAINTE-ELISABETH",
        "SAINTE-ELISABETH-DE-PROULX",
        "SAINTE-ELIZABETH-DE-WARWICK",
        "SAINTE-EMELIE-DE-L'ENERGIE",
        "SAINTE-EULALIE",
        "SAINTE-EUPHEMIE",
        "SAINTE-FAMILLE",
        "SAINTE-FELICITE",
        "SAINTE-FELICITE-DE-L'ISLET",
        "SAINTE-FLAVIE",
        "SAINTE-FLORENCE",
        "SAINTE-FRANCOISE",
        "SAINTE-FRANCOISE-DE-LOTBINIERE",
        "SAINTE-GENEVIEVE",
        "SAINTE-GENEVIEVE-DE-BATISCAN",
        "SAINTE-GERMAINE-BOULE",
        "SAINTE-GERTRUDE-MANNEVILLE",
        "SAINTE-HEDWIDGE-DE-ROBERVAL",
        "SAINTE-HELENE-DE-BAGOT",
        "SAINTE-HELENE-DE-BREAKEYVILLE",
        "SAINTE-HELENE-DE-CHESTER",
        "SAINTE-HELENE-DE-KAMOURASKA",
        "SAINTE-HENEDINE",
        "SAINTE-JULIE",
        "SAINTE-JULIENNE",
        "SAINTE-JUSTINE",
        "SAINTE-JUSTINE-DE-NEWTON",
        "SAINTE-LOUISE",
        "SAINTE-LUCE",
        "SAINTE-LUCIE-DE-BEAUREGARD",
        "SAINTE-LUCIE-DES-LAURENTIDES",
        "SAINTE-MADELEINE",
        "SAINTE-MARCELLINE-DE-KILDARE",
        "SAINTE-MARGUERITE-MARIE",
        "SAINTE-MARIE",
        "SAINTE-MARIE-DE-BLANDFORD",
        "SAINTE-MARIE-SALOME",
        "SAINTE-MARTHE",
        "SAINTE-MARTHE-SUR-LE-LAC",
        "SAINTE-MARTINE",
        "SAINTE-MELANIE",
        "SAINTE-MONIQUE",
        "SAINTE-MONIQUE-LAC-SAINT-JEAN",
        "SAINTE-PAULE",
        "SAINTE-PERPETUE",
        "SAINTE-PERPETUE-DE-L'ISLET",
        "SAINTE-PETRONILLE",
        "SAINTE-RITA",
        "SAINTE-ROSE",
        "SAINTE-ROSE-DE-WATFORD",
        "SAINTE-ROSE-DU-NORD",
        "SAINTE-SABINE",
        "SAINTE-SABINE-DE-BELLECHASSE",
        "SAINTE-SERAPHINE",
        "SAINTE-SOPHIE",
        "SAINTE-SOPHIE-D'HALIFAX",
        "SAINTE-SOPHIE-DE-LEVRARD",
        "SAINTE-THECLE",
        "SAINTE-THERESE",
        "SAINTE-THERESE-DE-GASPE",
        "SAINTE-THERESE-DE-LA-GATINEAU",
        "SAINTE-URSULE",
        "SAINTE-VICTOIRE-DE-SOREL",
        "SAINTS-ANGES",
        "SAINTS-MARTYRS-CANADIENS",
        "SALABERRY-DE-VALLEYFIELD",
        "SALLUIT",
        "SAWYERVILLE",
        "SAYABEC",
        "SCHEFFERVILLE",
        "SCOTSTOWN",
        "SCOTT",
        "SENNETERRE",
        "SENNEVILLE",
        "SEPT-ILES",
        "SHANNON",
        "SHAWINIGAN",
        "SHAWINIGAN-SUD",
        "SHAWVILLE",
        "SHEENBORO",
        "SHEFFORD",
        "SHELDRAKE",
        "SHERBROOKE",
        "SHERRINGTON",
        "SHIGAWAKE",
        "SHIPSHAW",
        "SOREL-TRACY",
        "SQUATEC",
        "ST-ATHANASE",
        "ST-BARNABE-NORD",
        "ST-FRANCOIS-DE-LA-RIVIERE-DU-S",
        "ST-FRANCOIS-XAVIER-DE-BROMPTON",
        "ST-GABRIEL-DE-KAMOURASKA",
        "ST-JOACHIM-DE-MONTMORENCY",
        "ST-JOSEPH-DE-LA-POINTE-DE-LEVY",
        "ST-MARCEL-DE-L'ISLET",
        "ST-NAZAIRE-DU-LAC-ST-JEAN",
        "ST-OCTAVE",
        "ST-ONESIME",
        "ST-PIERRE-DE-LA-RIVIERE-DU-SUD",
        "ST-VALERIEN",
        "STANBRIDGE EAST",
        "STANBRIDGE STATION",
        "STANDON",
        "STANSTEAD",
        "STE-CATHERINE-DE-LA-J-CARTIER",
        "STE-IRENE-DE-MATAPEDIA",
        "STE-JEANNE-D'ARC-DE-MATANE",
        "STE-MARGUERITE-DE-DORCHESTER",
        "STE-MARGUERITE-DU-LAC-MASSON",
        "STOKE",
        "STONEHAM-ET-TEWKESBURY",
        "STORNOWAY",
        "STRATFORD",
        "STUKELY-SUD",
        "SUTTON",
        "TADOUSSAC",
        "TAILLON",
        "TASCHEREAU",
        "TASIUJAQ",
        "TEMISCAMING",
        "TERRASSE-VAUDREUIL",
        "TERREBONNE",
        "TETE-A-LA-BALEINE",
        "THETFORD MINES",
        "THURSO",
        "TINGWICK",
        "TOURVILLE",
        "TRECESSON",
        "TRES-SAINT-REDEMPTEUR",
        "TRING-JONCTION",
        "TROIS-PISTOLES",
        "TROIS-RIVES",
        "TROIS-RIVIERES",
        "ULVERTON",
        "UMIUJAQ",
        "UPTON",
        "VAL-ALAIN",
        "VAL-BRILLANT",
        "VAL-D'ESPOIR",
        "VAL-D'OR",
        "VAL-DAVID",
        "VAL-DES-BOIS",
        "VAL-DES-LACS",
        "VAL-DES-MONTS",
        "VAL-JOLI",
        "VAL-MORIN",
        "VAL-PARADIS",
        "VAL-RACINE",
        "VAL-SAINT-GILLES",
        "VALCOURT",
        "VALLEE-JONCTION",
        "VARENNES",
        "VAUDREUIL-DORION",
        "VAUDREUIL-SUR-LE-LAC",
        "VENISE-EN-QUEBEC",
        "VENOSTA",
        "VERCHERES",
        "VERDUN",
        "VICTORIAVILLE",
        "VILLAGE SAINT-PIERRE",
        "VILLE-MARIE",
        "VILLEBOIS",
        "VILLEROY",
        "VIMONT",
        "WAKEFIELD",
        "WALTHAM",
        "WARDEN",
        "WARWICK",
        "WASKAGANISH",
        "WASWANIPI",
        "WATERLOO",
        "WATERVILLE",
        "WEEDON",
        "WEMINDJI",
        "WEMOTACI",
        "WENDAKE",
        "WENTWORTH",
        "WENTWORTH-NORD",
        "WEST BROME",
        "WESTBURY",
        "WESTMOUNT",
        "WICKHAM",
        "WINDSOR",
        "WOBURN",
        "WOLINAK",
        "WOTTON",
        "YAMACHICHE",
        "YAMASKA",
        "YAMASKA-EST",
    ],
    "SK": [
        "ABBEY",
        "ABERDEEN",
        "ABERNETHY",
        "ADMIRAL",
        "AIR RONGE",
        "ALAMEDA",
        "ALBERTVILLE",
        "ALIDA",
        "ALLAN",
        "ALSASK",
        "ALTICANE",
        "ALVENA",
        "ANEROID",
        "ANNAHEIM",
        "ANTLER",
        "ARBORFIELD",
        "ARCHERWILL",
        "ARCOLA",
        "ARDATH",
        "ARDILL",
        "ARELEE",
        "ARRAN",
        "ASQUITH",
        "ASSINIBOIA",
        "ATWATER",
        "AVONHURST",
        "AVONLEA",
        "AYLESBURY",
        "AYLSHAM",
        "BALCARRES",
        "BALDWINTON",
        "BALGONIE",
        "BANGOR",
        "BANKEND",
        "BARTHEL",
        "BATEMAN",
        "BATTLEFORD",
        "BEATTY",
        "BEAUBIER",
        "BEAUVAL",
        "BEAVER CREEK",
        "BEECHY",
        "BELLE PLAINE",
        "BELLEGARDE",
        "BENGOUGH",
        "BENSON",
        "BETHUNE",
        "BIENFAIT",
        "BIG BEAVER",
        "BIG RIVER",
        "BIGGAR",
        "BIRCH HILLS",
        "BIRSAY",
        "BJORKDALE",
        "BLACK LAKE",
        "BLADWORTH",
        "BLAINE LAKE",
        "BLUMENHOF",
        "BORDEN",
        "BRACKEN",
        "BRADWELL",
        "BREDENBURY",
        "BRIERCREST",
        "BRIGHT SAND",
        "BROADVIEW",
        "BROCK",
        "BROCKINGTON",
        "BRODERICK",
        "BROMHEAD",
        "BROOKSBY",
        "BROWNLEE",
        "BRUNO",
        "BUCHANAN",
        "BUENA VISTA",
        "BUFFALO NARROWS",
        "BULYEA",
        "BURR",
        "BURSTALL",
        "BUSHELL PARK",
        "CABRI",
        "CACTUS LAKE",
        "CADILLAC",
        "CALDER",
        "CANDIAC",
        "CANDLE LAKE",
        "CANDO",
        "CANOE NARROWS",
        "CANORA",
        "CANWOOD",
        "CARDROSS",
        "CARIEVALE",
        "CARLTON",
        "CARLYLE",
        "CARMEL",
        "CARNDUFF",
        "CARON",
        "CARONPORT",
        "CARRAGANA",
        "CARROT RIVER",
        "CASA RIO",
        "CENTRAL BUTTE",
        "CEYLON",
        "CHAMBERLAIN",
        "CHAPLIN",
        "CHELAN",
        "CHITEK LAKE",
        "CHOICELAND",
        "CHRISTOPHER LAKE",
        "CHURCHBRIDGE",
        "CLAIR",
        "CLAVET",
        "CLAYBANK",
        "CLAYDON",
        "CLEARWATER RIVER",
        "CLIMAX",
        "COCHIN",
        "CODERRE",
        "CODETTE",
        "COLE BAY",
        "COLEVILLE",
        "COLFAX",
        "COLGATE",
        "COLONSAY",
        "CONGRESS",
        "CONQUEST",
        "CONSUL",
        "COPPERSANDS",
        "CORMAN PARK",
        "CORNING",
        "CORONACH",
        "COURVAL",
        "COWESSESS",
        "CRAIK",
        "CRANE VALLEY",
        "CRAVEN",
        "CREELMAN",
        "CREIGHTON",
        "CROOKED RIVER",
        "CRYSTAL SPRINGS",
        "CUDWORTH",
        "CUMBERLAND HOUSE",
        "CUPAR",
        "CUT KNIFE",
        "CYMRIC",
        "D'ARCY STATION",
        "DAFOE",
        "DALMENY",
        "DANBURY",
        "DAVIDSON",
        "DAVIN",
        "DEBDEN",
        "DEER VALLEY",
        "DELISLE",
        "DELMAS",
        "DEMAINE",
        "DENARE BEACH",
        "DENHOLM",
        "DENZIL",
        "DESCHAMBAULT LAKE",
        "DILKE",
        "DILLON",
        "DINSMORE",
        "DODSLAND",
        "DOLLARD",
        "DOMREMY",
        "DORINTOSH",
        "DRAKE",
        "DRINKWATER",
        "DUBUC",
        "DUCK LAKE",
        "DUFF",
        "DUMMER",
        "DUNDURN",
        "DUPEROW",
        "DUVAL",
        "DYSART",
        "EAGLE RIDGE",
        "EARL GREY",
        "EASTEND",
        "EATONIA",
        "EBENEZER",
        "EDAM",
        "EDENWOLD",
        "EDGELEY",
        "ELBOW",
        "ELFROS",
        "ELROSE",
        "ELSTOW",
        "EMERALD PARK",
        "ENDEAVOUR",
        "ENGLEFELD",
        "ERNFOLD",
        "ESTERHAZY",
        "ESTEVAN",
        "ESTON",
        "EVESHAM",
        "EYEBROW",
        "FAIRLIGHT",
        "FAIRY GLEN",
        "FENWOOD",
        "FERLAND",
        "FERTILE",
        "FIFE LAKE",
        "FILLMORE",
        "FINDLATER",
        "FIR MOUNTAIN",
        "FISKE",
        "FLAXCOMBE",
        "FLEMING",
        "FLINTOFT",
        "FOAM LAKE",
        "FOND DU LAC",
        "FORGET",
        "FORT QU'APPELLE",
        "FOSSTON",
        "FOX VALLEY",
        "FOXFORD",
        "FRANCIS",
        "FRENCHMAN BUTTE",
        "FROBISHER",
        "FRONTIER",
        "FULDA",
        "FURDALE",
        "GAINSBOROUGH",
        "GALLIVAN",
        "GARRICK",
        "GERALD",
        "GLADMAR",
        "GLASLYN",
        "GLASNEVIN",
        "GLEN EWEN",
        "GLENAVON",
        "GLENBAIN",
        "GLENBUSH",
        "GLENSIDE",
        "GLENTWORTH",
        "GLIDDEN",
        "GOLDEN PRAIRIE",
        "GOODEVE",
        "GOODSOIL",
        "GOODWATER",
        "GOULDTOWN",
        "GOVAN",
        "GRANDORA",
        "GRASSWOOD",
        "GRAVELBOURG",
        "GRAY",
        "GRAYSON",
        "GREEN LAKE",
        "GRENFELL",
        "GRIFFIN",
        "GRONLID",
        "GUERNSEY",
        "GULL LAKE",
        "HAFFORD",
        "HAGEN",
        "HAGUE",
        "HALBRITE",
        "HANDEL",
        "HANLEY",
        "HARRIS",
        "HAWARDEN",
        "HAZEL DELL",
        "HAZENMORE",
        "HAZLET",
        "HEARNE",
        "HENDON",
        "HENRIBOURG",
        "HEPBURN",
        "HERBERT",
        "HERSCHEL",
        "HEWARD",
        "HODGEVILLE",
        "HOEY",
        "HOLBEIN",
        "HOLDFAST",
        "HOOSIER",
        "HUBBARD",
        "HUDSON BAY",
        "HUMBOLDT",
        "HYAS",
        "ILE-A-LA-CROSSE",
        "IMPERIAL",
        "INDIAN HEAD",
        "INSINGER",
        "INVERMAY",
        "ISLAND LAKE",
        "ITUNA",
        "JACKFISH LAKE",
        "JANSEN",
        "JEDBURGH",
        "KAMSACK",
        "KAYVILLE",
        "KEELER",
        "KELFIELD",
        "KELLIHER",
        "KELVINGTON",
        "KENASTON",
        "KENDAL",
        "KENNEDY",
        "KENOSEE LAKE",
        "KERROBERT",
        "KHEDIVE",
        "KILLALY",
        "KINCAID",
        "KINDERSLEY",
        "KINISTINO",
        "KINLEY",
        "KINOOSAO",
        "KIPLING",
        "KISBEY",
        "KRONAU",
        "KRYDOR",
        "KUROKI",
        "KYLE",
        "KYLEMORE",
        "LA LOCHE",
        "LA RONGE",
        "LAC VERT",
        "LACADENA",
        "LAFLECHE",
        "LAIRD",
        "LAJORD",
        "LAKE ALMA",
        "LAKE LENORE",
        "LAMPMAN",
        "LANCER",
        "LANDIS",
        "LANG",
        "LANGBANK",
        "LANGENBURG",
        "LANGHAM",
        "LANIGAN",
        "LAPORTE",
        "LASHBURN",
        "LEADER",
        "LEASK",
        "LEBRET",
        "LEMBERG",
        "LEOVILLE",
        "LEROSS",
        "LEROY",
        "LESLIE",
        "LESTOCK",
        "LEWVAN",
        "LIBERTY",
        "LIEBENTHAL",
        "LIMERICK",
        "LINTLAW",
        "LIPTON",
        "LISIEUX",
        "LIVELONG",
        "LLOYDMINSTER",
        "LOCKWOOD",
        "LONE ROCK",
        "LOON LAKE",
        "LOREBURN",
        "LOVE",
        "LOVERNA",
        "LUCKY LAKE",
        "LUMSDEN",
        "LUSELAND",
        "MACDOWALL",
        "MACKLIN",
        "MACNUTT",
        "MACOUN",
        "MACRORIE",
        "MADISON",
        "MAIDSTONE",
        "MAIN CENTRE",
        "MAJOR",
        "MAKWA",
        "MANKOTA",
        "MANOR",
        "MANTARIO",
        "MAPLE CREEK",
        "MARCELIN",
        "MARENGO",
        "MARGO",
        "MARKINCH",
        "MARQUIS",
        "MARSDEN",
        "MARSHALL",
        "MARTENSVILLE",
        "MARYFIELD",
        "MAYFAIR",
        "MAYMONT",
        "MAYVIEW",
        "MAZENOD",
        "MCCORD",
        "MCLEAN",
        "MCMAHON",
        "MCTAGGART",
        "MEACHAM",
        "MEADOW LAKE",
        "MEATH PARK",
        "MEDSTEAD",
        "MELFORT",
        "MELVILLE",
        "MENDHAM",
        "MEOTA",
        "MERVIN",
        "MESKANAW",
        "MEYRONNE",
        "MIDALE",
        "MIDDLE LAKE",
        "MIKADO",
        "MILDEN",
        "MILDRED",
        "MILESTONE",
        "MINTON",
        "MISTATIM",
        "MONT NEBO",
        "MONTMARTRE",
        "MONTREAL LAKE",
        "MOOSE JAW",
        "MOOSOMIN",
        "MORSE",
        "MORTLACH",
        "MOSSBANK",
        "MOZART",
        "MUENSTER",
        "MULLINGAR",
        "MUSKODAY",
        "NAICAM",
        "NEIDPATH",
        "NEILBURG",
        "NETHERHILL",
        "NEUDORF",
        "NEVILLE",
        "NIPAWIN",
        "NOKOMIS",
        "NORQUAY",
        "NORTH BATTLEFORD",
        "NORTH PORTAL",
        "NORTH WEYBURN",
        "NORTHGATE",
        "NUT MOUNTAIN",
        "ODESSA",
        "OGEMA",
        "OKLA",
        "ONION LAKE",
        "ORKNEY",
        "ORMISTON",
        "OSAGE",
        "OSLER",
        "OUNGRE",
        "OUTLOOK",
        "OXBOW",
        "PADDOCKWOOD",
        "PAKWAW LAKE",
        "PALMER",
        "PAMBRUN",
        "PANGMAN",
        "PARADISE HILL",
        "PARKBEG",
        "PARKERVIEW",
        "PARKMAN",
        "PARKSIDE",
        "PARRY",
        "PASQUA",
        "PATHLOW",
        "PATUANAK",
        "PAYNTON",
        "PEEBLES",
        "PELICAN NARROWS",
        "PELLY",
        "PENNANT STATION",
        "PENSE",
        "PENZANCE",
        "PERDUE",
        "PHIPPEN",
        "PIAPOT",
        "PIERCELAND",
        "PILGER",
        "PILOT BUTTE",
        "PINEHOUSE LAKE",
        "PLATO",
        "PLEASANTDALE",
        "PLENTY",
        "PLUNKETT",
        "PONTEIX",
        "PORCUPINE PLAIN",
        "PORTREEVE",
        "PRAIRIE RIVER",
        "PRAIRIE VIEW",
        "PREECEVILLE",
        "PRELATE",
        "PRIMATE",
        "PRINCE ALBERT",
        "PRUD'HOMME",
        "PUNNICHY",
        "QU'APPELLE",
        "QUILL LAKE",
        "QUINTON",
        "RABBIT LAKE",
        "RADISSON",
        "RADVILLE",
        "RAMA",
        "RAPID VIEW",
        "RAYMORE",
        "RED EARTH",
        "REDVERS",
        "REGINA BEACH",
        "REGINA",
        "REWARD",
        "RHEIN",
        "RICETON",
        "RICHARD",
        "RICHARDSON",
        "RICHLEA",
        "RICHMOUND",
        "RIDGEDALE",
        "RIVERHURST",
        "RIVERSIDE ESTATES",
        "ROBSART",
        "ROCANVILLE",
        "ROCKGLEN",
        "ROCKHAVEN",
        "ROKEBY",
        "ROSE VALLEY",
        "ROSETOWN",
        "ROSTHERN",
        "ROULEAU",
        "RUDDELL",
        "RUNNYMEDE",
        "RUSH LAKE",
        "RUTHILDA",
        "SALTCOATS",
        "SANDY BAY",
        "SASKATOON",
        "SCEPTRE",
        "SCOTT",
        "SCOUT LAKE",
        "SEDLEY",
        "SEMANS",
        "SENLAC",
        "SHACKLETON",
        "SHAMROCK",
        "SHAUNAVON",
        "SHEHO",
        "SHELL LAKE",
        "SHELLBROOK",
        "SHIPMAN",
        "SILTON",
        "SIMMIE",
        "SIMPSON",
        "SINTALUTA",
        "SMEATON",
        "SMILEY",
        "SNOWDEN",
        "SONNINGDALE",
        "SOUTHEND",
        "SOUTHEY",
        "SOVEREIGN",
        "SPALDING",
        "SPEERS",
        "SPIRITWOOD",
        "SPRING VALLEY",
        "SPRINGSIDE",
        "SPRINGWATER",
        "SPRUCE HOME",
        "SPRUCE LAKE",
        "SPY HILL",
        "ST BENEDICT",
        "ST BRIEUX",
        "ST DENIS",
        "ST GREGOR",
        "ST ISIDORE DE BELLEVUE",
        "ST LOUIS",
        "ST VICTOR",
        "ST WALBURG",
        "STALWART",
        "STANLEY MISSION",
        "STAR CITY",
        "STEELMAN",
        "STENEN",
        "STEWART VALLEY",
        "STOCKHOLM",
        "STONY BEACH",
        "STONY RAPIDS",
        "STORNOWAY",
        "STORTHOAKS",
        "STOUGHTON",
        "STRANRAER",
        "STRASBOURG",
        "STRONGFIELD",
        "STUMP LAKE",
        "STURGEON LANDING",
        "STURGIS",
        "SUCCESS",
        "SUMMERBERRY",
        "SWIFT CURRENT",
        "SYLVANIA",
        "TANTALLON",
        "TESSIER",
        "THEODORE",
        "TIMBER BAY",
        "TISDALE",
        "TOGO",
        "TOMPKINS",
        "TORQUAY",
        "TRAMPING LAKE",
        "TRIBUNE",
        "TROSSACHS",
        "TRUAX",
        "TUFFNELL",
        "TUGASKE",
        "TURNOR LAKE",
        "TURTLEFORD",
        "TUXFORD",
        "TWAY",
        "TYNER",
        "TYVAN",
        "UNITY",
        "URANIUM CITY",
        "VAL MARIE",
        "VANGUARD",
        "VANSCOY",
        "VAWN",
        "VEREGIN",
        "VERWOOD",
        "VIBANK",
        "VICEROY",
        "VICTOIRE",
        "VIDORA",
        "VISCOUNT",
        "VONDA",
        "WADENA",
        "WAKAW",
        "WALDECK",
        "WALDHEIM",
        "WALDRON",
        "WAPELLA",
        "WARMAN",
        "WASECA",
        "WASKESIU LAKE",
        "WATERHEN LAKE",
        "WATROUS",
        "WATSON",
        "WAUCHOPE",
        "WAWOTA",
        "WEBB",
        "WEEKES",
        "WEIRDALE",
        "WELDON",
        "WELWYN",
        "WEST BEND",
        "WEYAKWIN",
        "WEYBURN",
        "WHELAN",
        "WHITE BEAR",
        "WHITE CITY",
        "WHITE FOX",
        "WHITECAP",
        "WHITEWOOD",
        "WILCOX",
        "WILKIE",
        "WILLOW BUNCH",
        "WILLOWBROOK",
        "WINDTHORST",
        "WISETON",
        "WISHART",
        "WOLLASTON LAKE",
        "WOLSELEY",
        "WOOD MOUNTAIN",
        "WOODROW",
        "WROXTON",
        "WYMARK",
        "WYNYARD",
        "YARBO",
        "YELLOW CREEK",
        "YELLOW GRASS",
        "YELLOW QUILL",
        "YORKTON",
        "YOUNG",
        "ZEALANDIA",
        "ZEHNER",
        "ZENON PARK",
    ],
    "YT": [
        "BEAVER CREEK",
        "BURWASH LANDING",
        "CARCROSS",
        "CARMACKS",
        "DAWSON",
        "DESTRUCTION BAY",
        "ELSA",
        "FARO",
        "HAINES JUNCTION",
        "MARSH LAKE",
        "MAYO",
        "OLD CROW",
        "PELLY CROSSING",
        "ROSS RIVER",
        "TAGISH",
        "TESLIN",
        "WATSON LAKE",
        "WHITEHORSE",
    ],
}
